IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfServiceCPWProjectsBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfServiceCPWProjectsBrowse'
		DROP PROCEDURE [dbo].adfServiceCPWProjectsBrowse
	END
GO

PRINT 'Creating procedure adfServiceCPWProjectsBrowse'
GO

/******************************************************************************
**		File: adfServiceCPWProjectsBrowse.sql
**		Name: adfServiceCPWProjectsBrowse
**		Desc:         ""
**				   
**		Author: Maria Bastrakova
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		26.11.12	SAP				        
*******************************************************************************/
CREATE PROCEDURE [dbo].[adfServiceCPWProjectsBrowse]
	@CostCentersXML				XML,
	@ProjectManagerXML			XML,
	@CustomerXML				XML,
	@ProjectCategoriesXML		XML,
	@CurrencyCode				NCHAR(4),
	@WithEmptyCostCenter		INT,
	@WithEmptyManager			INT,
	@WithEmptyCustomer			INT,
	@WithEmptyProjectCategories	INT
		
AS
	SET NOCOUNT ON
			
	SELECT
		[Project].[ID],
		[Project].[Number],
		[Project].[FileAs],
		[ServiceAssignment].[ID] AS [AssignmentID],
		[ServiceAssignment].[Price] AS [CurrentPrice],
		[ServiceAssignment].[FileAs] AS [ServiceName],
		[ServiceAssignment].[ServiceID],
		[Service].[Code] AS [ServiceCode]
	FROM
		[Project] 
		INNER JOIN [ServiceAssignment] 
			ON ([Project].[ID] = [ServiceAssignment].[ProjectID])
		LEFT OUTER JOIN [DocumentCategory]
			ON ([Project].[Class] = [DocumentCategory].[DocumentClass] AND [Project].[ID] = [DocumentCategory].[DocumentID])
		LEFT JOIN [Service]
			ON [Service].[ID] = [ServiceAssignment].[ServiceID]
			
	WHERE
	([Project].[CostCenterID] IN (SELECT T.c.value('ID[1]', 'int')
								  FROM @CostCentersXML.nodes('/CostCenters/CostCenter') T(c)) 
								   OR 
	(@WithEmptyCostCenter = 1 AND 
		(([Project].[CostCenterID] IS NULL) OR
		  [Project].[CostCenterID] IN (SELECT T.c.value('ID[1]', 'int')
								  FROM @CostCentersXML.nodes('/CostCenters/CostCenter') T(c)))))

	AND 
	
	([Project].[ProjectManagerEmployeeID] IN (SELECT T.c.value('ID[1]', 'int')
											  FROM @ProjectManagerXML.nodes('/Managers/Manager') T(c)) 
											 OR 
	(@WithEmptyManager = 1 AND (([Project].[ProjectManagerEmployeeID]  IS NULL) 
								OR 
		[Project].[ProjectManagerEmployeeID] IN (SELECT T.c.value('ID[1]', 'int')
											     FROM @ProjectManagerXML.nodes('/Managers/Manager') T(c)))))
	AND 
	
	([Project].[CustomerCompanyID] IN (SELECT T.c.value('ID[1]', 'int')
										FROM @CustomerXML.nodes('/Customers/Customer') T(c))
										OR 
	(@WithEmptyCustomer = 1 AND (([Project].[CustomerCompanyID] IS NULL) OR 
		[Project].[CustomerCompanyID] IN (SELECT T.c.value('ID[1]', 'int')
										  FROM @CustomerXML.nodes('/Customers/Customer') T(c)))))
	AND

	([DocumentCategory].[CategoryID] IN (SELECT T.c.value('ID[1]', 'int')
											     FROM @ProjectCategoriesXML.nodes('/ProjectCategories/ProjectCategory') T(c)) 
											     OR 
	(@WithEmptyProjectCategories = 1 AND (([DocumentCategory].[CategoryID] IS NULL) OR 
		[DocumentCategory].[CategoryID] IN (SELECT T.c.value('ID[1]', 'int')
											     FROM @ProjectCategoriesXML.nodes('/ProjectCategories/ProjectCategory') T(c)))))

	AND
	(((@CurrencyCode <> 'NULL') AND ([Project].[CurrencyCode] = @CurrencyCode)) OR (@CurrencyCode = 'NULL'))
	AND ([Project].[State] = 2) AND ([ServiceAssignment].[State] = 1)
		
	IF @@ERROR != 0
	BEGIN
		RETURN 1
	END

	RETURN 0
GO

GRANT EXECUTE ON [adfServiceCPWProjectsBrowse] TO PUBLIC
GO
 
