IF  NOT EXISTS (SELECT * FROM systypes WHERE name = N'TBitMask')
	/*==============================================================*/
	/* Domain: TBitMask                                             */
	/*==============================================================*/
	EXEC sp_addtype TBitMask, 'int' , 'not null'
go 

IF NOT EXISTS (
	SELECT * 
	FROM
		sys.all_objects o
		inner join sys.key_constraints r
			on o.object_id = r.parent_object_id
	where
		SCHEMA_NAME(o.schema_id) = 'dbo' AND 
		o.name LIKE 'EntryAmount'
)
BEGIN
	ALTER TABLE [EntryAmount] ADD CONSTRAINT EntryAmountPK PRIMARY KEY ([ID])
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'PublicationTime' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Announcement')
BEGIN
	EXEC sp_executesql N'ALTER TABLE [Announcement] ADD [PublicationTime] TDateTime null'
	EXEC sp_executesql N'
	ALTER TABLE [Announcement] DISABLE TRIGGER ALL
	UPDATE [Announcement] SET [PublicationTime] = [Created]
	ALTER TABLE [Announcement] ENABLE TRIGGER ALL'
	EXEC sp_executesql N'ALTER TABLE [Announcement] ALTER COLUMN [PublicationTime] TDateTime not null'
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'Attendee') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	/*==============================================================*/
	/* Table: Attendee                                              */
	/*==============================================================*/
	create table Attendee (
	   MeetingRequestID     TIdentifier          not null,
	   EmployeeID           TIdentifier          not null,
	   Required             TBool                not null default 1,
	   Present              TBool                not null default 0,
	   ResponseType         TCode                null,
	   constraint AttendeePK primary key  (MeetingRequestID, EmployeeID)
	)
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'AttendeeResponse') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	/*==============================================================*/
	/* Table: AttendeeResponse                                      */
	/*==============================================================*/
	create table AttendeeResponse (
	   MeetingRequestID     TIdentifier          not null,
	   EmployeeID           TIdentifier          not null,
	   ID                   TIdentifier          identity,
	   ResponseType         TCode                not null,
	   FileAs               TName                not null,
	   Comments             TNotes               null,
	   Created              TSysDateTime         not null,
	   constraint AttendeeResponsePK primary key  (MeetingRequestID, EmployeeID, ID)
	)
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'CalendarResource') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	/*==============================================================*/
	/* Table: CalendarResource                                      */
	/*==============================================================*/
	create table CalendarResource (
	   UserID               TIdentifier          not null,
	   ResourceID           TIdentifier          not null,
	   constraint CalendarResourcePK primary key  (UserID, ResourceID)
	)
END

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'EndDate' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Issue')
BEGIN
	EXECUTE sp_rename N'dbo.Issue.EndDate', N'EndTime', 'COLUMN' 
	ALTER TABLE [Issue] ALTER COLUMN [EndTime] TDateTime NULL
END
GO
IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'StartTime' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Issue')
	ALTER TABLE [Issue] ADD [StartTime] TDateTime NULL
GO
IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Duration' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Issue')
	ALTER TABLE [Issue] ADD [Duration] TCount NOT NULL DEFAULT 0
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'MeetingRequest') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	/*==============================================================*/
	/* Table: MeetingRequest                                        */
	/*==============================================================*/
	create table MeetingRequest (
	   Class                TClass               not null,
	   ID                   TIdentifier          identity,
	   State                TState               not null,
	   Flag                 TFlag                not null,
	   FileAs               TName                not null,
	   ProjectID            TIdentifier          null,
	   OriginatorEmployeeID TIdentifier          not null,
	   ActivityTypeID       TIdentifier          null,
	   PriorityID           TIdentifier          not null,
	   StartTime            TDateTime            not null,
	   Duration             TCount               not null,
	   Location             TName                null,
	   Color                TColor               null,
	   Comments             TNotes               null,
	   Created              TSysDateTime         not null default GETDATE(),
	   CreatedBy            TUserID              not null,
	   Modified             TSysDateTime         not null default GETDATE(),
	   ModifiedBy           TUserID              not null,
	   Timestamp            timestamp            not null,
	   constraint MeetingRequestPK primary key  (ID)
	)
	/*==============================================================*/
	/* Table: MeetingResource                                       */
	/*==============================================================*/
	create table MeetingResource (
	   MeetingRequestID     TIdentifier          not null,
	   ResourceID           TIdentifier          not null,
	   Required             TBool                not null default 1,
	   constraint MeetingResourcePK primary key  (MeetingRequestID, ResourceID)
	)
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'FactureCurrency' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [FactureCurrency] TIdentifier NOT NULL DEFAULT 0
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Scale' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	ALTER TABLE [Project] ADD [Scale] TCount NOT NULL DEFAULT 2
GO


IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'Resource') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	/*==============================================================*/
	/* Table: Resource                                              */
	/*==============================================================*/
	create table Resource (
	   Class                TClass               not null,
	   ID                   TIdentifier          identity,
	   State                TState               not null,
	   Flag                 TFlag                not null,
	   Code                 TCode                not null,
	   FileAs               TName                not null,
	   ResourceTypeID       TIdentifier          not null,
	   ResponsibleEmployeeID TIdentifier          null,
	   AutoSubmit           TBool                not null default 1,
	   Comments             TNotes               null,
	   Created              TSysDateTime         not null default GETDATE(),
	   CreatedBy            TUserID              not null,
	   Modified             TSysDateTime         not null default GETDATE(),
	   ModifiedBy           TUserID              not null,
	   Timestamp            timestamp            not null,
	   constraint ResourcePK primary key  (ID)
	)

	/*==============================================================*/
	/* Table: ResourceAvailability                                  */
	/*==============================================================*/
	create table ResourceAvailability (
	   ResourceID           TIdentifier          not null,
	   ID                   TIdentifier          identity,
	   AvailableFrom        TDate                not null,
	   AvailableTo          TDate                null,
	   constraint ResourceAvailabilityPK primary key  (ResourceID, ID)
	)

	/*==============================================================*/
	/* Table: ResourceRequest                                       */
	/*==============================================================*/
	create table ResourceRequest (
	   Class                TClass               not null,
	   ID                   TIdentifier          identity,
	   State                TState               not null,
	   Flag                 TFlag                not null,
	   FileAs               TName                not null,
	   StartTime            TDateTime            not null,
	   Duration             TCount               not null,
	   ProjectID            TIdentifier          null,
	   EmployeeID           TIdentifier          not null,
	   ResourceID           TIdentifier          not null,
	   PriorityID           TIdentifier          not null,
	   Color                TColor               null,
	   MeetingRequestID     TIdentifier          null,
	   Comments             TNotes               null,
	   Created              TSysDateTime         not null default GETDATE(),
	   CreatedBy            TUserID              not null,
	   Modified             TSysDateTime         not null default GETDATE(),
	   ModifiedBy           TUserID              not null,
	   Timestamp            timestamp            not null,
	   constraint ResourceRequestPK primary key  (ID)
	)

	
	/*==============================================================*/
	/* Table: ResourceType                                          */
	/*==============================================================*/
	create table ResourceType (
		Class                TClass               not null,
		ID                   TIdentifier          identity,
		State                TState               not null,
		Flag                 TFlag                not null,
		FileAs               TName                not null,
		Comments             TNotes               null,
		Created              TSysDateTime         not null default GETDATE(),
		CreatedBy            TUserID              not null,
		Modified             TSysDateTime         not null default GETDATE(),
		ModifiedBy           TUserID              not null,
		Timestamp            timestamp            not null,
		constraint ResourceTypePK primary key  (ID)
	)	
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'MeetingRequestID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='TimeEntry')
	ALTER TABLE [TimeEntry] ADD [MeetingRequestID] TIdentifier NULL
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'WEBLogin' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='User')
BEGIN
	ALTER TABLE [User] ADD [WEBLogin] TSysname NULL
	ALTER TABLE [User] ADD [WEBPassword] TSysname NULL
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'UserWebConfiguration') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
	/*==============================================================*/
	/* Table: UserWebConfiguration                                  */
	/*==============================================================*/
	create table UserWebConfiguration (
	   ID                   TIdentifier          not null,
	   Value                XML                  not null,
	   constraint UserWebConfigurationPK primary key  (ID)
	)
go

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'FolderID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
	EXEC sp_executesql N'ALTER TABLE [Project] ADD [FolderID] TIdentifier null'
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'IsGroup' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Role')
	EXEC sp_executesql N'ALTER TABLE [Role] ADD [IsGroup] TBool not null default 0'
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'ApplicationSettings' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='User')
	EXEC sp_executesql N'ALTER TABLE [User] ADD ApplicationSettings  XML null'
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'ContactExternalLink') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	drop table ContactExternalLink;
END
GO

IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'ExternalLink') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
	/*==============================================================*/
	/* Table: ExternalLink                                          */
	/*==============================================================*/
	create table ExternalLink (
	   DeviceID             varchar(40)          not null,
	   ItemID               TCode                not null,
	   DocumentClass        TClass               not null,
	   DocumentID           TIdentifier          not null,
	   constraint ExternalLinkPK primary key  (DeviceID, ItemID),
	   constraint ContactExternalLinkAK unique (DeviceID, DocumentClass, DocumentID)
	)
END
GO

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'BudgetOverrun' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @DefaultName sysname, @sql nvarchar(max)
	SELECT @DefaultName = cstr.name
	FROM 
		sys.tables AS tbl
		INNER JOIN sys.all_columns AS clmns ON clmns.object_id=tbl.object_id
		INNER JOIN sys.default_constraints AS cstr ON cstr.object_id=clmns.default_object_id
	WHERE
		(tbl.name=N'Project' and SCHEMA_NAME(tbl.schema_id)=N'dbo') AND clmns.name = 'BudgetOverrun'
	IF @DefaultName IS NOT NULL
	BEGIN
		SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT '+ @DefaultName
		EXEC sp_executesql @sql
	END
	EXEC sp_executesql N'ALTER TABLE [Project] DROP COLUMN [BudgetOverrun]'
END
GO

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'TaskDelay' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @DefaultName sysname, @sql nvarchar(max)
	SELECT @DefaultName = cstr.name
	FROM
		sys.tables AS tbl
		INNER JOIN sys.all_columns AS clmns ON clmns.object_id=tbl.object_id
		INNER JOIN sys.default_constraints AS cstr ON cstr.object_id=clmns.default_object_id
	WHERE
		(tbl.name=N'Project' and SCHEMA_NAME(tbl.schema_id)=N'dbo') AND clmns.name = 'TaskDelay'
	IF @DefaultName IS NOT NULL
	BEGIN
		SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT '+ @DefaultName
		EXEC sp_executesql @sql
	END
	EXEC sp_executesql N'ALTER TABLE [Project] DROP COLUMN [TaskDelay]'
END
GO

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'PaymentDelay' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @DefaultName sysname, @sql nvarchar(max)
	SELECT @DefaultName = cstr.name
	FROM
		sys.tables AS tbl
		INNER JOIN sys.all_columns AS clmns ON clmns.object_id=tbl.object_id
		INNER JOIN sys.default_constraints AS cstr ON cstr.object_id=clmns.default_object_id
	WHERE
		(tbl.name=N'Project' and SCHEMA_NAME(tbl.schema_id)=N'dbo') AND clmns.name = 'PaymentDelay'
	IF @DefaultName IS NOT NULL
	BEGIN
		SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT '+ @DefaultName
		EXEC sp_executesql @sql
	END
	EXEC sp_executesql N'ALTER TABLE [Project] DROP COLUMN [PaymentDelay]'
END
GO

IF EXISTS (SELECT * FROM syscolumns WHERE [name] = 'PaymentDelayWorkDays' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	DECLARE @DefaultName sysname, @sql nvarchar(max)
	SELECT @DefaultName = cstr.name
	FROM
		sys.tables AS tbl
		INNER JOIN sys.all_columns AS clmns ON clmns.object_id=tbl.object_id
		INNER JOIN sys.default_constraints AS cstr ON cstr.object_id=clmns.default_object_id
	WHERE
		(tbl.name=N'Project' and SCHEMA_NAME(tbl.schema_id)=N'dbo') AND clmns.name = 'PaymentDelayWorkDays'
	IF @DefaultName IS NOT NULL
	BEGIN
		SET @sql = N'ALTER TABLE [Project] DROP CONSTRAINT '+ @DefaultName
		EXEC sp_executesql @sql
	END
	EXEC sp_executesql N'ALTER TABLE [Project] DROP COLUMN [PaymentDelayWorkDays]'
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'InvoiceExpirationPeriodType' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Project')
BEGIN
	EXEC adfParameterSet 'InvoiceExpirationPeriodType', 'Pjm5', 1
	EXEC sp_executesql N'ALTER TABLE [Project] ADD [InvoiceExpirationPeriodType]  TIdentifier not null default 1'
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'InvoiceExpirationPeriodType' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Invoice')
	EXEC sp_executesql N'ALTER TABLE [Invoice] ADD [InvoiceExpirationPeriodType]  TIdentifier not null default 1'
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'DivisionID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='TimeEntry')
	EXEC sp_executesql N'ALTER TABLE [TimeEntry] ADD [DivisionID]  TIdentifier null'
GO
IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'DivisionID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='Expense')
	EXEC sp_executesql N'ALTER TABLE [Expense] ADD [DivisionID]  TIdentifier null'
GO
IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'DivisionID' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ServiceRequest')
	EXEC sp_executesql N'ALTER TABLE [ServiceRequest] ADD [DivisionID]  TIdentifier null'
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Actively' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectActivityType')
	ALTER TABLE [ProjectActivityType] ADD Actively TBool NULL;
GO	

IF EXISTS (SELECT * FROM [ProjectActivityType] WHERE [Actively] IS NULL)
BEGIN
	UPDATE [ProjectActivityType] SET [Actively] = 1
	
	ALTER TABLE [ProjectActivityType] ALTER COLUMN Actively TBool NOT NULL; 	
END
GO

IF NOT EXISTS (SELECT * FROM syscolumns WHERE [name] = 'Actively' AND OBJECTPROPERTY(id, N'IsUserTable') = 1 AND OBJECT_NAME(id)='ProjectExpenseCode')
	ALTER TABLE [ProjectExpenseCode] ADD Actively TBool NULL;
GO	

IF EXISTS (SELECT * FROM [ProjectExpenseCode] WHERE [Actively] IS NULL)
BEGIN
	UPDATE [ProjectExpenseCode] SET [Actively] = 1
	
	ALTER TABLE [ProjectExpenseCode] ALTER COLUMN Actively TBool NOT NULL; 	
END
GO

-----END OF SCRIPT