﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[ContactCreate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure ContactCreate'
	drop procedure [exch].[ContactCreate]
end
go

print 'Creating procedure ContactCreate'
go

create procedure [exch].[ContactCreate] @UserID TIdentifier, @XContact xml with execute as 'pjmexchangesync'
as
begin	
	declare @Class TClass, @ContactSyncMode int, @LocalSyncMode int, @ReminderID TIdentifier, @ID TIdentifier, @result int
	
	set nocount on;

	set @Class = dbo.adfGetClassByName('Adf.Employee');

	declare	@FirstName TName, @MiddleName TName, @LastName TName, @FullName TName,
			@BirthDate TDate, @EventTime TDate, @NextInterval int, @Gender int, @Company TName, @Position TName, @UserName TName, @Comments TNotes,
			@Title TCode, @Suffix TCode, @Initials TCode, @Division TName, @Picture varbinary(max);
	
	select
		@FirstName = T.C.value('@FirstName', 'TName'),
		@MiddleName = T.C.value('@MiddleName', 'TName'),
		@LastName = T.C.value('@LastName', 'TName'),
		@FullName = T.C.value('@FileAs', 'TName'),
		@BirthDate = T.C.value('@BirthDate', 'TDate'),
		@EventTime = CAST(T.C.value('(Reminder/@EventTime)[1]', 'TDateTime') as datetime),
		@NextInterval = T.C.value('(Reminder/@NextInterval)[1]', 'int'),
		@Gender = T.C.value('(ExtendedProperties/Gender)[1]', 'int'),
		@Picture = T.C.value('(ExtendedProperties/Picture)[1]', 'varbinary(max)'),
		@Company = T.C.value('@Company', 'TName'),
		@Position = T.C.value('@Position', 'TName'),
		@Comments = T.C.value('@Comments', 'TNotes'),
		@Title = T.C.value('@Title', 'TCode'),
		@Suffix = T.C.value('@Suffix', 'TCode'),
		@Initials = T.C.value('@Initials', 'TCode'),
		@Division = T.C.value('@Division', 'TName')
	from
		@XContact.nodes('Contact') T(C)	

	-- сотрудников собственной компании не создаем и не обновляем
	if exists(SELECT * FROM [Company] WHERE ([FileAs] = @Company or [LegalName] = @Company) AND [Own] = 1)
	begin
		select cast(N'<Contact />' as xml);
		return 2;
	end;

	if @FullName is null
	begin
		set @FullName = @FirstName;
		if @FullName is null
			set @FullName = @LastName;
		else
			set @FullName = @FullName + ' ' + @LastName;
	end

	if @FullName is null
	begin
		set @FullName = 'Синхронизация с Microsoft Exchange'
	end

	declare @CompanyID TIdentifier, @PositionID TIdentifier, @DivisionID TIdentifier;

	begin transaction;

	exec @result = [exch].[PositionGetOrCreate] @Position, @UserID, @PositionID output;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[CompanyGetOrCreate] @Company, @UserID, @CompanyID output;

	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	if @CompanyID is not null
	begin
		exec @result = [exch].[DivisionGetOrCreate] @Division, @UserID, @CompanyID, @DivisionID output;
		if @result = 1 or @@error != 0
		begin
			rollback transaction;
			return 1;
		end
	end

	insert into [Employee]
		([State], [FileAs], [FirstName], [MiddleName], [LastName], [BirthDate], [CompanyID], [PositionID], [Comments], [Title], [Suffix], [Initials], [DivisionID])
	values
		(1, @FullName, @FirstName, @MiddleName, @LastName, @BirthDate, @CompanyID, @PositionID, @Comments, @Title, @Suffix, @Initials, @DivisionID);
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	set @ID = scope_identity();

	insert into [BusinessCard] 
		([ID], [Class], [State], [FileAs], [Flag])
	values 
		(@ID, @Class, 1, @FullName, 0)
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec [exch].[ReminderUpdate] @UserID, @Class, @ID, @EventTime, @NextInterval;
	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	declare @ExtendedProperties xml;

	set @ExtendedProperties = N'<ExtendedProperties><Values><Gender>0</Gender></Values></ExtendedProperties>';

	set	@ExtendedProperties.modify('replace value of (/ExtendedProperties/Values/Gender[1]/text())[1] with sql:variable("@Gender")')
	
	if @Picture is not null
		set @ExtendedProperties.modify('insert <Picture>{sql:variable("@Picture")}</Picture> into (/ExtendedProperties/Values)[1]');

	insert into [ExtendedProperties] 
		([ID], [Class], [ExtendedProperties])
	values
		(@ID, @Class, @ExtendedProperties);
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[UpdatePhone] @XContact, @Class, @ID;
	if @result != 0 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[UpdateEmail] @XContact, @Class, @ID;
	if @result != 0 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec @result = [exch].[UpdateAddress] @XContact, @Class, @ID;
	if @result != 0 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	insert into [dbo].[ExchangeDocumentSync]
		([DocumentClass], [DocumentID], [UserID])
	values
		(@Class, @ID, @UserID);
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	insert into [UserContact] 
		([BusinessCardClass], [BusinessCardID], [UserID])
	values
		(@Class, @ID, @UserID);
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	commit transaction;

	exec [exch].[ContactGet] @UserID, @ID;

	return 0;
end	
go


grant execute on [exch].[ContactCreate] to [projectmateservice];
go
