﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[ExchangeLinkCreate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure ExchangeLinkCreate'
	drop procedure [exch].[ExchangeLinkCreate]
end
go

print 'Creating procedure ExchangeLinkCreate'
go

create procedure [exch].[ExchangeLinkCreate] @UserID TIdentifier, @Class TName, @DocumentID TIdentifier, @ExchangeID varchar(max), @Data xml, @SyncTime TDateTime
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare @DocumentClass TClass, @EmployeeClass TClass, @RowVersion bigint;

	set @DocumentClass = dbo.adfGetClassByName(@Class);
	set @EmployeeClass = dbo.adfGetClassByName('Adf.Employee');
	select @RowVersion = @Data.value('(//@RowVersion)[1]', 'bigint')

	begin transaction

	insert into [exch].[ExchangeLink]
		([UserID], [DocumentClass], [DocumentID], [ExchangeID], [Data], [SyncTime], [RowVersion])
	values
		(@UserID, @DocumentClass, @DocumentID, @ExchangeID, @Data, @SyncTime, @RowVersion);
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	if not exists(select * from [dbo].[ExchangeDocumentSync] where [UserID] = @UserID and [DocumentClass] = @DocumentClass and [DocumentID] = @DocumentID)
	begin
		insert into [dbo].[ExchangeDocumentSync] 
			([DocumentClass], [DocumentID], [UserID])
		values
			(@DocumentClass, @DocumentID, @UserID);
		if @@error != 0
		begin
			rollback transaction;
			return 1;
		end
	end

	if @DocumentClass = @EmployeeClass
	begin
		if not exists(select * from [UserContact] where [UserID] = @UserID and [BusinessCardClass] = @DocumentClass and [BusinessCardID] = @DocumentID)
		begin
			insert into [dbo].[UserContact] 
				([BusinessCardClass], [BusinessCardID], [UserID])
			values
				(@DocumentClass, @DocumentID, @UserID);
			if @@error != 0
			begin
				rollback transaction;
				return 1;
			end
		end
	end
	
	commit transaction;

	return 0;
end

go


grant execute on [exch].[ExchangeLinkCreate] to [projectmateservice];
go
