﻿if exists (select * from dbo.sysobjects where id = object_id(N'[exch].[TimeEntryUpdate]') and objectproperty(id, N'IsProcedure') = 1)
begin
	print 'Dropping procedure TimeEntryUpdate'
	drop procedure [exch].[TimeEntryUpdate]
end
go

print 'Creating procedure TimeEntryUpdate'
go

create procedure [exch].[TimeEntryUpdate] @UserID TIdentifier, @XData xml
with execute as 'pjmexchangesync'
as
begin
	set nocount on;

	declare	@FileAs TName, @Start TDateTime, @End TDateTime, @Comments TNotes, @EventTime TDateTime, @NextInterval int, @EmployeeID TIdentifier, @DivisionID TIdentifier, @TimeEntryClass TClass,
			@TimeEntryID TIdentifier, @result int;
	
	set @TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')

	select
		@TimeEntryID = T.C.value('@ID', 'TIdentifier'),
		@FileAs = T.C.value('@FileAs', 'TName'),
		@Start = T.C.value('@Start', 'TDateTime'),
		@End = T.C.value('@End', 'TDateTime'),
		@Comments = T.C.value('@Comments', 'TNotes'),
		@EventTime = T.C.value('(Reminder/@EventTime)[1]', 'TDateTime'),
		@NextInterval = T.C.value('(Reminder/@NextInterval)[1]', 'int')
	from
		@XData.nodes('TimeEntry') T(C);

	if @FileAs is null
		set @FileAs = '(без темы)';

	--Параметры округления длительности записи

	declare @RoundInterval int, @RoundingMode int, @var TVariant, @RoundedDuration TCount, @Duration TCount, @State TState, @NewState TState;

	set @Duration = datediff(minute, @Start, @End);

	exec adfParameterGet @Name='RoundInterval', @Group='Pjm5', @Value = @var output
	set @RoundInterval = CAST(@var as int)

	exec adfParameterGet @Name='RoundingMode', @Group='Pjm5', @Value = @var output
	set @RoundingMode = CAST(@var as int)

	set @RoundedDuration = dbo.fnPjm5RoundedDuration(@Duration, @RoundInterval, @RoundingMode);

	select @State = [State] from [TimeEntry] where [ID] = @TimeEntryID;

	if @State is null
	begin
		select cast(N'<TimeEntry />' as xml);
		return 2;
	end

	if @State <> 1 and @State <> 5 and @State <> 2
	begin
		select cast(N'<TimeEntry />' as xml);
		return 3;
	end
	else
	begin
		if @State = 1 and @State = 5
			set @NewState = 1;
		else
			set @NewState = @State;
	end

	begin transaction;

	update [TimeEntry]
	set
		[FileAs] = @FileAs,
		[State] = @NewState,
		[StartTime] = @Start,
		[Duration] = @Duration,
		[RoundedDuration] = @RoundedDuration,
		[Comments] = @Comments,
		[Modified] = DEFAULT,
		[ModifiedBy] = DEFAULT
	where
		[ID] = @TimeEntryID;
			
	if @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	exec [exch].[ReminderUpdate] @UserID, @TimeEntryClass, @TimeEntryID, @EventTime, @NextInterval;

	if @result = 1 or @@error != 0
	begin
		rollback transaction;
		return 1;
	end

	commit transaction;

	exec [exch].[TimeEntryGet] @UserID, @TimeEntryID;

	return 0;
end

go


grant execute on [exch].[TimeEntryUpdate] to [projectmateservice];
go
