IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnPjm6GetAvailableProjectsForTimeEntryApproveBrowse]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnPjm6GetAvailableProjectsForTimeEntryApproveBrowse'
		DROP FUNCTION [dbo].[fnPjm6GetAvailableProjectsForTimeEntryApproveBrowse]
	END

GO

PRINT 'Creating function fnPjm6GetAvailableProjectsForTimeEntryApproveBrowse'
GO
/******************************************************************************
**		File:	fnPjm6GetAvailableProjectForTimeEntryBrowse.sql
**		Name: 	fnPjm6GetAvailableProjectForTimeEntryBrowse
**		Desc:	Процедура возвращает список доступных для броузинга времени проектов
**				с указанием того, в каких проектах сотрудник может видеть деньги 
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	11.03.09	SSA			Первая версия
**    	06.04.09	ENB			View земенены на прямой доступ к таблицам
**		15.06.10	KOV			Расставлены скобочки
**		14.10.11	PAM			Добавлена выгрузка компании заказчика
**		03.04.13	SOV			Возможность просматривать финансы имеет фин. рук-ля проекта
**								или участник с установленной галкой "Управление финансами"
**		13.05.13	SOV			Добавлена выборка проектов для пом. рук-ля
**		06.09.13	SOV			Апрувер и пом. рук-ля больше не видят фин-сы;
**								добавлена выборка признака, является ли сотрудник апрувером в проекте
*******************************************************************************/
CREATE FUNCTION [dbo].[fnPjm6GetAvailableProjectsForTimeEntryApproveBrowse] (
	@ProjectSelector	int,
	@ActiveProjectID	TIdentifier
)

RETURNS @Projects TABLE ([ID] INT PRIMARY KEY, [CustomerCompanyID] TIdentifier, [ViewFinance] INT NOT NULL DEFAULT 0,
	[ViewBillableHour] bit DEFAULT 0) --Дополнительно смотрим права на просмотр времени к оплате для тех, 
									  -- у кого нет прав на просмотр финансов

AS 
BEGIN
	
	DECLARE 
		@ViewAllFinance TBool,
		@ViewFinance TBool,
		@CanBeManagerAssistant TBool,
		@CurrentEmployeeID TIdentifier,
		@ViewAllProjects TBool,
		@IsManager TBool,
		@Assistant TBool

	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @CanBeManagerAssistant = dbo.adfHasAccessRight(dbo.adfGetRightID('CanBeProjectManagerAssistant'))
	SET	@CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @Assistant = dbo.adfHasAccessRight(dbo.adfGetRightID ('Assistant'))
	SET @IsManager = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject'))

-- Вижу все проекты
	IF @ViewAllProjects = 1 AND @Assistant = 1
	
		INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID])
		SELECT
			[Project].[ID], 0, [Project].[CustomerCompanyID]
		FROM
			[Project]
		WHERE
			(@ProjectSelector = 0 AND
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID) 
				OR
			(@ProjectSelector = 1 AND
			[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID) 
				OR
			(@ProjectSelector = 2) 
				OR
			(@ProjectSelector = 3 AND
				(
					(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
					(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
				)
			) 


	ELSE BEGIN 
	
	-- Добавляем проекты, где я активный участник
		INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID], [ViewBillableHour])
		SELECT [Project].[ID], 0, [Project].[CustomerCompanyID], 
			CASE WHEN [AP].[Administrator] = 1 OR [AP].[Approver] = 1 THEN 1
				ELSE 0  
			END
		FROM   [Project]
			INNER JOIN (	
				SELECT
					[Assignment].[ProjectID],
					[Assignment].[Approver],
					[Assignment].[Administrator]
				FROM
					[Assignment] 
				WHERE 	
					[Assignment].[ID] IN (
						SELECT [AssignmentEntry].[AssignmentID]
						FROM   [AssignmentEntry]
						WHERE  
							[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
					) AND
				   ([Assignment].[State] = 1)
				) AS AP
			ON [Project].[ID] = [AP].[ProjectID] 
			AND	
			((@ProjectSelector = 0 AND
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID) 
				OR
			(@ProjectSelector = 1 AND
			[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID) 
				OR
			(@ProjectSelector = 2) 
				OR
			(@ProjectSelector = 3 AND
				(
					(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
					(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
				)
			))

	--  Добавляем проекты, где я пом. рук-ля, но проверяем при этом права, 
	--  смотрим чтобы не добавлялись дубликаты
		IF @CanBeManagerAssistant = 1 BEGIN
			INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID], [ViewBillableHour])
			SELECT
				[Project].[ID], 0, [Project].[CustomerCompanyID], 1
			FROM
				[Project]
			WHERE
				(
					[Project].[ID] NOT IN (SELECT [ID] FROM @Projects)
				)	
					AND
				(
					[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID
				)
					AND	
				((@ProjectSelector = 0 AND
					[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID) 
						OR
					(@ProjectSelector = 1 AND
					[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID) 
						OR
					(@ProjectSelector = 2) 
						OR
					(@ProjectSelector = 3 AND
						(
							(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
							(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
						)
					) 
				)
		END

	--  Добавляем проекты, где я менеджер, но проверяем при этом права, 
	--  смотрим чтобы не добавлялись дубликаты
		IF @IsManager = 1 BEGIN
			INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID])
			SELECT
				[Project].[ID], 1, [Project].[CustomerCompanyID]
			FROM
				[Project]
			WHERE
				(
					[Project].[ID] NOT IN (SELECT [ID] FROM @Projects)
				)	
					AND
				(
					[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				)
					AND	
				((@ProjectSelector = 0 AND
					[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID) 
						OR
					(@ProjectSelector = 1 AND
					[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID) 
						OR
					(@ProjectSelector = 2) 
						OR
					(@ProjectSelector = 3 AND
						(
							(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
							(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
						)
					) 
				)
			END

		--  Добавляем проекты, где я фин. менеджер, но проверяем при этом права, 
		--  смотрим, чтобы не добавлялись дубликаты
		IF @ViewFinance = 1 BEGIN
			INSERT INTO @Projects ([ID], [ViewFinance], [CustomerCompanyID])
			SELECT
				[Project].[ID], 1, [Project].[CustomerCompanyID]
			FROM
				[Project]
			WHERE
				(
					[Project].[ID] NOT IN (SELECT [ID] FROM @Projects)
				)	
					AND
				(
					[Project].[FinanceManagerEmployeeID] = @CurrentEmployeeID
				)
					AND	
				((@ProjectSelector = 0 AND
					[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID) 
						OR
					(@ProjectSelector = 1 AND
					[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID) 
						OR
					(@ProjectSelector = 2) 
						OR
					(@ProjectSelector = 3 AND
						(
							(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
							(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
						)
					) 
				)
		END
	END
	
--	Теперь обновляем поле для просмотра финансов
	IF @ViewAllFinance = 1 
	
	-- Вижу все финансы
		UPDATE @Projects SET [ViewFinance] = 1
	
	ELSE BEGIN  

		-- Вижу не все финансы	
		-- Для начала там, где я менеджер, фин. мен-р 
		UPDATE @Projects SET [ViewFinance] = 1
		WHERE ID IN (
			SELECT	ID 
			FROM	[Project] 
			WHERE	
				([Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID AND @IsManager = 1) OR
				([Project].[FinanceManagerEmployeeID] = @CurrentEmployeeID AND @ViewFinance = 1)
		)

	-- Если есть право просмотра финансов по своим проектам
		IF dbo.adfHasAccessRight(dbo.adfGetRightID ('ViewFinance')) = 1 BEGIN
			UPDATE @Projects SET [ViewFinance] = 1
			WHERE ID IN (
				SELECT
					[Assignment].[ProjectID]
				FROM
					[Assignment] 
				WHERE 	
					[Assignment].[ID] IN (
						SELECT [AssignmentEntry].[AssignmentID]
						FROM   [AssignmentEntry]
						WHERE  
							[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
					) AND
					[Assignment].[FinanceManagement] = 1 AND
				   ([Assignment].[State] = 1)
				)
		END

		-- Вижу время к оплате	
		-- Для начала там, где я пом. рук-ля проекта
		IF ( @CanBeManagerAssistant = 1)
		BEGIN
			UPDATE @Projects SET [ViewBillableHour] = 1
			WHERE ID IN (
				SELECT
					[ID]
				FROM
					[Project] 
				WHERE
					[Project].[ManagerAssistantEmployeeID] = @CurrentEmployeeID)
		END

		-- Установка признака просмотра времени к оплате для апрувера и администратора
		UPDATE @Projects SET [ViewBillableHour] = 1
		WHERE ID IN (
			SELECT
				[Assignment].[ProjectID]
			FROM
				[Assignment] 
			WHERE 	
				[Assignment].[ID] IN (
					SELECT [AssignmentEntry].[AssignmentID]
					FROM   [AssignmentEntry]
					WHERE  
						[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID						
				) AND
				[Assignment].[State] = 1 AND ([Assignment].[Approver] = 1 OR [Assignment].[Administrator] = 1)
			)

	END
	
	RETURN

END
	
GO
