IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6GetAvailableProjectsForMemberOverdraft]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function pjm6GetAvailableProjectsForMemberOverdraft'
		DROP FUNCTION [dbo].[pjm6GetAvailableProjectsForMemberOverdraft]
	END

GO

PRINT 'Creating function pjm6GetAvailableProjectsForMemberOverdraft'
GO
/******************************************************************************
**		File:	pjm6GetAvailableProjectsForMemberOverdraft.sql
**		Name: 	pjm6GetAvailableProjectsForMemberOverdraft
**		Desc:	      
**               c  
**				  
**
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	30.03.09	ENB			 
**		13.07.11	SYV			   UseSubProjects
*******************************************************************************/
CREATE FUNCTION pjm6GetAvailableProjectsForMemberOverdraft (
)

RETURNS @Projects TABLE (
		[ID] INT PRIMARY KEY,	
		[RealManHour] TCount NULL, 
		[RealBudget]  TMoney NULL, 
		[EstimatedBudget]  TMoney NULL,
		[ViewFinance] INT NOT NULL DEFAULT 0,
		[ParentProjectID] INT
)

AS 

BEGIN

	DECLARE 
		@today	datetime, 
		@ViewFinance TBool,
     	@CurrentEmployeeID  TIdentifier
		--@UseSubProjects		TBool,
		--@value				TVariant

--   
	--EXEC adfParameterGet @Name='UseSubProjects', @Group='Pjm6', @Value = @value OUTPUT
	--SET @UseSubProjects = ISNULL(CAST(@value as bit), 0)
		
	SET @today = GETDATE()

--      ?
	SELECT 
		@CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance')) | 
	                   dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance')) 
	
	INSERT INTO @Projects ( 
		[ID], 
		[RealManHour], 
		[RealBudget], 
		[EstimatedBudget],
		[ViewFinance],
		[ParentProjectID]
	) 
	SELECT
		[Project].[ID],
		dbo.fnPjm6GetProjectManHour([Project].[ID]) / 60.0,
		dbo.fnPjm6GetProjectBudget([Project].[ID]),
		SUM(
			(ISNULL([BusyEntry].[Planned], 0) - ISNULL([BusyEntry].[OvertimeWork], 0)) * ISNULL([Assignment].[StandardRate], 0) +
			 ISNULL([BusyEntry].[OvertimeWork], 0) * COALESCE([Assignment].[OvertimeRate], [Assignment].[StandardRate], 0)
		) / 60.0,
--	 ,      
		@ViewFinance,
		[SubProjects].[ProjectID]
	FROM			
		[Project]
		LEFT OUTER JOIN fnpjm6GetSubprojectsForBrowse() AS [SubProjects]
			ON [SubProjects].[SubprojectID] = [Project].[ID]
		INNER JOIN (
			SELECT
				[Assignment].[ProjectID]
			FROM
				[Assignment] 
			WHERE 	
				[Assignment].[ID] IN (
					SELECT [AssignmentEntry].[AssignmentID]
					FROM   [AssignmentEntry]
					WHERE  
							[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID 
 				) AND
				[Assignment].[State] = 1
			) AS [Projects]
			ON [Project].[ID] = [Projects].[ProjectID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		INNER JOIN [Task]
			ON [Task].[ProjectID] = [Project].[ID] AND [Task].[State] IN (2, 3, 5)
		LEFT OUTER JOIN [BusyEntry]
			ON [BusyEntry].[TaskID] = [Task].[ID] AND [BusyEntry].[Date] <= @today
		LEFT OUTER JOIN [Assignment]
			ON [Assignment].[ID] = [BusyEntry].[AssignmentID]
	WHERE
		[Project].[State] = 2 AND
		ISNULL([ProjectDetail].[PlannedBudget], 0) > 0
	GROUP BY 
		[Project].[ID],
		[SubProjects].[ProjectID]
	HAVING
		dbo.fnPjm6GetProjectBudget([Project].[ID]) >
		SUM(
			(ISNULL([BusyEntry].[Planned], 0) - ISNULL([BusyEntry].[OvertimeWork], 0)) * ISNULL([Assignment].[StandardRate], 0) +
			 ISNULL([BusyEntry].[OvertimeWork], 0) * COALESCE([Assignment].[OvertimeRate], [Assignment].[StandardRate], 0)
		) / 60.0

--  ParentID  NULL   ,    
	--IF @UseSubProjects = 1
	UPDATE @Projects
	SET [ParentProjectID] = NULL
	WHERE
		[ParentProjectID] IS NOT NULL AND
		[ParentProjectID] NOT IN (SELECT [ID] FROM @Projects)

	RETURN

END
	
GO
