IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportGetAvailableProjects ]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportGetAvailableProjects '
		DROP FUNCTION [dbo].[fnReportGetAvailableProjects ]
	END
GO

PRINT 'Creating function fnReportGetAvailableProjects '
GO
/******************************************************************************
**		File: fnReportGetAvailableProjects .sql
**		Name: fnReportGetAvailableProjects 
**
**              
**		Return values:

**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		-- @RequiredFieldFlag
		-- 0   
		-- 1     
		-- 2        
		-- 3           
**		Auth: MAN
**		Date: 25/08/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		25.08.10	MAN				First Version
**		03.04.13	SOV				    . - 
**									     " "
*******************************************************************************/
CREATE FUNCTION dbo.fnReportGetAvailableProjects 
(
	@CompanyID			  Tidentifier,	--ID 
	@CostCenterID		  Tidentifier,	-- ID  
	@ProjectManagerID	  Tidentifier,	--ID  
	@ProjectID			  Tidentifier,	--ID 
	@PeriodStart		  TDateTime,	--   
	@PeriodEnd			  TDateTime,	--   
	@RequiredFieldFlag	  TIdentifier,	--    
	@ContractProject	  TFlag			--   . 0 , 1  
)
RETURNS @Result TABLE 
(
	[ProjectID]		Tidentifier,
	[ProjectNumber] TName,
	[ViewFinance]	TBool
)
AS
BEGIN
	
	DECLARE 
		@CurrentEmployeeID	TIdentifier,
		@ViewAllFinance		TBool,
		@ViewAllProjects	TBool,
		@HasManageProject	TBool,
		@ViewFinance		TBool
		
	--  ?
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	-- ,     
	SET	@ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
	-- ,     .
	SET	@ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	--  
	SET @HasManageProject = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject'))
	--  
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance')) 
	
	--   
	INSERT INTO @Result
	(
		[ProjectID],
		[ProjectNumber],
		[ViewFinance]
	)
		SELECT 
			[Project].[ID],
			[Project].[Number],
			CASE 
				WHEN ( @ViewAllFinance = 1 ) 
				THEN 1
				ELSE 0
			END 
		FROM
			[Project]
		WHERE
		( 
			--   
			[Project].[SupplierCompanyID] = @CompanyID 
			OR 
			@CompanyID IS NULL
		)
		AND
		( 
			--    
			[Project].[ProjectManagerEmployeeID] = @ProjectManagerID
			OR 
			@ProjectManagerID IS NULL
		)
		AND
		(
			--    
			ISNULL([Project].[CostCenterID],-2) = ISNULL(@CostCenterID,-2)
			OR  
			@CostCenterID = -1
		)
		AND
		( 
			--   
			[Project].[ID] = @ProjectID
			OR
			@ProjectID IS NULL
		)
		AND
		(
			@ContractProject = 0
			OR
			[Project].[ProjectTypeID] = 1
		)
		AND
		( 
			--    
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
			OR
			@ViewAllProjects = 1 --   
			OR
			@ViewAllFinance = 1 --    
		)
		AND
		(
			--   
			@RequiredFieldFlag = 0 
			OR
			EXISTS 
			(
				SELECT TOP 1
					[TimeEntry].[ID]
				FROM 
					[TimeEntry] 
				WHERE 
					[TimeEntry].[ProjectID]=[Project].[ID]
					AND
					[TimeEntry].[StartTime] >= @PeriodStart
					AND
					[TimeEntry].[StartTime] < @PeriodEnd
					AND
					(
						@RequiredFieldFlag = 0 
						OR
						(
							--     
							@RequiredFieldFlag = 1
							AND
							[TimeEntry].[State] in (1,2,3,5,6) --   4 ()
						)
						OR
						(
							--        
							@RequiredFieldFlag = 2
							AND
							[TimeEntry].[Billable] = 1 -- 
						)
						OR
						(
							--           
							@RequiredFieldFlag = 3
							AND
							[TimeEntry].[Billable] = 1 -- 
							AND
							[TimeEntry].[State] in ( 3,6 )
						)
					)
				)
			OR
			EXISTS 
			(
				SELECT TOP 1
					[Expense].[ID]
				FROM 
					[Expense] 
				WHERE 
					[Expense].[ProjectID]=[Project].[ID]
					AND
					[Expense].[Date] >= @PeriodStart
					AND
					[Expense].[Date] < @PeriodEnd
					AND
					(
						@RequiredFieldFlag = 0 
						OR
						(
							--     
							@RequiredFieldFlag = 1
							AND
							[Expense].[State] in (1,2,3,5,6) --   4 ()
						)
						OR
						(
							--        
							@RequiredFieldFlag = 2
							AND
							[Expense].[Billable] = 1 -- 
						)
						OR
						(
							--           
							@RequiredFieldFlag = 3
							AND
							[Expense].[Billable] = 1 -- 
							AND
							[Expense].[State] in ( 3,6 ) 
						)
					)
				)		
		)
	--    ViewFinance
	--      
	UPDATE 
		@Result 
	SET	
		[ViewFinance] = 1
	WHERE 
		[@Result].[ProjectID] IN 
		(
			SELECT 
				[Project].[ID]
			FROM 
				[Project]
			WHERE
				([Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID AND @HasManageProject = 1) OR
				dbo.fnPjm7IsFinanceManager([Project].[ID], @CurrentEmployeeID) = 1
		)
		--    ,    
	IF @ViewFinance = 1 
	BEGIN
		SELECT 
     		@CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()		
		UPDATE 
			@Result 
		SET	
			[ViewFinance] = 1
		WHERE 
			[@Result].[ProjectID] IN 
			(
				SELECT
					[Assignment].[ProjectID]
				FROM
					[Assignment] 
				WHERE 	
					[Assignment].[ID] IN 
					(
						SELECT 
							[AssignmentEntry].[AssignmentID]
						FROM   
							[AssignmentEntry]
						WHERE  
							[AssignmentEntry].[EmployeeID] = @CurrentEmployeeID
					) 
					AND
					[Assignment].[State] = 1 AND [Assignment].[FinanceManagement] = 1
			)
	END
RETURN
END
GO