IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportGetExpenseCostSum]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportGetExpenseCostSum'
		DROP FUNCTION [dbo].[fnReportGetExpenseCostSum]
	END
GO

PRINT 'Creating function fnReportGetExpenseCostSum'
GO

/******************************************************************************
**		File: fnReportGetExpenseCostSum.sql
**		Name: fnReportGetExpenseCostSum
**
**              
**		Return values: 
**		
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: MAN
**		Date: 23/08/2010 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		23.08.2010	MAN				First Version
*******************************************************************************/
CREATE FUNCTION dbo.fnReportGetExpenseCostSum 
(
	@PeriodStart		TDateTime,
	@PeriodEnd			TDateTime,
	@CurrencyCode		TCode3,
	@ProjectXML			XML
)
RETURNS @ResultTimeCostSum  TABLE 
(
	ProjectID					Tidentifier,
	ExpenseCostingBillable		TAmount,	--  :  
	ExpenseCostingRegistered	TAmount,	--  : 
	ExpenseCostingApproved		TAmount,	--  : 
	ExpenseRevenueSold			TAmount,	--  :  
	ExpenseRevenueApproved		TAmount,	--  : 
	ExpenseRevenueSigned		TAmount		--  : 
)
AS
BEGIN
	DECLARE
		@CalculationClass TClass,
		@StatementClass	  TClass,
		@InvoiceClass     TClass,
		@ExpenseClass     TClass,
		@ApprovedState    TState
		
	SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	SET	@StatementClass	  = dbo.adfGetClassByName('Pjm5.Statement')
	SET	@InvoiceClass	  = dbo.adfGetClassByName('Pjm5.Invoice')
	SET	@ExpenseClass	  = dbo.adfGetClassByName('Pjm5.Expense')
	
	DECLARE @CostingBillable	TABLE( ProjectID Tidentifier, ExpenseID TIdentifier, Value TAmount )
	DECLARE @CostingRegistered	TABLE( ProjectID Tidentifier, ExpenseID TIdentifier, Value TAmount )
	DECLARE @CostingApproved	TABLE( ProjectID Tidentifier, ExpenseID TIdentifier, Value TAmount )
	DECLARE @RevenueSold		TABLE( ProjectID Tidentifier, ExpenseID TIdentifier, Value TAmount )
	DECLARE @RevenueApproved	TABLE( ProjectID Tidentifier, ExpenseID TIdentifier, Value TAmount )
	DECLARE @RevenueSigned		TABLE( ProjectID Tidentifier, ExpenseID TIdentifier, Value TAmount )
	
	DECLARE @DocumentInFinance TABLE( [DocumentID] TIdentifier,[LinkClass] TClass,[State] TState,[Date] TDateTime,[ThroughCalculation] TFlag)
	INSERT INTO 
		@DocumentInFinance([DocumentID],[LinkClass],[State],[Date],[ThroughCalculation] )
	SELECT 
		[DocumentID],[LinkClass],[State],[Date],[ThroughCalculation]
	FROM 
		dbo.fnReportGetDocumentInFinance(@ExpenseClass,@PeriodStart, @PeriodEnd,@ProjectXML)

	INSERT INTO	@CostingBillable 
	(
		[ProjectID],
		[ExpenseID],
		[Value]
	)
	SELECT
		DISTINCT
		[Expense].[ProjectID],
		[Expense].[ID],
		SUM
		( 
			DISTINCT
			CASE 
				WHEN [Project].[ApplyVat] = 0
					THEN  [Expense].[TotalPC]
				ELSE
					[Expense].[TotalWithVATPC]						
			END	 *
			CASE [Expense].[State]
				WHEN 6 THEN 
					dbo.fnReportGetFinDocumentCurrency([Expense].[ToCurrencyCode],[Expense].[ID],@ExpenseClass,@CurrencyCode)
				ELSE
				dbo.pjm6fnCurrencyGetRate
				(
					[Expense].[ToCurrencyCode],
					[Expense].[Date],
					@CurrencyCode
				)
			END
		) 
	FROM
		[Expense]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
		Left Outer JOIN @DocumentInFinance
			ON [@DocumentInFinance].[DocumentID] = [Expense].[ID]
	WHERE
		[Expense].[Billable] = 1 --   
		AND
		[Expense].[State] IN (3, 6) -- , 
		AND
		[Expense].[Date] >= @PeriodStart
		AND
		[Expense].[Date] < @PeriodEnd
		AND
		[Expense].[ProjectID] IN 
		(	
			SELECT
				ROW.value('@ProjectID','TIdentifier') AS [ProjectID]
			FROM
				@ProjectXML.nodes('/row') AS ROW(ROW)
		)
	GROUP BY 
		[Expense].[ID],
		[Expense].[ProjectID]
		
	INSERT INTO	@CostingRegistered
	(
		[ProjectID],
		[ExpenseID],
		[Value]
	)
	SELECT
		[Expense].[ProjectID],
		[Expense].[ID],
		SUM
		( 
			DISTINCT
			CASE 
				WHEN [Project].[ApplyVat] = 0
					THEN  [Expense].[TotalPC]
				ELSE
					[Expense].[TotalWithVATPC]						
			END	 *
			dbo.fnReportGetFinDocumentCurrency([Expense].[ToCurrencyCode],[Expense].[ID],@ExpenseClass,@CurrencyCode)
		) 
	FROM
		[Expense]
		INNER JOIN @DocumentInFinance
			ON [Expense].[ID] = [@DocumentInFinance].[DocumentID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
	WHERE
		[@DocumentInFinance].[ThroughCalculation] = 0
		AND
		(
			(
				[@DocumentInFinance].[LinkClass] = @CalculationClass
				AND
				[@DocumentInFinance].[State] IN (1,2,3,5)
			)
			OR
			(
				[@DocumentInFinance].[LinkClass] = @StatementClass
				AND
				[@DocumentInFinance].[State] IN (1,2,3)
			) 
			OR
			(
				[@DocumentInFinance].[LinkClass] = @InvoiceClass
				AND
				[@DocumentInFinance].[State] IN (1,2,4,5,6,7)	
			)
		)
	GROUP BY 
		[Expense].[ID],
		[Expense].[ProjectID]

	INSERT INTO	@CostingApproved
	(
		[ProjectID],
		[ExpenseID],
		[Value]
	)
	SELECT
		[Expense].[ProjectID],
		[Expense].[ID],
		SUM
		(
			DISTINCT 
			CASE 
				WHEN [Project].[ApplyVat] = 0
					THEN  [Expense].[TotalPC]
				ELSE
					[Expense].[TotalWithVATPC]						
			END	 *
			dbo.fnReportGetFinDocumentCurrency([Expense].[ToCurrencyCode],[Expense].[ID],@ExpenseClass,@CurrencyCode)
		)
	FROM
		[Expense]
		INNER JOIN @DocumentInFinance
			ON [Expense].[ID] = [@DocumentInFinance].[DocumentID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
	WHERE
		(
			[@DocumentInFinance].[LinkClass] = @CalculationClass
			AND
			[@DocumentInFinance].[State] IN (2,3)
		)
		OR
		(
			[@DocumentInFinance].[ThroughCalculation] = 0
			AND 
			[@DocumentInFinance].[LinkClass] = @StatementClass
			AND
			[@DocumentInFinance].[State] IN (2,3)
		) 
		OR
		(	
			[@DocumentInFinance].[ThroughCalculation] = 0
			AND 
			[@DocumentInFinance].[LinkClass] = @InvoiceClass
			AND
			[@DocumentInFinance].[State] IN (2,5)	
		)
	GROUP BY 
		[Expense].[ID],
		[Expense].[ProjectID]

	INSERT INTO	@RevenueSold
	(
		[ProjectID],
		[ExpenseID],
		[Value]
	)
	SELECT
		DISTINCT
		[Expense].[ProjectID],
		[Expense].[ID],
		SUM
		( 
			DISTINCT
			CASE 
				WHEN [Project].[ApplyVat] = 0
					THEN  [Expense].[TotalPC]
				ELSE
					[Expense].[TotalWithVATPC]						
			END	 *
			dbo.fnReportGetFinDocumentCurrency([Expense].[ToCurrencyCode],[Expense].[ID],@ExpenseClass,@CurrencyCode)
		)
	FROM
		[Expense]
		INNER JOIN @DocumentInFinance
			ON [Expense].[ID] = [@DocumentInFinance].[DocumentID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
	WHERE 
		(
			[@DocumentInFinance].[LinkClass] = @StatementClass
			AND
			[@DocumentInFinance].[State] IN (1,2,3)
		) 
		OR
		(
			[@DocumentInFinance].[LinkClass] = @InvoiceClass
			AND
			[@DocumentInFinance].[State] IN (1,2,4,5,6,7)
		)	
	GROUP BY 
		[Expense].[ID],
		[Expense].[ProjectID]
			
	INSERT INTO	@RevenueApproved
	(
		[ProjectID],
		[ExpenseID],
		[Value]
	)
	SELECT
		DISTINCT
		[Expense].[ProjectID],
		[Expense].[ID],	
		SUM
		(
			DISTINCT
			CASE 
				WHEN [Project].[ApplyVat] = 0
					THEN  [Expense].[TotalPC]
				ELSE
					[Expense].[TotalWithVATPC]						
			END	 *
			dbo.fnReportGetFinDocumentCurrency([Expense].[ToCurrencyCode],[Expense].[ID],@ExpenseClass,@CurrencyCode)
		)
	FROM
		[Expense]
		INNER JOIN @DocumentInFinance
			ON [Expense].[ID] = [@DocumentInFinance].[DocumentID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
	WHERE
		(
			[@DocumentInFinance].[LinkClass] = @StatementClass
			AND
			[@DocumentInFinance].[State] IN (2,3)
		) 
		OR
		(
			[@DocumentInFinance].[LinkClass] = @InvoiceClass
			AND
			[@DocumentInFinance].[State] IN (2,5)	
		)
	GROUP BY 
		[Expense].[ID],
		[Expense].[ProjectID]
			
	INSERT INTO	@RevenueSigned
	(
		[ProjectID],
		[ExpenseID],
		[Value]
	)
	SELECT
		DISTINCT
		[Expense].[ProjectID],
		[Expense].[ID],	
		SUM
		( 
			DISTINCT
			CASE 
				WHEN [Project].[ApplyVat] = 0
					THEN  [Expense].[TotalPC]
				ELSE
					[Expense].[TotalWithVATPC]						
			END	
			*
			dbo.fnReportGetFinDocumentCurrency([Expense].[ToCurrencyCode],[Expense].[ID],@ExpenseClass,@CurrencyCode)
		)
	FROM
		[Expense]
		INNER JOIN @DocumentInFinance
			ON [Expense].[ID] = [@DocumentInFinance].[DocumentID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
	WHERE
		(
			[@DocumentInFinance].[LinkClass] = @StatementClass
			AND
			[@DocumentInFinance].[State] IN ( 3 )
		) 
		OR
		(
			[@DocumentInFinance].[LinkClass] = @InvoiceClass
			AND
			[@DocumentInFinance].[State] IN ( 5 )	
		)
	GROUP BY 
		[Expense].[ID],
		[Expense].[ProjectID]
			
	INSERT INTO @ResultTimeCostSum
	(
		ProjectID,
		ExpenseCostingBillable,	--  :  
		ExpenseCostingRegistered,	--  :  
		ExpenseCostingApproved,	--  : 
		ExpenseRevenueSold,		--  :  
		ExpenseRevenueApproved,		--  : 
		ExpenseRevenueSigned		--  : 
	)
	SELECT 
		[@CostingBillable].[ProjectID],
		SUM( [@CostingBillable].[Value] ),
		SUM( [@CostingRegistered].[Value] ),
		SUM( [@CostingApproved].[Value] ),
		SUM( [@RevenueSold].[Value] ),
		SUM( [@RevenueApproved].[Value] ),
		SUM( [@RevenueSigned].[Value] )
	FROM
		@CostingBillable
		LEFT OUTER JOIN @CostingRegistered
			ON [@CostingRegistered].[ExpenseID] = [@CostingBillable].[ExpenseID]
		LEFT OUTER JOIN @CostingApproved
			ON [@CostingApproved].[ExpenseID] = [@CostingBillable].[ExpenseID]
		LEFT OUTER JOIN @RevenueSold
			ON [@RevenueSold].[ExpenseID] = [@CostingBillable].[ExpenseID]
		LEFT OUTER JOIN @RevenueApproved
			ON [@RevenueApproved].[ExpenseID] = [@CostingBillable].[ExpenseID]
		LEFT OUTER JOIN @RevenueSigned
			ON [@RevenueSigned].[ExpenseID] = [@CostingBillable].[ExpenseID]
	GROUP BY
		[@CostingBillable].[ProjectID]
RETURN
END
GO