﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[fnReportTimeSellAnalysisByEmployeesGetPlannedValuesList]') AND xtype IN (N'FN', N'IF', N'TF'))
	BEGIN
		PRINT 'Dropping function fnReportTimeSellAnalysisByEmployeesGetPlannedValuesList'
		DROP FUNCTION [dbo].[fnReportTimeSellAnalysisByEmployeesGetPlannedValuesList]
	END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportTimeSellAnalysisByEmployeesGetPlannedValuesList')
	BEGIN
		PRINT 'Dropping Procedure ReportTimeSellAnalysisByEmployeesGetPlannedValuesList'
		DROP  Procedure  ReportTimeSellAnalysisByEmployeesGetPlannedValuesList
	END
GO

PRINT 'Creating Procedure ReportTimeSellAnalysisByEmployeesGetPlannedValuesList'
GO
/******************************************************************************
**		File: ReportTimeSellAnalysisByEmployees.sql
**		Name: ReportTimeSellAnalysisByEmployees
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		Auth: Sergey Pelevin			Date: 25.07.14
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		28.10.14	SAP			Добавлен пересчет в нац. валюту по курсу
*******************************************************************************/
CREATE PROCEDURE ReportTimeSellAnalysisByEmployeesGetPlannedValuesList
	@EmployeeID	int,		
	@PeriodStart date, -- Начало периода
	@PeriodEnd date, --Конец периода
	@CurrencySelector INT,--Валюта отчета (0 - учетная, 1 - национальная)
	@BaseCurrencyRate DECIMAL (18,4),--Курс учетной к национальной валюте
	@UtilizationPlanned decimal(18,2) OUTPUT, 
	@RealizationPlanned decimal(18,2) OUTPUT, 
	@RevenuePlanned decimal(18,2) OUTPUT
AS
BEGIN			

	SET @PeriodEnd = DATEADD(DAY,-1,@PeriodEnd)

	DECLARE	@Periods TABLE
	(
		StartDate date,
		EndDate date
	)

	INSERT INTO @Periods
	SELECT 
		[Y].[StartDate],
		[Y].[EndDate]
	FROM
		[dbo].[fnReportSplitPeriodOnYears](@PeriodStart,@PeriodEnd) as [Y]

	--SELECT * FROM @Periods
	
	DECLARE 
		@tmpPeriodStartDate date,
		@tmpPeriodEndDate date



	--*******************DEBUG
	--SELECT
	--	@tmpPeriodStartDate = {ts'2014-05-01 00:00:00'},
	--	@tmpPeriodEndDate = {ts'2014-12-31 00:00:00'}
	--FROM
	--	@Periods

	--SELECT 
	--	@tmpPeriodStartDate AS [StartDate],
	--	@tmpPeriodEndDate AS [EndDate]

	--DECLARE
	--	@Rowcount int

	--*******************DEBUG

	DECLARE @EmployeeNormsByPeriod TABLE
	(
		[StartDate] date,
		[EndDate] date,
		[WorkingDays] int,
		[NormID] int,
		[Utilization] decimal(18,10),
		[Realization] decimal(18,10),
		[Revenue] decimal(18,10)
	)

	DECLARE @Values TABLE
	(
		[Utilization] decimal(18,10),
		[Realization] decimal(18,10),
		[Revenue] decimal(18,10)
	)
    
    DECLARE periodsCursor CURSOR FAST_FORWARD READ_ONLY LOCAL FOR
    	SELECT 
			[StartDate],
			[EndDate]
    	FROM 
			@Periods
    
    OPEN periodsCursor    
    FETCH NEXT FROM periodsCursor INTO @tmpPeriodStartDate, @tmpPeriodEndDate    
    WHILE @@FETCH_STATUS = 0 
	BEGIN
		
		DECLARE
			@WorkingDaysInYear decimal(18,2)
		SELECT
			@WorkingDaysInYear = CAST
			(
				dbo.fnPjm5GetWorkingDays
				(
					CAST(CAST(YEAR(@tmpPeriodStartDate) AS varchar(4)) + '0101' AS datetime), 
					CAST(CAST(YEAR(@tmpPeriodStartDate) AS varchar(4)) + '1231' AS datetime)
				)  
				AS decimal(18,2)
			)

		--SELECT @WorkingDaysInYear as [WorkingDaysInYear]

		DELETE FROM @EmployeeNormsByPeriod
		INSERT INTO @EmployeeNormsByPeriod
    	SELECT
			CASE
				WHEN @tmpPeriodStartDate >= [ENE].[StartDate] THEN @tmpPeriodStartDate
				ELSE [ENE].[StartDate]
			END,
			CASE
				WHEN @tmpPeriodEndDate <= ISNULL((SELECT MIN([EmployeeNormEntry].[StartDate]) FROM [EmployeeNormEntry] WHERE [EmployeeNormEntry].[EmployeeID] = @EmployeeID AND [EmployeeNormEntry].[StartDate] > [ENE].[StartDate]),@tmpPeriodEndDate)
				THEN @tmpPeriodEndDate
				ELSE 
				ISNULL
				(
					(
						SELECT 
							DATEADD(DAY,-1,MIN([EmployeeNormEntry].[StartDate]) )
						FROM 
							[EmployeeNormEntry] 
						WHERE 
							[EmployeeNormEntry].[EmployeeID] = @EmployeeID 
							AND 
							[EmployeeNormEntry].[StartDate] > [ENE].[StartDate]
					),
					@tmpPeriodEndDate
				)
			END,
			dbo.fnPjm5GetWorkingDays
			(
				CASE
					WHEN @tmpPeriodStartDate >= [ENE].[StartDate] THEN @tmpPeriodStartDate
					ELSE [ENE].[StartDate]
				END,
				CASE
					WHEN @tmpPeriodEndDate <= ISNULL((SELECT MIN([EmployeeNormEntry].[StartDate]) FROM [EmployeeNormEntry] WHERE [EmployeeNormEntry].[EmployeeID] = @EmployeeID AND [EmployeeNormEntry].[StartDate] > [ENE].[StartDate]),@tmpPeriodEndDate)
					THEN @tmpPeriodEndDate
					ELSE 
					ISNULL
					(
						(
							SELECT 
								DATEADD(DAY,-1,MIN([EmployeeNormEntry].[StartDate]) )
							FROM 
								[EmployeeNormEntry] 
							WHERE 
								[EmployeeNormEntry].[EmployeeID] = @EmployeeID 
								AND 
								[EmployeeNormEntry].[StartDate] > [ENE].[StartDate]
						),
						@tmpPeriodEndDate
					)
				END
			),			
			[ENE].[NormID],
			NULL,
			NULL,
			NULL
		FROM
			[EmployeeNormEntry] AS [ENE]			
		WHERE
			[ENE].[EmployeeID] = @EmployeeID
			AND
			(
				[ENE].[StartDate] <= @tmpPeriodEndDate
				--AND
				--[ENE].[StartDate] >= @PeriodEnd
			)

		DELETE FROM @EmployeeNormsByPeriod WHERE [StartDate] > [EndDate]

		--SELECT * FROM @EmployeeNormsByPeriod
		--SELECT @Rowcount = COUNT(*) FROM @EmployeeNormsByPeriod

		UPDATE @EmployeeNormsByPeriod
		SET [Utilization] = 
		(
			SELECT TOP 1
			([NV].[UtilizationHours] * [ENBP].[WorkingDays]) / @WorkingDaysInYear
			FROM 
				(
					SELECT TOP 1
						*
					FROM
						[NormValue] AS [NV1]
					WHERE
						[NV1].[NormID] = [ENBP].[NormID]
						AND
						DATEPART(YEAR,([NV1].[Year])) <= DATEPART(YEAR,[ENBP].[StartDate])
					ORDER BY 
						[NV1].[Year] DESC
				) AS [NV]			
		),
		[Realization] = 
		(
			SELECT TOP 1
			([NV].[RealizationHours] * [ENBP].[WorkingDays]) / @WorkingDaysInYear
			FROM 
				(
					SELECT TOP 1
						*
					FROM
						[NormValue] AS [NV1]
					WHERE
						[NV1].[NormID] = [ENBP].[NormID]
						AND
						DATEPART(YEAR,([NV1].[Year])) <= DATEPART(YEAR,[ENBP].[StartDate])
					ORDER BY 
						[NV1].[Year] DESC
				) AS [NV]			
		),
		[Revenue] = 
		(
			SELECT TOP 1
			([NV].[Revenue] * [ENBP].[WorkingDays]) / @WorkingDaysInYear
			FROM 
				(
					SELECT TOP 1
						*
					FROM
						[NormValue] AS [NV1]
					WHERE
						[NV1].[NormID] = [ENBP].[NormID]
						AND
						DATEPART(YEAR,([NV1].[Year])) <= DATEPART(YEAR,[ENBP].[StartDate])
					ORDER BY 
						[NV1].[Year] DESC
				) AS [NV]			
		)
		FROM 
			@EmployeeNormsByPeriod AS [ENBP]


		--SELECT @Rowcount = COUNT(*) FROM @EmployeeNormsByPeriod
		--SELECT * FROM @EmployeeNormsByPeriod

		--SELECT @Rowcount = COUNT(*) FROM @Values

		INSERT INTO @Values
		SELECT
			[ENBP].[Utilization],
			[ENBP].[Realization],
			[ENBP].[Revenue]
		FROM
			@EmployeeNormsByPeriod AS [ENBP]

		--SELECT @Rowcount = COUNT(*) FROM @Values


    	FETCH NEXT FROM periodsCursor INTO @tmpPeriodStartDate, @tmpPeriodEndDate   
    END
    
    CLOSE periodsCursor
    DEALLOCATE periodsCursor

	--SELECT * FROM @Values
	
	SELECT
		@UtilizationPlanned = ROUND(SUM([V].[Utilization]),2),
		@RealizationPlanned = ROUND(SUM([V].[Realization]),2),
		@RevenuePlanned = 
		CASE 
			WHEN @CurrencySelector = 0 THEN ROUND(SUM([V].[Revenue]),2)
			ELSE ROUND(SUM([V].[Revenue])* @BaseCurrencyRate,2)
		END
	FROM
		@Values AS [V]   
	

    	

	RETURN 0
END
GO

GRANT EXEC ON ReportTimeSellAnalysisByEmployeesGetPlannedValuesList TO PUBLIC

GO