﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7DocumentChangeBillableFlagOnCalculationApprove]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7DocumentChangeBillableFlagOnCalculationApprove'
		DROP PROCEDURE [dbo].[pjm7DocumentChangeBillableFlagOnCalculationApprove]
	END
GO

PRINT 'Creating procedure pjm7DocumentChangeBillableFlagOnCalculationApprove'
GO

/******************************************************************************
**		File: pjm7DocumentChangeBillableFlagOnCalculationApproves.sql
**		Name: pjm7DocumentChangeBillableFlagOnCalculationApproves
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Sergey Pelevin
**		Date: 26.06.14
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		01.07.14	SAP			Доработка условий выбора ЗОВ и затрат
**		02.07.14	SAP			Обработка записей из других проектов / подпроектов
**		04.07.14	SAP			Фильтрация списка проектов, в кторых можно снимать флаги "К оплате"
**		16.08.14	SAP			Доработка процедуры. Теперь она работает в связке с процедурой
**								pjm7GetDocumentsForChangeBillableFlagOnCalculationApprove
*******************************************************************************/
CREATE PROCEDURE pjm7DocumentChangeBillableFlagOnCalculationApprove
	@DocumentClass TClass,
	@RecordIDs XML,
	@BillableFlagNewValue bit
AS
	SET NOCOUNT ON

	DECLARE 		
		@TimeEntryClass TClass = [dbo].[adfGetClassByName]('Pjm5.TimeEntry'),
		@ExpenseClass TClass = [dbo].[adfGetClassByName]('Pjm5.Expense')
		
	
	DECLARE @RecordsToChange TABLE
	(
		[ID] int
	)

	INSERT INTO @RecordsToChange
	SELECT
		T.[c].value('.','int')
	FROM
		@RecordIDs.nodes('/Records/Records/ID') as T(c)
		
	IF EXISTS(SELECT [ID] FROM @RecordsToChange)
	BEGIN 
		BEGIN TRANSACTION

		--добавление необходимых прав
		INSERT INTO [Right] ([Name],[DisplayName],[Group]) VALUES('RemoveBillableFlag', '', '')
		EXEC pjm6SetRightForMasters 'RemoveBillableFlag'

		IF @DocumentClass = @TimeEntryClass
		BEGIN
			UPDATE [TimeEntry]
			SET [Billable] = @BillableFlagNewValue
			WHERE [ID] IN (SELECT [ID] FROM @RecordsToChange)

			IF @@error <> 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
		ELSE IF @DocumentClass = @ExpenseClass
		BEGIN
			UPDATE [Expense]
			SET [Billable] = @BillableFlagNewValue
			WHERE [ID] IN (SELECT [ID] FROM @RecordsToChange)

			IF @@error <> 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END

		--удаление дарованных в ходе процедуры прав
		EXEC pjm6DelRightForMasters 'RemoveBillableFlag'
		DELETE [Right] WHERE [Name] = 'RemoveBillableFlag'

		IF @@error <> 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

		COMMIT TRANSACTION
	END

	RETURN 0
GO

GRANT EXECUTE ON pjm7DocumentChangeBillableFlagOnCalculationApprove TO PUBLIC
GO