IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6DocumentNumberGetNext')
	BEGIN
		PRINT 'Dropping Procedure pjm6DocumentNumberGetNext'
		DROP  Procedure  pjm6DocumentNumberGetNext
	END

GO

PRINT 'Creating Procedure pjm6DocumentNumberGetNext'
GO
/******************************************************************************
**		File: DocumentNumberGetNext
**		Name: pjm6DocumentNumberGetNext
**		Desc: 
**              
**		Auth: SPV
**		Date: 04.07.11
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.07.11	SPV				first version
*******************************************************************************/
CREATE Procedure pjm6DocumentNumberGetNext
	@Guid TGuid,
	@ProjectID TIdentifier = NULL,
	@CompanyID TIdentifier = NULL,
	@DocumentDate TDate = NULL,
	@Increase TBool = 1	--	 1,    
AS
	DECLARE
		@Class TClass,
		@ClassName TName,
		@Number TCount,
		@ApplyLevel tinyint,
		@NumberTemplate TName,
		@NameTemplate TName,
		@TemplateID TIdentifier,
		@SupplierCompanyID TIdentifier,
		@CustomerCompanyID TIdentifier,
		@CompanyClass TClass,
		@ProjectClass TClass,
		@NumerationID TIdentifier,
		@Seed TCount,
		@Increment TCount
		
	SELECT 
		@Class = [Class],
		@ClassName = [Name] 
	FROM 
		[Class] 
	WHERE 
		[Guid] = @Guid
		
	IF @Class IS NULL
	BEGIN
		RAISERROR('#InvalidDocumentGuid', 18, -1)
		RETURN 1
	END

	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @ProjectClass = dbo.adfGetClassByName('Pjm5.Project')

	--    (    ,  )
	IF @ProjectID IS NOT NULL
	BEGIN
		--    ,    
		SELECT
			@CustomerCompanyID = [CustomerCompanyID],
			@SupplierCompanyID = [SupplierCompanyID]
		FROM
			[Project]
		WHERE
			[ID] = @ProjectID
		
		--------------------------    ------------------------------------------
		SELECT
			@TemplateID = [ID],
			@ApplyLevel = [ApplyLevel],
			@NumberTemplate = [NumberTemplate],
			@NameTemplate = [NameTemplate],
			@Seed = [Seed],
			@Increment = [Increment]
		FROM
			[NumberTemplate]
		WHERE
			[CompanyID] = @SupplierCompanyID AND
			[TemplateClass] = @Class
		
		--    ,    
		IF @TemplateID IS NULL 
		BEGIN
			INSERT INTO [NumberTemplate] ([TemplateClass], [CompanyID], [ApplyLevel], [DuePeriodType], [CurrentNumber], [PrevNumber])
			VALUES (@Class, @SupplierCompanyID, 0, dbo.fnPjm6NumberGetDefaultPeriodType(@Class, 0), 1, 1)
			
			SET @TemplateID = SCOPE_IDENTITY()

			SELECT
				@ApplyLevel = [ApplyLevel],
				@NumberTemplate = [NumberTemplate],
				@NameTemplate = [NameTemplate],
				@Seed = [Seed],
				@Increment = [Increment]
			FROM
				[NumberTemplate]
			WHERE
				[ID] = @TemplateID
		END
		
		------------------------------------  ----------------------------------------------
		--     
		IF @ApplyLevel != 0
		BEGIN
			SELECT
				@NumerationID = [ID]
			FROM
				[NumberAssignment]
			WHERE
				[DocumentClass] = CASE @ApplyLevel WHEN 1 THEN @CompanyClass WHEN 2 THEN @ProjectClass END AND
				[DocumentID] = CASE @ApplyLevel WHEN 1 THEN @CustomerCompanyID WHEN 2 THEN @ProjectID END AND
				[TemplateClass] = @Class

			--------    ,  
			IF @NumerationID IS NULL
			BEGIN
				INSERT INTO [NumberAssignment]
				(
					[TemplateClass], [DocumentClass], [DocumentID], [InitDate], [DuePeriodType], [CurrentNumber], [PrevNumber]
				)
				VALUES
				(
					@Class,
					CASE @ApplyLevel WHEN 1 THEN @CompanyClass WHEN 2 THEN @ProjectClass END,
					CASE @ApplyLevel WHEN 1 THEN @CustomerCompanyID WHEN 2 THEN @ProjectID END,
					@DocumentDate, dbo.fnPjm6NumberGetDefaultPeriodType(@Class, @ApplyLevel), @Seed, @Seed
				)
				SET @Number = @Seed
				SET @NumerationID = @@IDENTITY

				IF @Increase = 1
				BEGIN
					UPDATE [NumberAssignment]
					SET [CurrentNumber] = [CurrentNumber] + @Increment
					WHERE [ID] = @NumerationID
				END
			END
			--------   ,    
			ELSE
			BEGIN
				--  
				SELECT
					@Number = CASE
						WHEN ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND [DuePeriodType] = 1
							THEN [PrevNumber] 
						WHEN ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) > 0 AND [DuePeriodType] = 1
							THEN @Seed
						ELSE [CurrentNumber] END
				FROM
					[NumberAssignment]
				WHERE
					[ID] = @NumerationID
				--  
				IF @Increase = 1
				BEGIN
					UPDATE [NumberAssignment]
					SET
						[PrevNumber] = CASE
							--       ,    
							--   1.   -  2.    >  . 
							WHEN (ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0)) > 0 AND [DuePeriodType] = 1
								THEN [CurrentNumber]
							--    
							WHEN
								ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND
								[DuePeriodType] = 1 
								THEN [PrevNumber] + @Increment
							--     
							ELSE [PrevNumber] END,
						[CurrentNumber] = CASE
							--           ""   >  .
							WHEN 
								ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) > 0 AND [DuePeriodType] = 1 
								THEN @Seed + @Increment
							--     "",    
							WHEN 
								ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND [DuePeriodType] = 1 
								THEN [CurrentNumber]
							--  
							ELSE [CurrentNumber] + @Increment END,
						[InitDate] = CASE WHEN @DocumentDate > [InitDate] OR [InitDate] IS NULL THEN @DocumentDate ELSE [InitDate] END
					WHERE
						[ID] = @NumerationID
				END
			END
		END
		--------     
		ELSE
		BEGIN
			--   
			SELECT @Number = CASE
					WHEN ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND [DuePeriodType] = 1
						THEN [PrevNumber] 
					WHEN ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) > 0 AND [DuePeriodType] = 1
						THEN [Seed]
					ELSE [CurrentNumber] END
			FROM [NumberTemplate]
			WHERE [ID] = @TemplateID
			--    ,   
			IF @Increase = 1
			BEGIN
				UPDATE [NumberTemplate]
				SET
					[PrevNumber] = CASE
						--       ,    
						--   1.   -  2.    >  . 
						WHEN (ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0)) > 0 AND [DuePeriodType] = 1
							THEN [CurrentNumber]
						--    
						WHEN
							ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND
							[DuePeriodType] = 1 
							THEN [PrevNumber] + [Increment]
						--     
						ELSE [PrevNumber] END,
					[CurrentNumber] = CASE
						--           ""   >  .
						WHEN 
							ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) > 0 AND [DuePeriodType] = 1 
							THEN [Seed] + [Increment]
						--     "",    
						WHEN 
							ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND [DuePeriodType] = 1 
							THEN [CurrentNumber]
						--  
						ELSE [CurrentNumber] + [Increment] END,
					[InitDate] = CASE WHEN @DocumentDate > [InitDate] OR [InitDate] IS NULL THEN @DocumentDate ELSE [InitDate] END
				WHERE
					[ID] = @TemplateID
			END
		END
	END
	---------   
	ELSE
	BEGIN
		--  
		SELECT @TemplateID = [ID] FROM [NumberTemplate] WHERE [TemplateClass] = @Class AND [CompanyID] = @CompanyID
		IF @TemplateID IS NULL 
		BEGIN
			INSERT INTO [NumberTemplate] ([TemplateClass], [CompanyID], [ApplyLevel], [DuePeriodType], [CurrentNumber], [PrevNumber])
			VALUES (@Class, @CompanyID, 0, dbo.fnPjm6NumberGetDefaultPeriodType(@Class, 0), 1, 1)
			
			SET @TemplateID = SCOPE_IDENTITY()

			SELECT
				@ApplyLevel = [ApplyLevel],
				@NumberTemplate = [NumberTemplate],
				@NameTemplate = [NameTemplate],
				@Seed = [Seed],
				@Increment = [Increment]
			FROM
				[NumberTemplate]
			WHERE
				[ID] = @TemplateID
		END

		--                
		SELECT
			@Number = CASE
				WHEN ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND [DuePeriodType] = 1
					THEN [PrevNumber] 
				WHEN ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) > 0 AND [DuePeriodType] = 1
					THEN [Seed]
				ELSE [CurrentNumber] END,
			@NumberTemplate = [NumberTemplate],
			@NameTemplate = [NameTemplate]
		FROM
			[NumberTemplate]
		WHERE
			[ID] = @TemplateID

		IF @Increase = 1
		BEGIN
			UPDATE [NumberTemplate]
			SET
				[PrevNumber] = CASE
					--       ,    
					--   1.   -  2.    >  . 
					WHEN (ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0)) > 0 AND [DuePeriodType] = 1
						THEN [CurrentNumber]
					--    
					WHEN
						ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND
						[DuePeriodType] = 1 
						THEN [PrevNumber] + [Increment]
					--     
					ELSE [PrevNumber] END,
				[CurrentNumber] = CASE
					--           ""   >  .
					WHEN 
						ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) > 0 AND [DuePeriodType] = 1 
						THEN [Seed] + [Increment]
					--     "",    
					WHEN 
						ISNULL(DATEDIFF(year, [InitDate], @DocumentDate), 0) < 0 AND [DuePeriodType] = 1 
						THEN [CurrentNumber]
					--  
					ELSE [CurrentNumber] + [Increment] END,
					
				-- c      
				[InitDate] = CASE WHEN @DocumentDate > [InitDate] OR [InitDate] IS NULL THEN @DocumentDate ELSE [InitDate] END
			WHERE
				[ID] = @TemplateID
		END

		IF @@ERROR != 0
		BEGIN
			RETURN 1
		END
	
		IF @Number IS NULL 
		BEGIN
			RAISERROR('#CannotGenerateDocumentNumber', 18, -1)
			RETURN 1
		END
	END

	--   
	--  
	IF @ProjectID IS NOT NULL
		SELECT
			@Number as [CurrentNumber],
			@NumberTemplate as [NumberTemplate],
			@NameTemplate as [NameTemplate],
			@ClassName as [ClassName],
			[Supplier].[Number] as [SupplierCode],
			[Customer].[Number] as [CustomerCode],
			[Project].[Date] as [ProjectDate],
			[Project].[Number] as [ProjectCode],
			[Project].[ContractDate] as [ContractDate],
			[Project].[ContractNumber] as [ContractCode],
			[Project].[NumerationCode] as [ProjectNumber]
		FROM
			[Project]
			LEFT OUTER JOIN [Company] [Supplier]
				ON [Project].[SupplierCompanyID] = [Supplier].[ID]
			LEFT OUTER JOIN [Company] [Customer]
				ON [Project].[CustomerCompanyID] = [Customer].[ID]
		WHERE
			[Project].[ID] = @ProjectID
	ELSE
		SELECT
			@Number as [CurrentNumber],
			@NumberTemplate as [NumberTemplate],
			@NameTemplate as [NameTemplate],
			@ClassName as [ClassName],
			[Company].[Number] as [SupplierCode],
			NULL as [CustomerCode],
			NULL as [ProjectDate],
			NULL as [ProjectCode],
			NULL as [ContractDate],
			NULL as [ContractCode],
			NULL as [ProjectNumber]
		FROM
			[Company]
		WHERE
			[ID] = @CompanyID
	
	RETURN 1
GO

GRANT EXEC ON pjm6DocumentNumberGetNext TO PUBLIC
GO
