﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ExchangeSyncUpdateAttributesForSync]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ExchangeSyncUpdateAttributesForSync'
		DROP PROCEDURE [dbo].[pjm7ExchangeSyncUpdateAttributesForSync]
	END
GO

PRINT 'Creating procedure pjm7ExchangeSyncUpdateAttributesForSync'
GO

/******************************************************************************
**		File: ExchangeSyncUpdateAttributesForSync.sql
**		Name: pjm7ExchangeSyncUpdateAttributesForSync
**		Desc: Процедура обновляет список атрибутов, для которых 
**				устанавливается синхронизация с Exchange для пользователя
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 21.02.2012 14:38:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE pjm7ExchangeSyncUpdateAttributesForSync
	@Attributes	XML,
	@ClassName	TName,
	@UserID		TIdentifier = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@Class	TClass
	SET @Class = dbo.adfGetClassByName(@ClassName)	

	IF @UserID IS NULL	
		SET @UserID = dbo.adfGetCurrentUserID()

	BEGIN TRANSACTION

	IF @ClassName = 'Adf.ActivityType'
	BEGIN
		DELETE FROM [ExchangeAttributesForSync]
		WHERE
			[ExchangeAttributesForSync].[DocumentClass] = @Class
			AND
			[ExchangeAttributesForSync].[UserID] = @UserID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END


	INSERT INTO [ExchangeAttributesForSync] ([DocumentID], [DocumentClass], [UserID])
	SELECT
		T.c.value('ID[1]','int'),
		@Class,
		@UserID
	FROM
		@Attributes.nodes('/pjm7ExchangeSyncUpdateAttributesForSync/ActivityType') AS T(c)
	WHERE T.c IS NOT NULL
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	END

	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON pjm7ExchangeSyncUpdateAttributesForSync TO PUBLIC
GO



