IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ExportInvoice')
	BEGIN
		PRINT 'Dropping Procedure ExportInvoice'
		DROP  Procedure  ExportInvoice
	END

GO

PRINT 'Creating Procedure ExportInvoice'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
/******************************************************************************
**		File: 
**		Name: 
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**     ----------							-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		31.05.10	SPV			 
**		31.08.11    SAM                
**		06.06.14	SAP			    CurrencyContractType
*******************************************************************************/ 
CREATE Procedure ExportInvoice
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	
	DECLARE
		@FactureClass TClass,
		@InvoiceClass TClass,
		@Value TVariant,
		@NationalCurrencyCode TCode3,
		@val TVariant,
		@EmployeeClass TClass,
		@CompanyClass TClass,
		@State TState

	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')

	IF EXISTS (
		SELECT
			[Invoice].[ID]
		FROM
			[Invoice]
			INNER JOIN [Project]
				ON [Project].[ID] = [Invoice].[ProjectID]
		WHERE
			[Invoice].[ID] = @ID AND
			[Project].[ContractDate] IS NULL AND
			[Project].[ContractNumber] IS NULL AND
			[Project].[ExchangeSystemName] IS NULL	)	
	BEGIN
		RAISERROR('#emptycontractfields', 18, -1)
		RETURN 1
	END

		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @val OUTPUT	
	SET @NationalCurrencyCode = CAST(@val AS varchar(3))
	
	SET @FactureClass = dbo.adfGetClassByName('Pjm5.Facture')
	
	SELECT @State = [State], @InvoiceClass = [Class] FROM [Invoice] WHERE [ID] = @ID
	
	IF @State = 3
	BEGIN
		exec pjm6ExportAnnualDocument @InvoiceClass, @ID
		RETURN
	END
	
	DECLARE @FactureStatement TABLE
	(
		[FactureID] TIdentifier,
		[StatementID] TIdentifier
	)
	--
	
	-- ID Udf- " ".    	
	DECLARE @ServiceTypeClass TClass, @ServiceTypeUDF TIdentifier
	SET @ServiceTypeClass = dbo.adfGetClassByName('Pjm5.ServiceType')
	SELECT
		@ServiceTypeUDF = [Property].[ID]
	FROM
		[Property]
	WHERE
		[Property].[Class] = @ServiceTypeClass AND [Property].[Name] = ' '
	
	------------------	
	
	--
	INSERT INTO @FactureStatement
	SELECT 
		[Facture].[ID] AS [FactureID],
		[Statement].[ID] AS [StatementID]
	FROM
		[Statement]
		INNER JOIN [Attachment]
			ON [Statement].[Class] = [Attachment].[DocumentClass]
				AND [Statement].[ID] = [Attachment].[DocumentID]
		INNER JOIN [Facture]
			ON [Facture].[Class] = [Attachment].[LinkDocumentClass]
				AND [Facture].[ID] = [Attachment].[LinkDocumentID]
	WHERE
		[Facture].[ID] = @ID
	UNION
	SELECT 
		[Facture].[ID] AS [FactureID],
		[Statement].[ID] AS [StatementID]
	FROM
		[Facture]
		INNER JOIN [Attachment]
			ON [Facture].[Class] = [Attachment].[DocumentClass]
				AND [Facture].[ID] = [Attachment].[DocumentID]
		INNER JOIN [Statement]
			ON [Statement].[Class] = [Attachment].[LinkDocumentClass]
				AND [Statement].[ID] = [Attachment].[LinkDocumentID]
	WHERE
		[Facture].[ID] = @ID
		----
		SELECT
			GETDATE() as 'Period/@StartDate',
			GETDATE() as 'Period/@EndDate',
			0 as 'Period/@PeriodType',
			(
				SELECT
					[Company].[ID] as '@SupplierID',
					[Company].[FileAs] as '@Name',
					'' as '@SupplierType',
					[Company].[LegalName] as '@LegalName',
					dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country]) as '@LegalAddress',
					dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostalAddress',
					[BasicPhone].[Phone] as '@BasePhone',
					[Fax].[Phone] as '@Fax',
					[Company].[LegalCode] as '@LegalCode',
					[Company].[KPP] as '@KPP',
				(
					SELECT
						[Invoice].[ID] as '@ID',
						[Invoice].[State] as '@State',
						[Invoice].[Number] as '@Number',
						[Invoice].[Date] as '@Date',
						[Currency].[NumericCode] as '@CurrencyNumericCode',
						[Currency].[Code] as '@CurrencyCode',
						[Invoice].[CurrencyRate] as '@CurrencyRate',
						dbo.pjm6fnCurrencyGetRate([Invoice].[CurrencyCode], [Invoice].[Date], @NationalCurrencyCode) as '@NationalCurrencyRate',
						[Invoice].[Advance] as '@Advance',
						[Invoice].[DueDate] as '@EndDate',
						[Invoice].[BaseCurrencyRate] as '@BaseCurrencyRate',
						[Invoice].[Total] as '@Total',
						[Invoice].[TotalWithVAT] as '@TotalWithVAT',
						[Invoice].[VAT] as '@VAT',
						(SELECT TOP(1)[VATRate] FROM [InvoiceLine] WHERE [InvoiceID] = [Invoice].[ID]) as '@VATRate',
						CASE WHEN (SELECT TOP(1)[VATRate] FROM [InvoiceLine] WHERE [InvoiceID] = [Invoice].[ID]) > 0 THEN 1 ELSE 0 END as '@ApplyVAT',
						--[Project].[ApplyVAT] as '@ApplyVAT',
						CASE [Invoice].[PaymentCurrencyPoint] WHEN 0 THEN 'Payment' ELSE 'Invoice' END as '@PaymentCurrencyRateDate',
						dbo.fnPjm6GetLastEditDate([Invoice].[ID], [Invoice].[Class]) as '@Modified',
						-----------contract
						(
						SELECT
							[Project].[ID] as '@ContractID',
							[Project].[ContractNumber] as '@ContractNumber',
							dbo.fnMask ([Project].[ExchangeSystemName], [Project].[ContractNumber],
							    [Project].[ContractDate]) as '@ExchangeSystemName',
							[Project].[ContractDate] as '@ContractDate',
							[Project].[ContractEndDate] as '@ContractEndDate',
							CASE
								WHEN [Project].[CurrencyCode] != @NationalCurrencyCode 
									AND ISNULL([ContractBankAccount].[CurrencyCode], [DefaultBankAccount].[CurrencyCode]) = @NationalCurrencyCode
									AND [Project].[PaymentCurrencyPoint] = 1
								THEN [NC].[Code]
								ELSE [Currency].[Code]
							END AS '@CurrencyCode',
							CASE 
								WHEN [Project].[CurrencyCode] != @NationalCurrencyCode 
									AND ISNULL([ContractBankAccount].[CurrencyCode], [DefaultBankAccount].[CurrencyCode]) = @NationalCurrencyCode
									AND [Project].[PaymentCurrencyPoint] = 1
								THEN [NC].[NumericCode]
								ELSE [Currency].[NumericCode]
							END AS '@CurrencyNumericCode',
							[CostCenter].[ID] as '@CostCenterID',
							[CostCenter].[Code] as '@CostCenterCode',
							[CostCenter].[FileAs] as '@CodeCenterFileAs',
							CASE
								WHEN [Project].[CurrencyCode] != @NationalCurrencyCode THEN
									CASE
										WHEN ISNULL([ContractBankAccount].[CurrencyCode], [DefaultBankAccount].[CurrencyCode]) != @NationalCurrencyCode THEN 'INT'
										ELSE 
											CASE [Project].[PaymentCurrencyPoint]
												WHEN 1 THEN 'NAT'
												WHEN 0 THEN 'UE'
											END										
									END
								ELSE 'NAT'
							END as '@CurrencyContractType',
							[Project].[InvoiceExpirationPeriod] as '@InvoiceExpirationPeriod',
							[Project].[InvoiceExpirationPeriodType] as '@InvoiceExpirationPeriodType',
							[Project].[IsConsignor] as '@IsConsignor',
							[Project].[ConsignorID] as '@ConsignorID',
							CASE [Project].[ConsignorClass] WHEN @EmployeeClass THEN 'Employee' WHEN @CompanyClass THEN 'Company' ELSE 'None' END as '@ConsignorType',
							[BusinessCard].[FileAs] as '@Consignor',
							[Project].[ConsignorContract] as '@ConsignorContract'
						 FROM
							[Project]
							LEFT OUTER JOIN [CostCenter]
								ON [Project].[CostCenterID] = [CostCenter].[ID]
							LEFT OUTER JOIN [Company]
								ON [Company].[ID] = [Project].[SupplierCompanyID]
							LEFT OUTER JOIN [BankAccount] [DefaultBankAccount]
								ON [DefaultBankAccount].[ID] = ISNULL([Company].[BankAccountID], -1)
							LEFT OUTER JOIN [BankAccount] [ContractBankAccount]
								ON [ContractBankAccount].[ID] = ISNULL([Project].[BankAccountID], -1)
							LEFT OUTER JOIN [Currency]
								ON [Currency].[Code] = [Project].[CurrencyCode]
							LEFT OUTER JOIN [BusinessCard]
								ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
							LEFT JOIN [Currency] AS [NC]
								ON [NC].[Code] = @NationalCurrencyCode 
							WHERE 
								[Project].[ID] = [Invoice].[ProjectID]
						 FOR XML PATH('Contract'), TYPE
						),
						---------------Bank account
						(
						SELECT
							[BankAccount].[ID] as '@BankAccountID',
							[BankAccount].[Account] as '@BankAccount',
							[BankAccount].[BankName] as '@Bank',
							[BankAccount].[City] as '@CityBank',
							[BankAccount].[IntermediaryAccount] as '@IntermediaryAccount',
							[BankAccount].[BankCode] as '@BankCode',
							[Currency].[Code] as '@CurrencyCode',
							[Currency].[NumericCode] as '@CurrencyNumericCode'
						FROM
							[BankAccount]
							INNER JOIN [Currency]
								ON [BankAccount].[CurrencyCode] = [Currency].[Code]							
						WHERE [BankAccount].[ID] = [Invoice].[SupplierBankAccountID]
						 FOR XML PATH('BankAccount'), TYPE
						),
						---------------Customer Bank account
						(
						SELECT
							[BankAccount].[ID] as '@BankAccountID',
							[BankAccount].[Account] as '@BankAccount',
							[BankAccount].[BankName] as '@Bank',
							[BankAccount].[City] as '@CityBank',
							[BankAccount].[IntermediaryAccount] as '@IntermediaryAccount',
							[BankAccount].[BankCode] as '@BankCode',
							[Currency].[Code] as '@CurrencyCode',
							[Currency].[NumericCode] as '@CurrencyNumericCode'
						 FROM
							[Company]
							INNER JOIN [BankAccount]
								ON [Company].[BankAccountID] = [BankAccount].[ID]
							INNER JOIN [Currency]
								ON [BankAccount].[CurrencyCode] = [Currency].[Code]
						WHERE
							[Invoice].[CustomerCompanyID] = [Company].[ID]
						 FOR XML PATH('ConsigneeBankAccount'), TYPE
						),
						-------------Customer
						(
							SELECT	
								[Company].[ID] as '@ID',
								[Company].[FileAs]  as '@Name',
								dbo.fnPjm6GetLegalFormType([Company].[LegalCode], ISNULL([LegalAddress].[Country], '')) as '@LegalFormType',
								[Company].[LegalName]  as '@LegalName',
								dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country])  as '@LegalAddress',
								dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostAddress',
								[BasicPhone].[Phone] as '@Phone',
								[Fax].[Phone] as '@Fax',
								[Company].[LegalCode]  as '@LegalCode',
								[Company].[KPP] as '@KPP'
							FROM
								[Company]
								LEFT OUTER JOIN [Address] as [LegalAddress]
									ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
										[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
										[LegalAddress].[AddressTypeID] = 1
								LEFT OUTER JOIN [Address] as [PostalAddress]
									ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
										[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
										[PostalAddress].[AddressTypeID] = 5
								LEFT OUTER JOIN [Phone] as [BasicPhone]
									ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
										[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
										[BasicPhone].[PhoneTypeID] = 11
								LEFT OUTER JOIN [Phone] as [Fax]
									ON [Fax].[BusinessCardID] = [Company].[ID] AND 
										[Fax].[BusinessCardClass] = [Company].[Class] AND
										[Fax].[PhoneTypeID] = 8 
							WHERE [Company].[ID] = [Invoice].[CustomerCompanyID]
							FOR XML PATH('Customer'), TYPE
						),
						-------------Consignee
						(
							SELECT	
								[Company].[ID] as '@ID',
								[Company].[FileAs]  as '@Name',
								dbo.fnPjm6GetLegalFormType([Company].[LegalCode], ISNULL([LegalAddress].[Country], '')) as '@LegalFormType',
								[Company].[LegalName]  as '@LegalName',
								dbo.fnPjm5AddressAsString([LegalAddress].[Street], [LegalAddress].[City],[LegalAddress].[Region],[LegalAddress].[PostalCode],[LegalAddress].[Country])  as '@LegalAddress',
								dbo.fnPjm5AddressAsString([PostalAddress].[Street], [PostalAddress].[City],[PostalAddress].[Region],[PostalAddress].[PostalCode],[PostalAddress].[Country]) as '@PostAddress',
								[BasicPhone].[Phone] as '@Phone',
								[Fax].[Phone] as '@Fax',
								[Company].[LegalCode]  as '@LegalCode',
								[Company].[KPP] as '@KPP'
							FROM
								[Company]
								LEFT OUTER JOIN [Address] as [LegalAddress]
									ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
										[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
										[LegalAddress].[AddressTypeID] = 1
								LEFT OUTER JOIN [Address] as [PostalAddress]
									ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
										[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
										[PostalAddress].[AddressTypeID] = 5
								LEFT OUTER JOIN [Phone] as [BasicPhone]
									ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
										[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
										[BasicPhone].[PhoneTypeID] = 11
								LEFT OUTER JOIN [Phone] as [Fax]
									ON [Fax].[BusinessCardID] = [Company].[ID] AND 
										[Fax].[BusinessCardClass] = [Company].[Class] AND
										[Fax].[PhoneTypeID] = 8 
							WHERE [Company].[ID] = [Invoice].[CustomerCompanyID]
							FOR XML PATH('Consignee'), TYPE
						),
						------------Invoice Lines
						(
							SELECT
								[InvoiceLine].[ID] as '@ID',
								[ServiceType].[ID] as '@ServiceTypeID',
								[ServiceType].[FileAs] as '@ServiceType',
								[ServiceType].[Code] as '@ServiceTypeCode',
								CASE [PropertyValue].[Value] WHEN 'True' THEN 1 ELSE 0 END as '@LineTypeIncludeSKU',
								[Service].[ID] as '@ServiceID',
								[Service].[FileAs] as '@Service',
								[Service].[Code] as '@ServiceCode',
								[InvoiceLine].[Amount] as '@Amount',
								[InvoiceLine].[VATRate] as '@VATRate',
								[UOM].[FileAs] '@UOM',
								CASE 
								WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
									THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
								ELSE [InvoiceLine].[Price]
								END  as '@Price',
								[InvoiceLine].[Amount] * 
									CASE 
										WHEN [InvoiceLine].[VATIsIncluded] = 1 AND [InvoiceLine].[Amount] != 0
											THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] - [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
										ELSE [InvoiceLine].[Price]
									END  as '@Total',
								CASE 
									WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
										THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
									ELSE [InvoiceLine].[Price]
								END  as '@PriceWithVAT',
								[InvoiceLine].[Amount] * 
								CASE 
									WHEN [InvoiceLine].[VATIsIncluded] = 0 AND [InvoiceLine].[Amount] != 0
										THEN ([InvoiceLine].[Price] * [InvoiceLine].[Amount] + [InvoiceLine].[VAT]) / [InvoiceLine].[Amount]
									ELSE [InvoiceLine].[Price]
								END as '@TotalWithVAT',
								[InvoiceLine].[VAT] as '@VAT',
								[InvoiceLine].[Description] as '@Description'
							FROM
								[InvoiceLine]
								LEFT OUTER JOIN [ServiceType]
									ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
								LEFT OUTER JOIN [UOM]
									ON [InvoiceLine].[UOMID] = [UOM].[ID]
								LEFT OUTER JOIN [ServiceAssignment]
										ON [ServiceAssignment].[Class] = [InvoiceLine].[DocumentClass]
										AND [ServiceAssignment].[ID] = [InvoiceLine].[DocumentID]
								LEFT OUTER JOIN [Service]
										ON [Service].[ID] = [ServiceAssignment].[ServiceID]
								LEFT OUTER JOIN [PropertyValue]
									ON [PropertyValue].[DocumentClass] = [ServiceType].[Class] AND
									 [PropertyValue].[DocumentID] = [ServiceType].[ID] AND [PropertyValue].[PropertyID] = @ServiceTypeUDF
							WHERE
								[InvoiceLine].[InvoiceID] = [Invoice].[ID]
							FOR XML PATH('InvoiceLine'), TYPE
						),
						---------------------Payments
						(
						SELECT
							[Payment].[ID] as '@ID',
							[Payment].[Number] as '@Number',
							[Payment].[IncomingNumber] as '@SysNum',
							[Payment].[IncomingDate] as '@DatePorucheniya',
							[Payment].[Date] as '@Date',
							[Payment].[Value] as '@Sum'
						FROM
							[PaymentDetail]
							INNER JOIN [Payment]
								ON [PaymentDetail].[PaymentID] = [Payment].[ID]
						WHERE
							[PaymentDetail].[InvoiceID] = [Invoice].[ID]
						FOR XML PATH('Payment'), TYPE
						) as 'Payments'
					FROM
						[Invoice] 
						INNER JOIN [Project]
							ON [Project].[ID] = [Invoice].[ProjectID]
						INNER JOIN [Currency]
							ON [Currency].[Code] = [Invoice].[CurrencyCode]
					WHERE
						[Invoice].[State] IN (2, 5) AND [Invoice].[ID] = @ID
					FOR XML PATH('Invoice'), TYPE
				) as 'Invoices'
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID] AND [Invoice].[ID] = @ID
		INNER JOIN [Company] 
			ON [Company].[ID] = [Project].[SupplierCompanyID]
		LEFT OUTER JOIN [Address] as [LegalAddress]
			ON [LegalAddress].[BusinessCardID] = [Company].[ID] AND 
				[LegalAddress].[BusinessCardClass] = [Company].[Class] AND
				[LegalAddress].[AddressTypeID] = 1
		LEFT OUTER JOIN [Address] as [PostalAddress]
			ON [PostalAddress].[BusinessCardID] = [Company].[ID] AND 
				[PostalAddress].[BusinessCardClass] = [Company].[Class] AND
				[PostalAddress].[AddressTypeID] = 5
		LEFT OUTER JOIN [Phone] as [BasicPhone]
			ON [BasicPhone].[BusinessCardID] = [Company].[ID] AND 
				[BasicPhone].[BusinessCardClass] = [Company].[Class] AND
				[BasicPhone].[PhoneTypeID] = 11
		LEFT OUTER JOIN [Phone] as [Fax]
			ON [Fax].[BusinessCardID] = [Company].[ID] AND 
				[Fax].[BusinessCardClass] = [Company].[Class] AND
				[Fax].[PhoneTypeID] = 8
	FOR XML PATH('Supplier'), TYPE) as 'Suppliers'
	FOR XML PATH('Documents')
	
	DECLARE @ExportFinanceOnce TBool
	SELECT
		@ExportFinanceOnce = [Company].[ExportFinanceOnce]
	FROM
		[Invoice]
		INNER JOIN [Company]
			ON [Invoice].[SupplierCompanyID] = [Company].[ID]
	WHERE
		[Invoice].[ID] = @ID
	
	DECLARE @ExportItemID TIdentifier, @SupplierID TIdentifier, @Date TDate
	SELECT @SupplierID = [SupplierCompanyID], @Date = [Date] FROM [Invoice] WHERE [ID] = @ID
	EXEC pjm6CreateExportItem @SupplierID, @Date, @Date, 3
	SET @ExportItemID = @@IDENTITY
		
	UPDATE
		[Invoice]
	SET
		[Invoice].[ExportItemID] = @ExportItemID,
		[Invoice].[ExchangeBanned] = @ExportFinanceOnce
	WHERE
		[Invoice].[ID] = @ID AND [Invoice].[State] IN (2, 5) AND [Invoice].[ExchangeBanned] = 0
	
	RETURN 0
GO

GRANT EXEC ON ExportInvoice TO PUBLIC

GO
