IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5FactureLineUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
BEGIN
	PRINT 'Dropping procedure pjm5FactureLineUpdate'
	DROP PROCEDURE [dbo].[pjm5FactureLineUpdate]
END
GO

PRINT 'Creating procedure pjm5FactureLineUpdate'
GO

/******************************************************************************
**		File: pjm5FactureLineUpdate.sql
**		Name: pjm5FactureLineUpdate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		05.04.13	SOV				   . -
**		27.08.13	SOV				      Amount  
*******************************************************************************/
CREATE PROCEDURE [pjm5FactureLineUpdate]
	@ID	TIdentifier,
	@FactureID TIdentifier,
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@UOMID TIdentifier,
	@Amount TAmount,
	@VATIsIncluded TBool, 
	@VATRate TPercent, 
	@OriginalPrice TMoney,
	@Price TMoney,
	@Total TMoney,
	@Excise TMoney,
	@VAT TMoney,
	@TotalWithVAT TMoney,
	@OriginalPricePC TMoney,
	@PricePC TMoney,
	@TotalPC TMoney,
	@ExcisePC TMoney,
	@VATPC TMoney,
	@TotalWithVATPC TMoney,
	@Country TName,
	@CustomDeclaration TName,
	@Description TNotes,
	@BasePrice TCount,
	@SortKey TCode,
	@EditedInPaymentCurrency TBool
AS
	SET NOCOUNT ON
	DECLARE 
		@BaseCurrencyRate TAmount, 
		@NationalCurrency TCode3, 
		@BaseCurrency TCode3,
		@CurrencyCode TCode3,
		@value TVariant,
		@Scale TCount,
		@ProjectID TIdentifier
		
	SELECT
		@CurrencyCode = [Project].[CurrencyCode],
		@Scale = [Facture].[Scale],
		@ProjectID = [Project].[ID]
	FROM
		[Facture]
		INNER JOIN [Project]
			ON [Project].[ID] = [Facture].[ProjectID]
	WHERE
		[Facture].[ID] = @FactureID

	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5IsProjectManager(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm7IsFinanceManager(@ProjectID, @EmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		
	
	DECLARE @IsTimeEntry bit = 0,
		@BillableIsModified bit = 0			

	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	BEGIN
		SET @UOMID = 1 --  Hours
		SET @IsTimeEntry = 1
	END

	SET @Price = ISNULL(@Price, 0.0)
	SET @VAT = ISNULL(@VAT, 0.0)
	IF @ID IS NULL -- 
	BEGIN
		IF (@IsTimeEntry = 1)
		BEGIN
			DECLARE @PreviousAmount TAmount
			SELECT @PreviousAmount = [AmountBeforeFinanceDocumentInsert] FROM [EntryAmount] WHERE [ID] = @DocumentID
			
			IF (@Amount != @PreviousAmount)
				SET @BillableIsModified = 1
		END

		INSERT INTO [FactureLine] 
			(FactureID,
			DocumentClass,
			DocumentID,
			UOMID,
			Amount,
			VATIsIncluded, 
			VATRate, 
			OriginalPrice,
			Price,
			Total,
			Excise,
			VAT,
			TotalWithVAT,
			OriginalPricePC,
			PricePC,
			TotalPC,
			ExcisePC,
			VATPC,
			TotalWithVATPC,
			Country,
			CustomDeclaration,
			Description, 
			BasePrice, SortKey, EditedInPaymentCurrency)
		VALUES 
			(@FactureID,
			@DocumentClass,
			@DocumentID,
			@UOMID,
			@Amount,
			@VATIsIncluded, 
			@VATRate, 
			@OriginalPrice,
			@Price,
			ROUND(@Total, @Scale),
			@Excise,
			ROUND(@VAT, @Scale),
			ROUND(@TotalWithVAT, @Scale),
			@OriginalPricePC,
			@PricePC,
			ROUND(@TotalPC, @Scale),
			@ExcisePC,
			ROUND(@VATPC, @Scale),
			ROUND(@TotalWithVATPC, @Scale),
			@Country,
			@CustomDeclaration,
			@Description,
			@BasePrice, @SortKey,@EditedInPaymentCurrency)
		IF @@ERROR != 0
			RETURN 1
	END
	ELSE
	BEGIN
		IF (@IsTimeEntry = 1)
		BEGIN
			DECLARE @CurrentAmount TAmount
			SELECT @CurrentAmount = [Amount] FROM [FactureLine] WHERE [ID] = @ID

			IF (@Amount != @CurrentAmount)
				SET @BillableIsModified = 1
		END

		UPDATE 
			[FactureLine] 
		SET
			[DocumentClass] = @DocumentClass,
			[DocumentID] = @DocumentID,
			[UOMID] = @UOMID,
			[Amount] = @Amount,
			[VATIsIncluded] = @VATIsIncluded, 
			[VATRate] = @VATRate, 
			[OriginalPrice] = @OriginalPrice,
			[Price] = @Price,
			[Total] = ROUND(@Total, @Scale),
			[Excise] = @Excise,
			[VAT] = ROUND(@VAT, @Scale),
			[TotalWithVAT] = ROUND(@TotalWithVAT, @Scale),
			[OriginalPricePC] = @OriginalPricePC,
			[PricePC] = @PricePC,
			[TotalPC] = ROUND(@TotalPC, @Scale),
			[ExcisePC] = @ExcisePC,
			[VATPC] = ROUND(@VATPC, @Scale),
			[TotalWithVATPC] = ROUND(@TotalWithVATPC, @Scale),
			[Country] = @Country,
			[CustomDeclaration] = @CustomDeclaration,
			[Description] =  @Description,
			[BasePrice] = @BasePrice, 
			[SortKey] = @SortKey,
			[EditedInPaymentCurrency] = @EditedInPaymentCurrency
		WHERE
			[ID] = @ID
		IF @@ERROR != 0
			RETURN 1
	END

	IF (@BillableIsModified = 1)
	BEGIN
		UPDATE [EntryAmount]
		SET
			[ModifiedInFinance] = GETDATE(),
			[ModifiedByInFinance] = dbo.adfGetCurrentUserID()
		WHERE
			[EntryAmount].[ID] = @DocumentID
	END

	RETURN 0
GO

GRANT EXECUTE ON pjm5FactureLineUpdate TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5FactureLineDelete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
BEGIN
	PRINT 'Dropping procedure pjm5FactureLineDelete'
	DROP PROCEDURE [dbo].[pjm5FactureLineDelete]
END
GO

PRINT 'Creating procedure pjm5FactureLineDelete'
GO

/******************************************************************************
**		File: pjm5FactureLineDelete.sql
**		Name: pjm5FactureLineDelete
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/20/2005 15:20:31
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		05.04.13	SOV				   . -
*******************************************************************************/
CREATE PROCEDURE pjm5FactureLineDelete
	@ID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE @ProjectID TIdentifier
	SELECT @ProjectID = [Invoice].[ProjectID] 
	FROM 
		[InvoiceLine]
		INNER JOIN [Invoice] 
			ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
	WHERE 
		[InvoiceLine].[ID] = @ID
	
	DECLARE @EmployeeID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageAllInvoices')) = 0 AND
		dbo.fnPjm5IsProjectManager(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm5IsProjectMember(@ProjectID, @EmployeeID) = 0 AND
		dbo.fnPjm7IsFinanceManager(@ProjectID, @EmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END		
	
	DELETE FROM [FactureLine] WHERE [ID] = @ID

	IF @@ERROR != 0
		RETURN 1

	RETURN 0
GO

GRANT EXECUTE ON pjm5FactureLineDelete TO PUBLIC
GO
