IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trFactureLineInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm5trFactureLineInsert'
		DROP  Trigger pjm5trFactureLineInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trFactureLineInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trFactureLineInsert'
GO
CREATE Trigger pjm5trFactureLineInsert 
ON [FactureLine] FOR INSERT
AS
BEGIN
	DECLARE
		@CalculationClass TClass,
		@FactureClass TClass

	SET @CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')	
	SET @FactureClass = dbo.adfGetClassByName('Pjm5.Facture')	
	IF EXISTS(
		SELECT * 
		FROM 
			[Attachment]
			INNER JOIN [inserted]
				ON ([inserted].[DocumentClass] = [Attachment].[DocumentClass] AND
					[inserted].[DocumentID] = [Attachment].[DocumentID] AND
					[Attachment].[AttachmentTypeID] = 3)
		WHERE
			[Attachment].[LinkDocumentClass] IN (@CalculationClass, @FactureClass)
		)
	BEGIN
		ROLLBACK TRANSACTION
		RAISERROR('#DocumentAlreadyLinked', 18, -1)
		RETURN
	END
		
	INSERT INTO [Attachment]
		(
		[DocumentClass], [DocumentID], [Name],
		[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID]
		)
	SELECT
		[inserted].[DocumentClass], [inserted].[DocumentID], '-',
		[Facture].[Class], [Facture].[ID], 3
	FROM
		[inserted]
		INNER JOIN [Facture]
			ON [Facture].[ID] = [inserted].[FactureID]
	WHERE
		[inserted].[DocumentID] IS NOT NULL AND
		[inserted].[DocumentClass] != dbo.adfGetClassByName('Pjm5.ServiceAssignment')
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = CASE
			WHEN [Calculation].[State] = 2 THEN 3
			ELSE [Calculation].[State]
		END,
		[Calculation].[InvoiceApproved] = 1,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [inserted]
			ON [Calculation].[Class] = [inserted].[DocumentClass] AND 
				[Calculation].[ID] = [inserted].[DocumentID]
	WHERE
		[Calculation].[State] IN (2, 3)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[DivisionID] = [Employee].[DivisionID],
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID] AND
				[TimeEntry].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Expense]
	SET
		[Expense].[DivisionID] = [Employee].[DivisionID],
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Expense].[EmployeeID]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID] AND
				[Expense].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[DivisionID] = [Employee].[DivisionID],
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [ServiceRequest].[EmployeeID]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID] AND
				[ServiceRequest].[State] = 3
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 6,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID]
	WHERE
		[TimeEntry].[State] != 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 6,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID]
	WHERE
		[Expense].[State] != 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 5,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID]
	WHERE
		[ServiceRequest].[State] != 5
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trFactureLineDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm5trFactureLineDelete'
		DROP  Trigger pjm5trFactureLineDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trFactureLineDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**		18.03.13	SAP					   Amount  
**										 AmountBeforeFinanceDocumentInsert
**		10.07.13	SOV					   " "  EntryAmount
**		31.07.13	SAP					   " "  EntryAmount
**		27.08.13	SOV					          
*******************************************************************************/

PRINT 'Creating Trigger pjm5trFactureLineDelete'
GO
CREATE Trigger pjm5trFactureLineDelete 
ON [FactureLine] FOR DELETE
AS
BEGIN
	DELETE [Attachment]
	FROM
		[Attachment]
		INNER JOIN [deleted]
			ON ([deleted].[DocumentClass] = [Attachment].[DocumentClass] AND 
				[deleted].[DocumentID] = [Attachment].[DocumentID])
		INNER JOIN [Facture]
			ON ([Facture].[ID] = [deleted].[FactureID] AND
				[Facture].[Class] = [Attachment].[LinkDocumentClass] AND 
				[Facture].[ID] = [Attachment].[LinkDocumentID])
	WHERE
		[Attachment].[AttachmentTypeID] = 3
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = 2,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [deleted]
			ON [Calculation].[Class] = [deleted].[DocumentClass] AND 
				[Calculation].[ID] = [deleted].[DocumentID]
	WHERE
		[Calculation].[State] = 3 AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			)

	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitStatementCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [deleted]
			ON [TimeEntry].[Class] = [deleted].[DocumentClass] AND 
				[TimeEntry].[ID] = [deleted].[DocumentID]
	WHERE
		[TimeEntry].[State] = 6 AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [deleted]
			ON [Expense].[Class] = [deleted].[DocumentClass] AND 
				[Expense].[ID] = [deleted].[DocumentID]
	WHERE
		[Expense].[State] = 6 AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [deleted]
			ON [ServiceRequest].[Class] = [deleted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [deleted].[DocumentID]
	WHERE
		[ServiceRequest].[State] = 5 AND
		NOT EXISTS(
			SELECT * 
			FROM [StatementLine] 
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE 
				[Statement].[State] IN (1, 2, 3) AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	DECLARE @timeClass TClass
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	UPDATE
		[EntryAmount]
	SET
		[Amount] = [AmountBeforeFinanceDocumentInsert],
		[ModifiedInFinance] = NULL,
		[ModifiedByInFinance] = NULL,
		[Price] = ISNULL([TimeEntry].[Rate], 0)
	FROM 
		[EntryAmount]
		INNER JOIN [deleted]
			ON [deleted].[DocumentID] = [EntryAmount].[ID]
		INNER JOIN [TimeEntry]
			ON [TimeEntry].[ID] = [deleted].[DocumentID] AND
				[deleted].[DocumentClass] = [TimeEntry].[Class]
		INNER JOIN [Facture]
			ON [Facture].[ID] = [deleted].[FactureID]
	WHERE
		[Facture].[State] != 3 AND
		NOT EXISTS (
			SELECT *
			FROM
				[StatementLine]
				INNER JOIN [deleted]
					ON [StatementLine].[DocumentClass] = [deleted].[DocumentClass] AND
						[StatementLine].[DocumentID] = [deleted].[DocumentID]
				INNER JOIN [Statement]
					ON [Statement].[ID] = [StatementLine].[StatementID]
			WHERE
				[StatementLine].[DocumentClass] = @timeClass AND
				[Statement].[State] != 4
		) AND
		NOT EXISTS (
			SELECT *
			FROM
				[InvoiceLine]
				INNER JOIN [deleted]
					ON [InvoiceLine].[DocumentClass] = [deleted].[DocumentClass] AND
						[InvoiceLine].[DocumentID] = [deleted].[DocumentID]
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE
				[InvoiceLine].[DocumentClass] = @timeClass AND
				[Invoice].[State] != 3
		)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END			
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trFactureLineUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trFactureLineUpdate'
		DROP  Trigger pjm5trFactureLineUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trFactureLineUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trFactureLineUpdate'
GO
CREATE Trigger pjm5trFactureLineUpdate 
ON [FactureLine] FOR INSERT, UPDATE, DELETE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
		
    IF EXISTS (
		SELECT *
		FROM [inserted]
		WHERE [inserted].[TotalWithVAT] < [inserted].[VAT]
	)
	BEGIN
		RAISERROR('#wrongvatvalue', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
			
	DECLARE @timeClass TClass
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	IF EXISTS(
		SELECT *
		FROM 
			[EntryAmount]
			INNER JOIN [inserted]
				ON [inserted].[DocumentClass] = @timeClass AND
					[inserted].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [deleted]
				ON [deleted].[DocumentClass] = [inserted].[DocumentClass] AND
					[deleted].[DocumentID] = [inserted].[DocumentID]
			INNER JOIN [StatementLine]
				ON [StatementLine].[DocumentClass] = @timeClass AND
					[StatementLine].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [Statement]
				ON [Statement].[ID] = [StatementLine].[StatementID]
		WHERE
			[Statement].[State] != 4 AND
			(
				[StatementLine].[Amount] != [inserted].[Amount] OR 
				[StatementLine].[PricePC] != [inserted].[OriginalPricePC]
			)
	)
	BEGIN
		RAISERROR('#CannotChangeEntryAmountOrPrice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	IF EXISTS(
		SELECT *
		FROM 
			[EntryAmount]
			INNER JOIN [inserted]
				ON [inserted].[DocumentClass] = @timeClass AND
					[inserted].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [deleted]
				ON [deleted].[DocumentClass] = [inserted].[DocumentClass] AND
					[deleted].[DocumentID] = [inserted].[DocumentID]
			INNER JOIN [InvoiceLine]
				ON [InvoiceLine].[DocumentClass] = @timeClass AND
					[InvoiceLine].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [Invoice]
				ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
		WHERE
			[Invoice].[State] != 3 AND
			(
				[InvoiceLine].[Amount] != [inserted].[Amount] OR 
				[InvoiceLine].[PricePC] != [inserted].[OriginalPricePC]
			)
	)
	BEGIN
		RAISERROR('#CannotChangeEntryAmountOrPrice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[EntryAmount]
	SET
		[Amount] = [inserted].[Amount],
		[Price] = [inserted].[OriginalPricePC]
	FROM 
		[EntryAmount]
		INNER JOIN [inserted]
			ON [inserted].[DocumentClass] = @timeClass AND
				[inserted].[DocumentID] = [EntryAmount].[ID]
	WHERE
		[EntryAmount].[Amount] != [inserted].[Amount] OR 
		[EntryAmount].[Price] != [inserted].[OriginalPricePC]
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE @changed TABLE ([ID] int)
	INSERT INTO @changed ([ID])
	SELECT DISTINCT
		ISNULL([inserted].[FactureID], [deleted].[FactureID])
	FROM
		[inserted]
		FULL OUTER JOIN [deleted]
			ON [inserted].[ID] = [deleted].[ID]
		INNER JOIN [Facture]
			ON 	[Facture].[ID] = ISNULL([inserted].[FactureID], [deleted].[FactureID])
	WHERE
		[Facture].[State] != 3
		
	DECLARE @ID int
	DECLARE @total money, @totalwithvat money, @totalPC money, @totalwithvatPC money
	DECLARE @totals TABLE ([ID] int, [Total] money, [TotalWithVAT] money, [TotalPC] money null, [TotalWithVATPC] money null)
	DECLARE Factures CURSOR FAST_FORWARD FOR SELECT [ID] FROM @changed
	
	OPEN Factures
	FETCH NEXT FROM Factures INTO @ID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SELECT
			@total = SUM([FactureLine].[Total]),		
			@totalwithvat = SUM([FactureLine].[TotalWithVAT]),
			@totalPC = SUM([FactureLine].[TotalPC]),
			@totalwithvatPC = SUM([FactureLine].[TotalWithVATPC])
		FROM
			[Facture]
			INNER JOIN [FactureLine]
				ON [FactureLine].[FactureID] = [Facture].[ID]
		WHERE
			[Facture].[ID] = @ID

		INSERT INTO @totals 
			([ID], [Total], [TotalWithVAT], [TotalPC], [TotalWithVATPC])
		VALUES 
			(@ID, @total, @totalwithvat, @totalPC, @totalwithvatPC)
		FETCH NEXT FROM Factures INTO @ID
	END
	CLOSE Factures
	DEALLOCATE Factures
	
			
	UPDATE
		[Facture]
	SET
		[Total] = ROUND([Total].[Total], CASE [Project].[ApplyVAT] WHEN 0 THEN 2 ELSE [Facture].[Scale] END),
		[TotalWithVAT] = ROUND([Total].[TotalWithVAT], 2),
		[TotalPC] = ROUND([Total].[TotalPC], CASE [Project].[ApplyVAT] WHEN 0 THEN 2 ELSE [Facture].[Scale] END),
		[TotalWithVATPC] = ROUND([Total].[TotalWithVATPC], 2),
		[Modified] = DEFAULT,
		[ModifiedBy] = DEFAULT
	FROM
		[Facture]
		INNER JOIN [Project]
			ON [Project].[ID] = [Facture].[ProjectID]
		INNER JOIN @totals AS [Total]
			ON 	[Facture].[ID] = [Total].[ID]
	WHERE
		[Facture].[State] != 3
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO
