IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7MeetingDocumentUserReminderCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7MeetingDocumentUserReminderCreate'
		DROP PROCEDURE [dbo].[pjm7MeetingDocumentUserReminderCreate]
	END
GO

PRINT 'Creating procedure pjm7MeetingDocumentUserReminderCreate'
GO

/******************************************************************************
**		File: pjm7MeetingDocumentUserReminderCreate.sql
**		Name: pjm7MeetingDocumentUserReminderCreate
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 28.04.2012 15:41:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		07.05.10	PAM				     
**    
*******************************************************************************/
CREATE PROCEDURE [pjm7MeetingDocumentUserReminderCreate]
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@ReminderEventTime TDateTime,
	@ReminderState TState,
	@ReminderInterval TTimeSpan
AS
	SET NOCOUNT ON
	
	IF @DocumentClass IS NULL OR @DocumentID IS NULL
	BEGIN
		RETURN 1
	END
	
	DECLARE
		@DatabaseView				TSysname,
		@ReminderSubtype			TCode2,
		@ReminderID					TIdentifier,
		@ReminderDescription		TName,
		@ReminderInitialState		TState,
		@ReminderInitialInterval	TTimeSpan,
		@sql						nvarchar(3000),
		@sqlexec					int,
		@rv							int
		
	CREATE TABLE #view
	([DocumentClass] smallint, [DocumentID] int, [UserID] int, [EventTime] datetime)
			
	DECLARE reminders CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
	SELECT
		[ReminderType].[Subtype],
		[ReminderType].[Name],
		[ReminderType].[View]
	FROM
		[ReminderType]
	WHERE
		[ReminderType].[Class] = @DocumentClass
		
	OPEN reminders

	FETCH NEXT FROM reminders INTO @ReminderSubtype, @ReminderDescription, @DatabaseView
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @sql = N'SELECT [DocumentClass], [DocumentID], [RecipientUserID], [EventTime] FROM ' +
		@DatabaseView + ' WHERE [DocumentID] = @DocumentID AND [DocumentClass] = @DocumentClass'
		
		DELETE FROM #view
		INSERT INTO #view ([DocumentClass], [DocumentID], [UserID], [EventTime])
		exec @sqlexec = sp_executesql @sql,
			N'@DocumentID int, @DocumentClass smallint', @DocumentID, @DocumentClass
		IF @sqlexec != 0
		BEGIN
			GOTO ERROR_HANDLER
		END
		
		SELECT TOP 1 @ReminderEventTime = [DbView].[EventTime]
		FROM #view AS [DbView]
		
		EXEC @rv = pjm7ReminderForUserCreateInternal	@ReminderID OUTPUT,
														@DocumentClass, 
														@DocumentID, 
														@ReminderSubtype, 
														@ReminderEventTime
			
		IF @rv != 0 OR @ReminderID IS NULL
		BEGIN
			GOTO ERROR_HANDLER
		END
		
		DECLARE @UserID TIdentifier
		DECLARE users CURSOR LOCAL FORWARD_ONLY READ_ONLY FOR
		SELECT [DbView].[UserID]
		FROM #view AS [DbView]
		WHERE [DbView].[UserID] IS NOT NULL
		
		OPEN users

		FETCH NEXT FROM users INTO @UserID
		WHILE @@FETCH_STATUS = 0
		BEGIN
			IF NOT EXISTS (
				SELECT * FROM [UserReminder]
				WHERE [ReminderID] = @ReminderID AND [UserID] = @UserID
			)
			BEGIN
				IF @ReminderEventTime IS NOT NULL
				BEGIN
					SELECT 
						@ReminderInitialState = ISNULL(dbo.fnPjm5GetUserInitialReminderState(@DocumentClass, @ReminderSubtype, @UserID), 0),
						@ReminderInitialInterval = ISNULL(dbo.fnPjm5GetReminderInterval(@DocumentClass, @ReminderSubtype, @UserID), 15)
					
					IF(@ReminderState = 1) AND (@ReminderInitialState = 0)
					BEGIN
						SELECT
						@ReminderInitialState = 1,
						@ReminderInitialInterval = @ReminderInterval
					END
					
					INSERT INTO [UserReminder] ([ReminderID], [UserID], [State],
						[OriginalInterval], [NextInterval], [Description])
					VALUES (@ReminderID, @UserID, @ReminderInitialState,
						@ReminderInitialInterval, @ReminderInitialInterval, @ReminderDescription)
				END
			END
			ELSE
			BEGIN
				UPDATE [UserReminder] 
				SET
					[State] =	CASE
									WHEN @ReminderEventTime IS NOT NULL THEN [State]
									ELSE 0
								END,
					[Modified] = DEFAULT
				WHERE [ReminderID] = @ReminderID AND [UserID] = @UserID
			END
			FETCH NEXT FROM users INTO @UserID
		END
		IF @@ERROR != 0
		BEGIN
			CLOSE users
			DEALLOCATE users
			GOTO ERROR_HANDLER
		END
		
		CLOSE users
		DEALLOCATE users
		
		DELETE FROM [UserReminder] WHERE [ReminderID] = @ReminderID AND [UserID] NOT IN (SELECT [DbView].[UserID]
		FROM #view AS [DbView]
		WHERE [DbView].[UserID] IS NOT NULL)  
		
		FETCH NEXT FROM reminders INTO @ReminderSubtype, @ReminderDescription, @DatabaseView
	END

	CLOSE reminders
	DEALLOCATE reminders
	RETURN 0

ERROR_HANDLER:
	CLOSE reminders
	DEALLOCATE reminders
	RETURN 1
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm7MeetingDocumentUserReminderCreate] TO PUBLIC
GO