﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ReminderForUserUpdate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ReminderForUserUpdate'
		DROP PROCEDURE [dbo].[pjm7ReminderForUserUpdate]
	END
GO

PRINT 'Creating procedure pjm7ReminderForUserUpdate'
GO

/******************************************************************************
**		File: pjm7ReminderForUserUpdate.sql
**		Name: pjm7ReminderForUserUpdate
**		Desc: Процедура создает напоминание для пользователя
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 18.05.2012 12:00:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		09.04.13	SOV				Удаление пробелов в начале и конце описания напоминания    
*******************************************************************************/
CREATE PROCEDURE [pjm7ReminderForUserUpdate]
	@ReminderID				TIdentifier,
	@UserID					TIdentifier,
	@ReminderState			TIdentifier,
	@ReminderEventTime		TDateTime,
	@ReminderInterval		TTimeSpan,
	@ReminderDescription	TName = NULL,					--Текст напоминания
	@AutoExecute			TBool = 0,						--Признак автоматического вызова процедуры
	@Now TDate = NULL										--Время клиента
AS
	SET NOCOUNT ON

	IF @UserID IS NULL OR @ReminderID IS NULL
	BEGIN
		RETURN 1
	END

	IF @Now IS NULL
		SET @Now = GETDATE()
	
	--Проверка на редактирование напоминания в прошлом
	--IF DATEADD(minute, -@ReminderInterval, @ReminderEventTime) < @Now
	--	IF @AutoExecute = 0
	--	BEGIN
	--		RAISERROR('#ReminderDateInPast', 18, -1)	
	--		RETURN 1
	--	END
			
	--	ELSE
	--		RETURN 0

	DECLARE 
		@ReminderSubtype		TCode2,
		@ReminderOldEventTime	TDate,
		@rv int
	
	SELECT 
		@ReminderSubtype = [Subtype],
		@ReminderOldEventTime = [EventTime]
	FROM 
		[Reminder] 
	WHERE 
		[ID] = @ReminderID

	BEGIN TRANSACTION

	IF @ReminderSubtype IN ('UR')
	BEGIN
		UPDATE [Reminder] SET
			[EventTime] = @ReminderEventTime
		WHERE
			[ID] = @ReminderID
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END


	UPDATE [UserReminder] SET
		[State] =	CASE
						WHEN @ReminderEventTime IS NOT NULL THEN @ReminderState
						ELSE 0
					END,
		[OriginalInterval] = @ReminderInterval,
		[NextInterval] = @ReminderInterval,
		[Description] = RTRIM(LTRIM(@ReminderDescription)),
		[Modified] = DEFAULT
	WHERE [ReminderID] = @ReminderID AND [UserID] = @UserID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON [pjm7ReminderForUserUpdate] TO PUBLIC
GO