﻿IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm7NotifyIconGetData')
	BEGIN
		PRINT 'Dropping Procedure pjm7NotifyIconGetData'
		DROP  Procedure  pjm7NotifyIconGetData
	END

GO

PRINT 'Creating Procedure pjm7NotifyIconGetData'
GO
/******************************************************************************
**		File: pjm7NotifyIconGetData.sql
**		Name: pjm7NotifyIconGetData
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**		Auth: Dmitriy Volkov			Date: 15.12.2014
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		15.12.2014	VDV			Изменение условия выборки встреч
*******************************************************************************/
CREATE PROCEDURE [pjm7NotifyIconGetData]		
AS
BEGIN
	SET NOCOUNT ON

	DECLARE
		@CurrentEmployeeID INT,
		@CurrentDate DATE,
		@DraftTimeEntriesCount INT,
		@DraftTimeEntriesHours DECIMAL(18,2),
		@UnfinishedMeetingRequestsCount INT

	SELECT 
		@CurrentEmployeeID = [dbo].[adfGetCurrentEmployeeID](),
		@CurrentDate = GETDATE()
	
	SELECT
		@DraftTimeEntriesCount = COUNT([ID]),
		@DraftTimeEntriesHours = SUM([Duration] / 60.0)
	FROM 
		[TimeEntry]
	WHERE
		[EmployeeID] = @CurrentEmployeeID
		AND
		[StartTime] < @CurrentDate
		AND
		[State] IN (1, 5)

	SELECT
		@UnfinishedMeetingRequestsCount = COUNT(DISTINCT[ID])
	FROM
		[MeetingRequest]
	WHERE
		[MeetingRequest].[OriginatorEmployeeID] = @CurrentEmployeeID
		AND
		[MeetingRequest].[StartTime] < @CurrentDate
		AND
		[MeetingRequest].[State] = 2

	SELECT
		@DraftTimeEntriesCount AS [DraftTimeEntriesCount],
		ISNULL(@DraftTimeEntriesHours, 0) AS [DraftTimeEntriesHours],
		@UnfinishedMeetingRequestsCount AS [UnfinishedMeetingRequestsCount]

END
GO

GRANT EXEC ON pjm7NotifyIconGetData TO PUBLIC

GO
