IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfPaymentCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfPaymentCreate'
		DROP PROCEDURE [dbo].[adfPaymentCreate]
	END
GO

PRINT 'Creating procedure adfPaymentCreate'
GO

/******************************************************************************
**		File: adfPaymentCreate.sql
**		Name: adfPaymentCreate
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/21/2005 17:11:09
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		12.03.13	SOV				 OpenXml  Xml 
*******************************************************************************/
CREATE PROCEDURE [adfPaymentCreate]
	@Xml XML
AS
	DECLARE @State TState,
			@FileAs TName,
			@Date TDate,
			@Number TCode,
			@IncomingDate TDate,
			@IncomingNumber TCode,
			@PaymentTypeID TIdentifier,
			@PayeeCompanyID TIdentifier,
			@PayeeBankAccountID TIdentifier,
			@PayerCompanyID TIdentifier,
			@Value TMoney,
			@BaseCurrencyRate TMoney,
			@CurrencyCode TCode3,
			@VAT TMoney,
			@Comments TNotes,
			@ID TIdentifier,
			@Flag TFlag,
			@Reason TName,
			@Payer TName,
			@val TVariant
	
	SET NOCOUNT ON
	
	SET @State = dbo.adfwfGetInitialState('93c2d727-32db-4dda-9bf5-a52f35ccd952')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	SELECT 
		@Date = CONVERT(datetime, XmlTable.value('Date[1]', 'nvarchar(19)')),
		@IncomingDate = CONVERT(datetime, XmlTable.value('IncomingDate[1]', 'nvarchar(19)')),
		@FileAs = XmlTable.value('FileAs[1]', 'nvarchar(512)'),
		@Number = XmlTable.value('Number[1]', 'varchar(32)'),
		@IncomingNumber = XmlTable.value('IncomingNumber[1]', 'varchar(32)'),
		@PaymentTypeID = XmlTable.value('PaymentTypeID[1]', 'int'),
		@CurrencyCode = XmlTable.value('CurrencyCode[1]', 'char(3)'),
		@PayeeCompanyID = XmlTable.value('SupplierCompanyID[1]', 'int'),
		@PayeeBankAccountID = XmlTable.value('PayeeBankAccountID[1]', 'int'),
		@PayerCompanyID = XmlTable.value('CustomerCompanyID[1]', 'int'),
		@Value = XmlTable.value('Value[1]', 'money'),
		@VAT = XmlTable.value('VAT[1]', 'money'),
		@Comments = XmlTable.value('Comments[1]', 'nvarchar(max)'),
		@Flag = XmlTable.value('Flag[1]', 'int'),
		@BaseCurrencyRate = XmlTable.value('BaseCurrencyRate[1]', 'money'),
		@Reason = XmlTable.value('Reason[1]', 'nvarchar(256)'),
		@Payer = XmlTable.value('Payer[1]', 'nvarchar(256)')
	FROM
		@Xml.nodes('/adfPaymentGet/Payment') List(XmlTable)

	SET @Date = CAST(CONVERT(varchar(8), @Date, 112) AS DATETIME)
	SET @IncomingDate = CAST(CONVERT(varchar(8), @IncomingDate, 112) AS DATETIME)
	
	IF @PaymentTypeID = 1 --  
	BEGIN
		SET @Payer = NULL
	END
	ELSE IF @PaymentTypeID = 2 --  
	BEGIN
		SET @PayeeBankAccountID = NULL
	END
	ELSE -- Invalid payment type
	BEGIN
		RAISERROR('#internalerror', 16, -1)
		RETURN 1
	END	
	
	IF @Flag IS NULL
	BEGIN
		SET @Flag = 0
	END

	DECLARE @BaseCurrencyCode TCode3
	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @val OUTPUT
	SET @BaseCurrencyCode = CAST(@val as varchar(3))
	
	IF @BaseCurrencyCode = @CurrencyCode
	BEGIN
		SET @BaseCurrencyRate = 1.0
	END
		
	IF @BaseCurrencyRate IS NULL
	BEGIN
		IF(@BaseCurrencyCode = dbo.fnPjm5GetNationalCurrency())
			SELECT 
				@BaseCurrencyRate = [Rate]
			FROM
				[CurrencyRate]
			WHERE
				[FromCurrencyCode] = @CurrencyCode AND
				[ToCurrencyCode] = @BaseCurrencyCode AND
				(@Date BETWEEN [ValidFrom] AND [ValidTo])
		ELSE
			SELECT 
				@BaseCurrencyRate = [Rate]
			FROM
				[CurrencyRate]
			WHERE
				[FromCurrencyCode] = @BaseCurrencyCode AND
				[ToCurrencyCode] = @CurrencyCode AND
				(@Date BETWEEN [ValidFrom] AND [ValidTo])
	END

	BEGIN TRANSACTION
	INSERT INTO [Payment]
		([Flag], [State], 
		[FileAs], [Date], [IncomingDate], [Number], [IncomingNumber],
		[PaymentTypeID], [CurrencyCode],
		[PayeeCompanyID], [PayeeBankAccountID], [PayerCompanyID],
		[Value], [VAT], [BaseCurrencyRate],
		[Comments], [Reason], [Payer])
	VALUES
		(@Flag, @State,
		@FileAs, @Date, @IncomingDate, @Number, @IncomingNumber,
		@PaymentTypeID, @CurrencyCode,
		@PayeeCompanyID, @PayeeBankAccountID, @PayerCompanyID, 
		@Value, @VAT, @BaseCurrencyRate,
		@Comments, @Reason, @Payer)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @ID = SCOPE_IDENTITY()
	COMMIT TRANSACTION

	EXEC adfPaymentGet @ID

	RETURN 0
GO

GRANT EXECUTE ON adfPaymentCreate TO PUBLIC
GO
 