﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7PaymentToInvoiceBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7PaymentToInvoiceBrowse'
		DROP PROCEDURE [dbo].[pjm7PaymentToInvoiceBrowse]
	END
GO

PRINT 'Creating procedure pjm7PaymentToInvoiceBrowse'
GO

/******************************************************************************
**		File: pjm7PaymentToInvoiceBrowse.sql
**		Name: pjm7PaymentToInvoiceBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		
*******************************************************************************/
CREATE PROCEDURE [pjm7PaymentToInvoiceBrowse]
	@DateSelector				TIdentifier,
    @PeriodStart				DateTime,
    @PeriodEnd					DateTime,
    @PayeeCompanyID				TIdentifier,
    @PayerCompanyID				TIdentifier,
    @CompanyManagerEmployeeID	TIdentifier,
    @ProjectManagerEmployeeID	TIdentifier
AS
	SET NOCOUNT ON

	DECLARE
		@BaseCurrencyCode	TCode3,
		@value				TVariant,
		@Date				TDate,
		@ViewAllFinance		TBool

	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))

	IF @ViewAllFinance = 1
	BEGIN
		EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @value OUTPUT
		SET @BaseCurrencyCode = CAST(@value as varchar(3))
	
		SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	
		IF @DateSelector = 1 -- last 7 days
			SELECT
				@PeriodStart = DATEADD(day, -7, @Date),
				@PeriodEnd = @Date

		IF @DateSelector = 2 -- this month
			SELECT
				@PeriodStart = DATEADD(day, 1 - DATEPART(day, @Date), @Date),
				@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))
	
		IF @DateSelector = 3 -- last month
			SELECT
				@PeriodStart = DATEADD(month, -1, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
				@PeriodEnd = DATEADD(day, -1, DATEADD(month, 1, @PeriodStart))

		IF @DateSelector = 4 -- 3 month
			SELECT
				@PeriodStart = DATEADD(month, -2, DATEADD(day, 1 - DATEPART(day, @Date), @Date)),
				@PeriodEnd = DATEADD(day, -1, DATEADD(month, 3, @PeriodStart))
			
		IF @DateSelector = 5 -- arbitrary period
			SELECT
				@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
				@PeriodEnd = CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime),
				@PeriodEnd = DATEADD(day, 1, @PeriodEnd),
				@PeriodEnd = DATEADD(millisecond, -5, @PeriodEnd)
			
		 SELECT
			[PaymentDetail].[ID] as [PaymentDetailID],
			[PaymentDetail].[PaymentID] as [ID],
			[Payment].[Class],
			[Payment].[State],
			[Payment].[Flag],
			[Payment].[Timestamp],
			[PaymentDetail].[InvoiceID],
			[Invoice].[Class] as [InvoiceClass],
			[Invoice].[State] as [InvoiceState],
			[Invoice].[Timestamp] as [InvoiceTimestamp],
			[Payment].[Number],
			[Payment].[Date],
			[Payment].[FileAs],
			[Payment].[PaymentTypeID],
			[Payment].[PayeeCompanyID],
			[Payment].[PayeeBankAccountID],
			[Payment].[PayerCompanyID],
			[Company].[ManagerEmployeeID],
			[Payment].[Value]-[Payment].[VAT] AS [TotalBC],
			[Payment].[VAT],
			[Payment].[Value],
			[Invoice].[Number] as [InvoiceNumber],
			[Invoice].[Date] as [InvoiceDate],
			[Invoice].[FileAs] as [InvoiceFileAs],
			[Invoice].[Advance],
			[Project].[CostCenterID],
			[Project].[ProjectManagerEmployeeID],
			[Invoice].[ProjectID],
			[Invoice].[Total],
			[Invoice].[VAT] as [InvoiceVAT],
			[Invoice].[TotalWithVAT],
			[PaymentDetail].[PaymentValue],
			([Payment].[Value] - ISNULL((SELECT SUM([PaymentValue]) FROM [PaymentDetail] WHERE [PaymentID] = [Payment].[ID]), 0)) AS [TotalNotAssigned],
			[Payment].[CurrencyCode],
			[Payment].[TotalWithVATBC],
			[Invoice].[TotalWithVATBC] AS [BaseTotal],
			([PaymentDetail].[PaymentValue]*[Payment].[BaseCurrencyRate]) as [PaymentValueBC],
			@BaseCurrencyCode as [BaseCurrencyCode],
			[Payment].[Created],
			[Payment].[CreatedBy],
			[Payment].[Modified],
			[Payment].[ModifiedBy]
		FROM
		[PaymentDetail] 
		INNER JOIN [Payment]
			ON [PaymentDetail].[PaymentID] = [Payment].[ID]
		INNER JOIN [Invoice]
			ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [Company]
			ON [Company].[ID] = [Payment].[PayerCompanyID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
		WHERE
			@ViewAllFinance = 1 
			AND
			((@DateSelector = 0) OR ([Payment].[Date] BETWEEN @PeriodStart AND @PeriodEnd))
			AND
			((@PayeeCompanyID IS NULL) OR ([Payment].[PayeeCompanyID] = @PayeeCompanyID))
			AND
			((@PayerCompanyID IS NULL) OR ([Payment].[PayerCompanyID] = @PayerCompanyID))
			AND
			((@CompanyManagerEmployeeID IS NULL) OR ([Company].[ManagerEmployeeID] = @CompanyManagerEmployeeID))
			AND
			((@ProjectManagerEmployeeID IS NULL) OR ([Project].[ProjectManagerEmployeeID] = @ProjectManagerEmployeeID))
		END
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm7PaymentToInvoiceBrowse] TO PUBLIC
GO
 
