IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5ProjectBrowseMineDraft')
	BEGIN
		PRINT 'Dropping Procedure pjm5ProjectBrowseMineDraft'
		DROP  Procedure  pjm5ProjectBrowseMineDraft
	END

GO

PRINT 'Creating Procedure pjm5ProjectBrowseMineDraft'
GO
/******************************************************************************
**		File: 
**		Name: pjm5ProjectBrowseMineDraft
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.04.13	SOV				    . - 
**									     " "
**		29.04.13	SOV				    
**		07.05.13	SOV				    - - 
**									        ?
**		07.05.13	SOV				  ID . -  . - 
**		05.05.14	BAO				    
*******************************************************************************/
CREATE Procedure pjm5ProjectBrowseMineDraft
	@CommonStateSelector INT,
	@CustomerStateSelector INT
AS
	SET NOCOUNT ON
	
	DECLARE 
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier,
		@HasManageProject TBool,
		@ViewFinance TBool
				
	SET @HasManageProject = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
		
	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Project].[ProjectStageID],
		[Budgets].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN @ViewAllFinance = 1 OR (@ViewFinance = 1 AND 
				(dbo.fnPjm7HasPossibilityToProjectFinanceManagement([Project].[ID], @CurrentEmployeeID) = 1 OR
				[Project].[FinanceManagerEmployeeID] = @CurrentEmployeeID)) OR
				(@HasManageProject = 1 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID)
				THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[Budgets].[PlannedManHour],
		CASE
			WHEN @ViewAllFinance = 1 OR (@ViewFinance = 1 AND 
				(dbo.fnPjm7HasPossibilityToProjectFinanceManagement([Project].[ID], @CurrentEmployeeID) = 1 OR
				[Project].[FinanceManagerEmployeeID] = @CurrentEmployeeID)) OR
				(@HasManageProject = 1 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID)
				THEN [Budgets].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Project].[ExchangeSystemName],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		[PaymentPeriod].[InvoiceNextPaymentDate],
		[PaymentPeriod].[StatementNextPaymentDate],
		[PaymentPeriod].[CalculationNextPaymentDate],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		[Projects].[ParentProjectID] AS [ParentProjectID],
		[Project].[ManagerAssistantEmployeeID],
		[Project].[FinanceManagerEmployeeID]
	FROM
		[Project]
		INNER JOIN pjm6GetAvailableProjectsForBrowse (
			@CurrentEmployeeID,		--  
			1,						-- 
			1						--   
		) AS [Projects]
			ON [Project].[ID] = [Projects].[ID]
		INNER JOIN [PaymentPeriod]
			ON [PaymentPeriod].[ProjectID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]
			ON [CustomerCompany].[ID] = [Project].[CustomerCompanyID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		INNER JOIN dbo.fnPjm7GetProjectsBudgets() AS [Budgets]
			ON [Budgets].[ProjectID] = [Project].[ID]
	WHERE
		( 
			(@CustomerStateSelector = 0) OR 
			(@CustomerStateSelector = 1 AND [Project].[ProjectTypeID] = 1) OR
			(@CustomerStateSelector = 2 AND [Project].[ProjectTypeID] = 2) OR
			([Project].[ProjectTypeID] NOT IN (1, 2) AND @CustomerStateSelector = 3)
		)
		
	RETURN 0
GO

GRANT EXEC ON pjm5ProjectBrowseMineDraft TO PUBLIC
GO
