IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm7ProjectBrowseReportByProjects]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm7ProjectBrowseReportByProjects'
		DROP PROCEDURE [dbo].[pjm7ProjectBrowseReportByProjects]
	END
GO

PRINT 'Creating procedure pjm7ProjectBrowseReportByProjects'
GO

/******************************************************************************
**		File: 
**		Name: pjm7ProjectBrowseReportByProjects
**		Desc:        "  "  MS Excel
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: sergey.pelevin
**		Date: 17/10/2012 11:17
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		06.11.12	SAP				     
**									 
**		07.11.12	SAP				    
**									
**		12.11.12	SOV				      ,   
**									 
**		21.11.12	SOV				    DISTINCT
**		30.11.12	SOV				 Flag   1        
**									 
**		03.12.12	SOV				   ProjectView    Project
**		07.05.13	SOV				    - - 
**									        ?
**		18.11.13	SAP				   
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm7ProjectBrowseReportByProjects]
--	    
	@ProjectSelector			INT,
	@ActiveProjectID			TIdentifier,
	@InactiveProjectID			TIdentifier,
--	   
	@CustomerCompanyID			TIdentifier,
--	   
	@DateSelector				INT,
	@PeriodStart				datetime,
	@PeriodEnd					datetime,
--	   
	@IndustryBranchSelector		INT,
	@IndustryBranchID			TIdentifier,
--	    
	@StateSelector				INT,
--	    
	@ProjectManagerEmployeeID	TIdentifier,
--	    
	@CostCenterSelector			INT,
	@CostCenterID				TIdentifier,
--	   
	@EmployeeSelector			INT,
	@EmployeeID					TIdentifier
AS
	SET NOCOUNT ON
	SET ANSI_WARNINGS OFF
	
--          
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) = 0 BEGIN
		RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END


	
	DECLARE 
		@date datetime
		
	--       
	SET @date = GETDATE()
	
	IF @DateSelector = 1
		SELECT
			@PeriodStart = CAST(CAST(YEAR(@date) AS varchar(4)) + '0101' AS datetime),
			@PeriodEnd = DATEADD(year, 1, @PeriodStart)
	IF @DateSelector = 2
		SELECT
			@PeriodStart = CAST(CAST(YEAR(@date)-1 AS varchar(4)) + '0101' AS datetime),
			@PeriodEnd = DATEADD(year, 1, @PeriodStart)
	IF @DateSelector = 3
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime))
	
	IF (@ProjectSelector = 1 AND @ActiveProjectID IS NOT NULL) OR (@ProjectSelector = 2 AND @InactiveProjectID IS NOT NULL)
	BEGIN
		SET @DateSelector = 0
		SET @IndustryBranchSelector = 0
		SET @IndustryBranchID = null
		SET @ProjectManagerEmployeeID = null
		SET @StateSelector = 0
		SET @CostCenterID = null
		SET @CostCenterSelector = 0
		SET @EmployeeSelector = 1
		SET @EmployeeID = null
	END
	
	
	--******************  ***************************
	
		DECLARE @ProjectAssignment TABLE
		(
			AssignmentID int,
			ProjectID int,
			AssignmentState int,
			EmployeeID int,
			EmployeeState int
		)
	
		INSERT INTO @ProjectAssignment
		SELECT  
		[Assignment].[ID], 
		[Assignment].[ProjectID],
		[Assignment].[State],
		[Employee].[ID], 
		[Employee].[State]
		FROM 
			[Assignment]
			INNER JOIN [AssignmentEntry]
				ON [Assignment].[ID] = [AssignmentEntry].[AssignmentID]
			INNER JOIN [Employee] 
				ON [Employee].[ID] = [AssignmentEntry].[EmployeeID]
		WHERE		 
			[Assignment].[State] = 1 AND 
			(				
				(
					@EmployeeSelector = 1 AND @EmployeeID IS NULL
				) OR
				(				
					@EmployeeSelector = 0 AND @EmployeeID IS NULL AND [Employee].[State] = 1
				) OR
				(
					[Employee].[ID] = @EmployeeID
				)
			)
		
		IF(@EmployeeID IS NULL)
		BEGIN
		INSERT INTO @ProjectAssignment
		SELECT
			null,
			[Project].[ID],
			null,
			null,
			null
		FROM
			[Project]
		WHERE
			[Project].[ID] NOT IN (SELECT [@ProjectAssignment].[ProjectID] FROM @ProjectAssignment)
		END
				
				
	
	--    
	DECLARE @ViewTable TABLE
	(
		[Class] TClass,
		[ID] TIdentifier,
		[CustomerCompanyID] TIdentifier,
		[ProjectNumber] TCode,
		[FileAs] TName,
		[ProjectManagerEmployeeID] TIdentifier,
		[CostCenterID] TIdentifier,
		[Date] TDate,
		[EndDate] TDate,
		[CurrencyCode] TCode3,
		[State] TState,
		[StateFileAs] TName,
		[ContractNumber] TCode,
		[ContractDate] TDate,
		[ContractEndDate] TDate,
		[ContractSubject] TName,
		[ResponsiblePersonEmployeeID] TIdentifier
	)	  
		  
	INSERT INTO @ViewTable
	SELECT DISTINCT
		[Project].[Class],
		[Project].[ID],
		[Project].[CustomerCompanyID],		
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CostCenterID],
		[Project].[Date],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[State],
		CASE
			WHEN [Project].[State] = -1 THEN '   '
			WHEN [Project].[State] = 1 THEN ''
			WHEN [Project].[State] = 2 THEN ''
			WHEN [Project].[State] = 3 THEN ''
			WHEN [Project].[State] = 4 THEN ''
			WHEN [Project].[State] = 5 THEN ' '
			WHEN [Project].[State] = 6 THEN ' '
		END AS StateFileAs,
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ResponsiblePersonEmployeeID]
		FROM
		[Project]
		INNER JOIN pjm6GetAvailableProjectsForBrowse ( --**************** ,  
			@ProjectManagerEmployeeID,		-- ID    
			@StateSelector,					--     
			1								--   
		) AS [Projects]
			ON [Project].[ID] = [Projects].[ID]	
		INNER JOIN--****************		
		@ProjectAssignment AS [ProjectAssignment]
			ON [Project].[ID] = [ProjectAssignment].[ProjectID]
	WHERE
		( --*********************
			@CustomerCompanyID IS NULL OR 
			[Project].[CustomerCompanyID] = @CustomerCompanyID
		) AND  
		( --*********************		
			@DateSelector = 0 OR 
			([Project].[Date] < @PeriodEnd AND ISNULL([Project].[EndDate], @date) > @PeriodStart)		 		
		) AND
		( --********************* 
			@CostCenterSelector = 0 OR 
			[CostCenterID] = @CostCenterID 
		) AND
		( --*******************
			[Project].[ProjectTypeID] = 1			
			AND
			(
				(@ProjectSelector = 0) 
				OR
				(
					@ProjectSelector = 1 AND 
					(
						(@ActiveProjectID IS NULL AND [Project].[State] = 2) OR
						(@ActiveProjectID IS NOT NULL AND [Project].[ID] = @ActiveProjectID)
					)
				) 
				OR
				(
					@ProjectSelector = 2 AND 
					(
						(@InactiveProjectID IS NULL AND [Project].[State] != 2) OR
						(@InactiveProjectID IS NOT NULL AND [Project].[ID] = @InactiveProjectID)
					)
				)
			)
		)
		AND--*******************
		(
			(@IndustryBranchSelector = 0 AND ([Project].[CustomerCompanyID] IN (SELECT [ID] FROM [Company]) OR [Project].[CustomerCompanyID] IS NULL))
			OR
			(@IndustryBranchSelector = 1 AND @IndustryBranchID IS NULL AND ([Project].[CustomerCompanyID] NOT IN (SELECT [CompanyID] FROM [CompanyIndustryBranch]) OR [Project].[CustomerCompanyID] IS NULL))
			OR
			(@IndustryBranchSelector = 1 AND [Project].[CustomerCompanyID] IN (SELECT [CompanyID] FROM [CompanyIndustryBranch] WHERE [IndustryBranchID] = @IndustryBranchID))
		)		
	
	
	--******************  ***************************
	
	--            
	DECLARE @EarliestProjectStartDateAndProjectCount TABLE
	(
		CompanyID TIdentifier,
		StartDate datetime,
		Cnt int
	)
	INSERT INTO @EarliestProjectStartDateAndProjectCount
	SELECT 
		[@ViewTable].[CustomerCompanyID],
		MIN([Project].[Date]),
		COUNT([Project].[ID])
	FROM 
		[Project]
		INNER JOIN @ViewTable
			ON [Project].[ID] = [@ViewTable].[ID]
	GROUP BY
		[@ViewTable].[CustomerCompanyID]		
	
		
		
	DECLARE @Customer TABLE
	(
		CompanyID TIdentifier,
		CompanyName TName,
		CompanyIndustryBranch TName,
		CompanyIndustryBranches varchar(max),
		CompanySupervisor TName,
		ProjectsCount int,
		StartDate TDate
	)
	INSERT INTO @Customer
	SELECT DISTINCT
		[Company].[ID],
		[Company].[FileAs] AS CompanyName,
		[IndustryBranch].[FileAs] AS CompanyIndustryBranch,
		NULL,
		[Employee].[FileAs],		
		[@EarliestProjectStartDateAndProjectCount].[Cnt],
		[@EarliestProjectStartDateAndProjectCount].[StartDate]
	FROM
		[Company]
		LEFT JOIN @ViewTable
			ON [Company].[ID] = [@ViewTable].[CustomerCompanyID]
		LEFT JOIN [CompanyIndustryBranch]
			ON [CompanyIndustryBranch].[CompanyID] = [Company].[ID]
		LEFT JOIN [IndustryBranch]
			ON [IndustryBranch].[ID] = [CompanyIndustryBranch].[IndustryBranchID]
		LEFT JOIN [Employee]
			ON [Employee].[ID] = [Company].[ExecutiveEmployeeID]
		INNER JOIN
				@EarliestProjectStartDateAndProjectCount 				
			ON [@EarliestProjectStartDateAndProjectCount].[CompanyID] = [Company].[ID]
	ORDER BY	
		[CompanyName] ASC,
		[CompanyIndustryBranch] ASC
	
		
	--         
	INSERT INTO @Customer
	SELECT
	0,
	' ',
	'',
	'',
	'',
	[@EarliestProjectStartDateAndProjectCount].[Cnt],
	[@EarliestProjectStartDateAndProjectCount].[StartDate]
	FROM @EarliestProjectStartDateAndProjectCount
	WHERE ISNULL([@EarliestProjectStartDateAndProjectCount].[CompanyID],'1')='1'
		
		
	
	--   CompanyIndustryBranches    
	DECLARE @CurCompanyID int,
		@tmpString varchar(max)	
	
	
	DECLARE CompanyIndustryBranchesCursor CURSOR FAST_FORWARD FOR
		SELECT [CompanyID]  FROM @Customer
	OPEN CompanyIndustryBranchesCursor
	FETCH NEXT FROM CompanyIndustryBranchesCursor INTO @CurCompanyID
	WHILE @@fetch_status = 0 
	BEGIN
		
		SET @tmpString = ''
		SELECT @tmpString = @tmpString + [CompanyIndustryBranch] + ', '
		FROM @Customer
		WHERE [@Customer].[CompanyID] = @CurCompanyID		
		
		UPDATE @Customer
		SET 
			[CompanyIndustryBranches] = @tmpString 			
		WHERE
			[@Customer].[CompanyID] = @CurCompanyID			
			
		FETCH NEXT FROM CompanyIndustryBranchesCursor INTO @CurCompanyID
	END
	CLOSE CompanyIndustryBranchesCursor
	DEALLOCATE CompanyIndustryBranchesCursor				
	
	--******************  ***************************	
	
	DECLARE @Project TABLE
	(
		Class TClass,
		CustomerCompanyID int,
		ID TIdentifier,
		ProjectNumber varchar(20),
		FileAs TName,
		ProjectManagerEmployeeID TIdentifier,
		CostCenterID TIdentifier,
		CostCenter TName,
		ShortDescription TNotes,
		Manager TName,
		Participant TName,
		Participants varchar(max),
		Date TDate,
		EndDate TDate null,
		CurrencyCode TCode3,
		State TState,
		StateFileAs TName,
		Flag bit 
	)
	INSERT INTO @Project
	SELECT DISTINCT
		[@ViewTable].[Class],
		[@ViewTable].[CustomerCompanyID],
		[@ViewTable].[ID],
		[@ViewTable].[ProjectNumber],
		[@ViewTable].[FileAs],
		[@ViewTable].[ProjectManagerEmployeeID],
		[@ViewTable].[CostCenterID],
		[CostCenter].[FileAs] AS CostCenter,
		[Project].[Comments] AS ShortDescription,
		[Manager].[FileAs] AS Manager,
		[Participant].[FileAs] AS Participant,
		NULL AS Participants,
		[@ViewTable].[Date],
		[@ViewTable].[EndDate],
		[@ViewTable].[CurrencyCode],
		[@ViewTable].[State],
		[@ViewTable].[StateFileAs], 
		0 AS [Flag]
	FROM
		@ViewTable
		LEFT JOIN [CostCenter]
			ON [CostCenter].[ID] = [@ViewTable].[CostCenterID]
		INNER JOIN [Project]
			ON [Project].[ID] = [@ViewTable].[ID]
		INNER JOIN [Employee] AS Manager
			ON [Manager].[ID] = [@ViewTable].[ProjectManagerEmployeeID]
		LEFT JOIN [Assignment]
			ON [Assignment].[ProjectID] = [@ViewTable].[ID]
				AND
				[Assignment].[State] = 1 -- 
		LEFT JOIN [AssignmentEntry]
			ON [AssignmentEntry].[AssignmentID] = [Assignment].[ID]			
		LEFT JOIN [Employee] AS [Participant]
			ON [Participant].[ID] = [AssignmentEntry].[EmployeeID]				
	ORDER BY 
		[@ViewTable].[ProjectNumber] ASC
		
	--   Participants    
	DECLARE	@CurProjectID int, @CurProjectCode TCode, @CurFlag bit
	
		
	DECLARE ProjectParticipantsCursor CURSOR FAST_FORWARD FOR
		SELECT [ID], [ProjectNumber], [Flag] FROM @Project
	OPEN ProjectParticipantsCursor
	FETCH NEXT FROM ProjectParticipantsCursor INTO @CurProjectID, @CurProjectCode, @CurFlag
	WHILE @@fetch_status = 0 
	BEGIN
	
		SET @tmpString = ''
		SELECT @tmpString = @tmpString + [Participant] + ', '
		FROM @Project
		WHERE [@Project].[ID] = @CurProjectID
		
		UPDATE @Project
		SET 
			[Participants] = @tmpString			
		WHERE
			[@Project].[ID] = @CurProjectID
			
			
		--           
		--        (  )
		--    1
		BEGIN
		
			IF @CurFlag = 0
			BEGIN
				UPDATE @Project
				SET 
					[Flag] = 1
				WHERE	
					[@Project].[ID] IN
					(SELECT 
						[@Project].[ID]
					FROM
						@Project
					WHERE
						([@Project].[ProjectNumber] = @CurProjectCode
						AND
						[@Project].[ID] <> @CurProjectID)
						OR
						[@Project].[ProjectNumber] LIKE '%''%'						
					)				
			END 
		END
			
		FETCH NEXT FROM ProjectParticipantsCursor INTO @CurProjectID, @CurProjectCode, @CurFlag
	END
	CLOSE ProjectParticipantsCursor
	DEALLOCATE ProjectParticipantsCursor	
	
	--******************  ***************************
	
	--    	
	DECLARE @Contract TABLE
	(
		ProjectID int,		
		ContactPersonID int,
		Number TCode,
		Date TDate,
		EndDate TDate,
		ContractSubject TName,
		ContactPersonFileAs varchar(max),		
		ContactPersonPosition varchar(max),
		ContactPersonCompany varchar(max),
		ContactPersonPhone varchar(50),
		ContactPersonPhones varchar(max),
		ContactPersonEMail varchar(300),
		ContactPersonEMails varchar(max)
	)
	INSERT INTO @Contract
	SELECT DISTINCT
		[@ViewTable].[ID] AS ProjectID,		
		[@ViewTable].[ResponsiblePersonEmployeeID],
		[@ViewTable].[ContractNumber],
		[@ViewTable].[ContractDate],
		[@ViewTable].[ContractEndDate],
		[@ViewTable].[ContractSubject],
		[Employee].[FileAs],
		[Position].[FileAs],		
		[@Customer].[CompanyName],
		[Phone].[Phone],
		NULL,
		[Email].[Email],
		NULL
	FROM
		@Customer
		INNER JOIN @ViewTable
			ON [@ViewTable].[CustomerCompanyID] = [@Customer].[CompanyID]			
		LEFT JOIN [Employee]
			ON [Employee].[ID] = [@ViewTable].[ResponsiblePersonEmployeeID]
		LEFT JOIN [Position]
			ON [Employee].[PositionID] = [Position].[ID]		
		LEFT JOIN [BusinessCard]
			ON ([BusinessCard].[ID] = [Employee].[ID]
				AND
				[BusinessCard].[Class] = 15 --  
				)
		LEFT JOIN [Phone]
			ON [Phone].[BusinessCardID] = [BusinessCard].[ID]
		LEFT JOIN [Email]
			ON ([Email].[BusinessCardID] = [BusinessCard].[ID]
				AND
				[Email].[EmailTypeID] in (1,2,3))
	
				
		
	--   ContactPersonPhones  ContactPersonEmails     e-mail  
	-- 			
	DECLARE	@CurContactPersonID int,
		@tmpString1 varchar(max)
	
	
	DECLARE ContactPersonPhonesEmailsCursor CURSOR FAST_FORWARD FOR
		SELECT [ContactPersonID]  FROM @Contract
	OPEN ContactPersonPhonesEmailsCursor
	FETCH NEXT FROM ContactPersonPhonesEmailsCursor INTO @CurContactPersonID
	WHILE @@fetch_status = 0 
	BEGIN
		
		SET @tmpString = ''
		SELECT DISTINCT @tmpString = @tmpString + [ContactPersonPhone] + ', '
		FROM @Contract
		WHERE [@Contract].[ContactPersonID] = @CurContactPersonID
		
		SET @tmpString1 = ''
		SELECT DISTINCT @tmpString1 = @tmpString1 + [ContactPersonEmail] + ', '
		FROM @Contract
		WHERE [@Contract].[ContactPersonID] = @CurContactPersonID
		
		UPDATE @Contract
		SET 			
			[ContactPersonPhones] = @tmpString,			
			[ContactPersonEMails] = @tmpString1			
		WHERE
			[@Contract].[ContactPersonID] = @CurContactPersonID
			
		FETCH NEXT FROM ContactPersonPhonesEmailsCursor INTO @CurContactPersonID
	END
	CLOSE ContactPersonPhonesEmailsCursor
	DEALLOCATE ContactPersonPhonesEmailsCursor
	
	--   
	SELECT DISTINCT
		[@Project].[Class],
		[@Project].[ID],
		[@Project].[CustomerCompanyID],	
		[@Project].[ProjectNumber],
		[@Project].[FileAs],
		[@Project].[ProjectManagerEmployeeID],
		[@Project].[CostCenterID],
		[@Project].[Date],
		[@Project].[EndDate],
		[@Project].[CurrencyCode],
		[@Project].[State],
		[@Project].[StateFileAs],
		[@Contract].[Number] AS ContractNumber,		
		[@Contract].[Date] AS ContractDate,
		[@Contract].[EndDate] AS ContractEndDate,
		[@Contract].[ContractSubject],
		[@Contract].[ContactPersonID] AS ResponsiblePersonEmployeeID,
		CASE
			WHEN ISNULL([@Project].[CustomerCompanyID],'1') = '1' THEN 0
			ELSE [@Project].[CustomerCompanyID]			
		END AS [ProjectCompanyID],
		[@Project].[CostCenter],
		[@Project].[ShortDescription],
		[@Project].[Manager],
		[@Project].[Participants],		
		[@Project].[Flag],			
		[@Contract].[ContactPersonFileAs],		
		[@Contract].[ContactPersonPosition],
		[@Contract].[ContactPersonCompany],		
		[@Contract].[ContactPersonPhones],		
		[@Contract].[ContactPersonEMails],		
		[@Customer].[CompanyIndustryBranches],
		[@Customer].[CompanySupervisor],
		[@Customer].[StartDate] AS CompanyStartDate
	FROM 
		@Project
		LEFT JOIN @Contract
			ON [@Contract].[ProjectID] = [@Project].[ID]
		LEFT JOIN @Customer
			ON [@Customer].[CompanyID] = [@Project].[CustomerCompanyID]		
	ORDER BY
		[@Project].[ProjectNumber]
	
	--  
	SELECT DISTINCT
		[@Customer].[CompanyID],
		[@Customer].[CompanyName],
		[@Customer].[CompanyIndustryBranches],
		[@Customer].[CompanySupervisor],
		[@Customer].[ProjectsCount],
		[@Customer].[StartDate]
	FROM 
		@Customer
	ORDER BY
		[@Customer].[CompanyName]
	
	--******************  ***************************
	
	--    	
	DECLARE @TaskRequest TABLE
	(
		TaskRequestProjectID TIdentifier,
		TaskRequestID TIdentifier,
		Subject varchar(max),
		PercentComplete float,
		Supervisor TName,
		Performer TName,
		Performers varchar(max),
		StartDate datetime,
		DueDate datetime,
		ExecutedDate datetime,
		ExecutionState int
	)
	INSERT INTO @TaskRequest
	SELECT DISTINCT
		[@Project].[ID],
		[TaskRequest].[ID],
		[TaskRequest].[FileAs],
		[TaskRequest].[PercentComplete],
		[Supervisor].[FileAs],
		[Performer].[FileAs],
		NULL,
		[TaskRequest].[StartTime],
		[TaskRequest].[DueTime],
		[TaskRequest].[EndTime],		
		CASE
			WHEN [TaskRequest].[State] = 5 -- ""
			THEN 1
			ELSE 0
		END AS ExecutionState
	FROM	
		@Project
		INNER JOIN @ViewTable
			ON [@Project].[ID] = [@ViewTable].[ID]
		INNER JOIN [TaskRequest]
			ON [TaskRequest].[ProjectID] = 	[@Project].[ID]	 		
		LEFT JOIN [Employee] AS [Supervisor]
			ON [Supervisor].[ID] = [TaskRequest].[SupervisorEmployeeID]
		INNER JOIN [TaskRequestAssignment]
			ON [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID]
		LEFT JOIN [Employee] AS [Performer]
			ON [Performer].[ID] = [TaskRequestAssignment].[EmployeeID]
	WHERE
		[TaskRequest].[ProjectID] in (SELECT [ProjectID] FROM @Project)
			AND [TaskRequest].[State] != 4 --   
	

	
	--   Performers    
	DECLARE	@CurTaskRequestID int
	
	
	DECLARE TaskRequestPerformersCursor CURSOR FAST_FORWARD FOR
		SELECT [TaskRequestID]  FROM @TaskRequest
	OPEN TaskRequestPerformersCursor
	FETCH NEXT FROM TaskRequestPerformersCursor INTO @CurTaskRequestID
	WHILE @@fetch_status = 0 
	BEGIN
		
		SET @tmpString = ''
		SELECT @tmpString = @tmpString + [Performer] + ', '
		FROM @TaskRequest
		WHERE [@TaskRequest].[TaskRequestID] = @CurTaskRequestID
		
		UPDATE @TaskRequest
		SET 
			[Performers] = @tmpString			
		WHERE
			[@TaskRequest].[TaskRequestID] = @CurTaskRequestID			
			
		FETCH NEXT FROM TaskRequestPerformersCursor INTO @CurTaskRequestID
	END
	CLOSE TaskRequestPerformersCursor
	DEALLOCATE TaskRequestPerformersCursor
		
		
	SELECT DISTINCT
		[@TaskRequest].[TaskRequestProjectID],		
		[@TaskRequest].[Subject],
		[@TaskRequest].[PercentComplete],
		[@TaskRequest].[Supervisor],		
		[@TaskRequest].[Performers],
		[@TaskRequest].[StartDate],
		[@TaskRequest].[DueDate],
		[@TaskRequest].[ExecutedDate],
		[@TaskRequest].[ExecutionState]
	FROM 
		@TaskRequest
	ORDER BY 
		[@TaskRequest].[ExecutionState] ASC, 
		[@TaskRequest].[DueDate] ASC
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm7ProjectBrowseReportByProjects] TO PUBLIC
GO