IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportAllocationByCostCenter')
	BEGIN
		PRINT 'Dropping Procedure ReportAllocationByCostCenter'
		DROP  Procedure  ReportAllocationByCostCenter
	END

GO

PRINT 'Creating Procedure ReportAllocationByCostCenter'
GO

/******************************************************************************
**		File: ReportAllocationByCostCenter.sql
**		Name: ReportAllocationByCostCenter
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		--------	--------	-------------------------------------------
**		04.09.13	BAO			1)   [AllTime]   
**									     .
**								2) [EndDate]     
**									 ,   -    
**									 
**		16.01.14	BAO			   
**								,    . -
**		15.12.14	SAP			     
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportAllocationByCostCenter]
      @CompanyID TIdentifier,
      @DateSelector int,
      @StartDate TDate,
      @EndDate TDate,
      @CurrencySelector int,
      @InvoiceSelector int,
	  @IncludingDrafts		int --       -?

AS

SET NOCOUNT ON

DECLARE @CompanyName TName,
        @BaseCurrency TCode3,
        @NationalCurrency TCode3,
        @CurrencyName TCode3,
        @Value TVariant,
        @InvoiceState TName,
        @Date TDate,
		@DayAfterEndDate TDate,
        @Clients int,
		@InvoiceClass TClass
	
SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
    
SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
SET @DayAfterEndDate = DATEADD(day, 1, @EndDate)

IF @DateSelector = 0
	SELECT
		@StartDate = [StartDate],
		@EndDate = GETDATE()
	FROM	
		dbo.adfGetDateInterval(2, @Date, @Date, @Date)
ELSE IF @DateSelector = 1
    SELECT
		@StartDate = [StartDate],
		@EndDate = [EndDate],
		@EndDate = DATEADD(DAY, -1, @EndDate)
	FROM	
		dbo.adfGetDateInterval(1, @Date, @Date, @Date)
ELSE IF @DateSelector = 2
    SELECT
		@StartDate = [StartDate],
		@EndDate = [EndDate]
	FROM	
		dbo.adfGetDateInterval(4, @Date, @Date, @Date)
ELSE IF @DateSelector = 3
SELECT
		@StartDate = [StartDate],
		@EndDate = [EndDate]
	FROM	
		dbo.adfGetDateInterval(3, @Date, @Date, @Date)
ELSE 
	SELECT
		@StartDate = CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime),
		@EndDate = CAST(CONVERT(varchar(8), @EndDate, 112) AS datetime)

EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
SET @BaseCurrency = CAST(@Value AS nvarchar(32))
   
EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
SET @NationalCurrency = CAST(@Value AS nvarchar(32))


DECLARE @Employees
TABLE
(
	ID	TIdentifier	
)	
INSERT INTO @Employees
SELECT
	[Employee].[ID]
FROM
	[Employee]
	LEFT OUTER JOIN [TimeEntry]
		ON [TimeEntry].[EmployeeID] = [Employee].[ID]
		AND [TimeEntry].[StartTime] BETWEEN @StartDate AND @EndDate
	LEFT OUTER JOIN [EntryAmount]
		ON [EntryAmount].[ID] = [TimeEntry].[ID]
	LEFT OUTER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
WHERE
	[TimeEntry].[ProjectID] IS NOT NULL AND	
	(
		[Project].[SupplierCompanyID] = @CompanyID OR
		@CompanyID IS NULL
	)
GROUP BY
	[Employee].[ID]


	--   ,    
DECLARE @TimeEntriesInFinance 
TABLE
(
	[DocumentID]			TIdentifier,
	[LinkClass]				TClass, 
	[LinkDocumentID]		TIdentifier, 
	[State]					TState, 
	[Date]					TDateTime, 
	[ThroughCalculation]	TFlag
)

DECLARE 
	@tmp_employeeID				TIdentifier

DECLARE insertCursor CURSOR LOCAL FAST_FORWARD FOR
SELECT
	[@Employees].[ID]
FROM
	@Employees

OPEN insertCursor
FETCH NEXT FROM insertCursor INTO @tmp_employeeID
WHILE @@FETCH_STATUS = 0
BEGIN
	
	INSERT INTO @TimeEntriesInFinance([DocumentID], [LinkClass], [LinkDocumentID], [State], [ThroughCalculation])
	SELECT 
		[F].[DocumentID],
		[F].[LinkClass], 
		[F].[LinkDocumentID], 
		[F].[State], 
		[F].[ThroughCalculation]
	FROM
		fnReportGetTimeEntriesInFinance(@StartDate, @EndDate, @tmp_employeeID) AS [F]

	FETCH NEXT FROM insertCursor INTO @tmp_employeeID
END
CLOSE insertCursor
DEALLOCATE insertCursor



DECLARE @FinanceTable TABLE (FileAs TName, 
                             CostCenterID TCode3, 
                             Clients int,
                             Revenue float, HasCostCenter bit)

INSERT INTO @FinanceTable (FileAs, 
                           CostCenterID, 
                           Clients , 
                           Revenue, HasCostCenter)
SELECT
	ISNULL([CostCenter].[FileAs], '( )') AS [FileAs], 
    [CostCenter].[ID] AS [CostCenterID],
    COUNT(DISTINCT([Project].[CustomerCompanyID])) AS [Clients],
CASE @CurrencySelector
		WHEN 0 THEN ISNULL(SUM([Invoice].[TotalBC]), 0)
        WHEN 1 THEN ISNULL(SUM([Invoice].[TotalBC] * dbo.pjm6fnCurrencyGetRate(@BaseCurrency, [Invoice].[Date], @NationalCurrency)), 0)
    END AS [Revenue],
	CASE [CostCenterID] WHEN NULL THEN 0 ELSE 1 END AS [HasCostCenter]
FROM
	[Invoice]
	INNER JOIN [Project]
		ON [Invoice].[ProjectID] = [Project].[ID]
	LEFT OUTER JOIN [CostCenter]
		ON [Project].[CostCenterID] = [CostCenter].[ID]
WHERE
	(
		[Project].[SupplierCompanyID] = @CompanyID OR @CompanyID IS NULL
	) 
	AND
	(
		(@InvoiceSelector = 0 AND [Invoice].[State] = 5) OR
		(@InvoiceSelector = 1 AND [Invoice].[State] IN (2,5))
	) 
	AND
    (
		[Invoice].[Date] BETWEEN @StartDate AND @EndDate
	) 
GROUP BY
	[Project].[CostCenterID],
	[CostCenter].[FileAs],
	[CostCenter].[ID]

SET @Clients = 
	(
		SELECT COUNT(*) FROM [Project]
		WHERE
		(
			(@StartDate BETWEEN [Project].[Date] AND [Project].[EndDate]) 
			OR 
			(@EndDate BETWEEN [Project].[Date] AND [Project].[EndDate])
		) 
		AND 
		(
			[Project].[CostCenterID] IN (SELECT CostCenterID FROM @FinanceTable)
		)
	)

EXEC  ReportAllocationByCostCenterHeader
		  @CompanyID,
		  @DateSelector, 
		  @StartDate OUTPUT,
		  @EndDate OUTPUT, 
		  @CurrencySelector,
		  @InvoiceSelector,
		  @Clients,
		  @BaseCurrency,
		  @NationalCurrency

--TIME TABLE
SELECT 
    ISNULL([CostCenter].[FileAs], '( )') FileAs,
    SUM(CASE 
           WHEN [TimeEntry].[State] IN (2,3,6) AND [TimeEntry].[Billable] = 1 THEN [EntryAmount].[Amount]
           ELSE 0
        END) AS [ToBePaid],
    SUM(CASE 
			WHEN [TimeEntry].[State] IN (6) 
				AND (@IncludingDrafts = 1 OR ([TimeEntriesInFinance].[State] = 2 OR 
						(@InvoiceClass = [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 5) OR
						(@InvoiceClass != [TimeEntriesInFinance].[LinkClass] AND [TimeEntriesInFinance].[State] = 3))) --     
			THEN [EntryAmount].[Amount]
			ELSE 0
		END) AS [Sold],
    SUM(CASE
           WHEN [TimeEntry].[State] NOT IN (1,2,5,4) THEN [EntryAmount].[Amount]
           ELSE 0
        END) AS [AllTime],
	CASE [CostCenter].[FileAs] WHEN NULL THEN 0 ELSE 1 END AS [HasCostCenter]
FROM
	[TimeEntry]
	INNER JOIN [EntryAmount]
		ON [EntryAmount].[ID] = [TimeEntry].[ID]
	INNER JOIN [Project]
		ON [Project].[ID] = [TimeEntry].[ProjectID]
	LEFT JOIN [CostCenter]
		ON [Project].[CostCenterID] = [CostCenter].[ID]
	LEFT OUTER JOIN										--    ,   
	@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
		ON [TimeEntriesInFinance].[DocumentID] = [TimeEntry].[ID]
WHERE
	[TimeEntry].[StartTime] >= @StartDate AND [TimeEntry].[StartTime] < @DayAfterEndDate
GROUP BY
	[Project].[CostCenterID], [CostCenter].[FileAs]
ORDER BY [HasCostCenter] DESC, [AllTime] DESC

--FINANCE TABLE
SELECT
	ISNULL([FileAs], '( )') AS [FileAs],
	[Clients],
	CASE (SELECT SUM([Clients]) FROM @FinanceTable)
		WHEN 0 THEN 0 
		ELSE [Clients]*100/(SELECT SUM([Clients]) FROM @FinanceTable) 
	END AS [ClientPercent],
	[Revenue]
FROM
	@FinanceTable AS [FinanceTable]
ORDER BY [HasCostCenter] DESC, [Revenue] DESC
GO

GRANT EXEC ON ReportAllocationByCostCenter TO PUBLIC

GO

