IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportBillOfProjectPeriodHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportBillOfProjectPeriodHeader'
		DROP  Procedure  ReportBillOfProjectPeriodHeader
	END

GO

PRINT 'Creating Procedure ReportBillOfProjectPeriodHeader'
GO

/******************************************************************************
**		File: ReportEmployeeActivityResult.sql
**		Name: ReportEmployeeActivityResult
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		23.08.2013	BAO				    ,
**									..   
**									(@TypeSelector, @DateSelector)
**		23.08.2013	BAO				    
**									( HaveTasks,    
**																  )
**		14.04.2014	BAO				     
**		14.04.2014	BAO				     ,    
**									  ""
**		06.10.2014	BAO				   
*******************************************************************************/
CREATE Procedure ReportBillOfProjectPeriodHeader
	@ProjectID		TIdentifier,
	@PeriodStart	TDateTime,
	@PeriodEnd		TDateTime,
	@DateSelector	int,
	@TypeSelector	int
AS
	SET NOCOUNT ON
	DECLARE
		@UserID						TIdentifier,
		@UserName					TName,
		@FactExpense				decimal(18,2),
		@FactExpenseBefore			decimal(18,2),
		@TimeEntryHours				decimal(18,2),
		@TimeEntrySum				decimal(18,2),
		@NotApprovedHours			decimal(18,2),
		@NotApprovedSum				decimal(18,2),
		@value			TVariant,
		@WorkTime		decimal(18,2),
		@RatesWithVAT TBool
	
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
	SET @UserID = dbo.adfGetCurrentUserID()
		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
	SELECT @RatesWithVAT = [RatesWithVAT] FROM [Project] WHERE [ID] = @ProjectID
	
	SELECT
		@TimeEntryHours = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		([TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd) AND
		[State] IN (2,3,6) AND --3: 6:  	
		[Billable] = 0
		
	SELECT
		@TimeEntrySum = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0) * ISNULL([Rate],0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		([TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd) AND
		[State] IN (2,3,6) AND--3: 6:  	
		[Billable] = 0
		
	SELECT
		@NotApprovedHours = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		([TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd) AND
		[State] = 2 --2:  		
		
	SELECT
		@NotApprovedSum = ISNULL(SUM(ISNULL([RoundedDuration] / 60.00,0) * ISNULL([Rate],0)), 0)
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[ProjectID] = @ProjectID AND
		([TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd) AND
		[State] = 2 --2:  	
			
	SELECT
		@FactExpense = 
				CASE 
					WHEN [Project].[RatesWithVAT] = 1 AND [Project].[ApplyVAT] = 1
					THEN ISNULL([TimeEntry].[Rate] / (1 + [TimeEntry].[VATRate]),0) * ISNULL(SUM([TimeEntry].[BillableDuration] / 60.00 * [TimeEntry].[Billable]),0)
					ELSE ISNULL(SUM(ISNULL([TimeEntry].[BillableDuration] / 60.00,0) * ISNULL([TimeEntry].[Billable], 0) * ISNULL([TimeEntry].[Rate],0)), 0)
				END
	FROM
		[vwTimeEntry] as [TimeEntry]
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
	WHERE
		[ProjectID] = @ProjectID AND
		[TimeEntry].[StartTime] < @PeriodEnd AND
		[TimeEntry].[State] IN (2,3,6) --3: 6:  	
	GROUP BY
		[Project].[RatesWithVAT],
		[Project].[ApplyVAT],
		[TimeEntry].[Rate],
		[TimeEntry].[VATRate]
		
	SELECT
		@FactExpense = ISNULL(@FactExpense, 0) + ISNULL(SUM(ISNULL([Expense].[Billable] * [Expense].[TotalWithVATPC],0)),0)
	FROM
		[Expense]
	WHERE
		[ProjectID] = @ProjectID AND
		[Expense].[Date] < @PeriodEnd AND
		[State] IN (2,3,6)--3: 6:  
		
	SELECT
		@FactExpenseBefore = 
			CASE 
					WHEN [Project].[RatesWithVAT] = 1 AND [Project].[ApplyVAT] = 1
					THEN ISNULL([TimeEntry].[Rate] / (1 + [TimeEntry].[VATRate]),0) * ISNULL(SUM([TimeEntry].[BillableDuration] / 60.00 * [TimeEntry].[Billable]),0)
					ELSE ISNULL(SUM(ISNULL([TimeEntry].[BillableDuration] / 60.00,0) * ISNULL([TimeEntry].[Billable], 0) * ISNULL([TimeEntry].[Rate],0)), 0)
				END
	FROM
		[vwTimeEntry] as [TimeEntry]
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
	WHERE
		[ProjectID] = @ProjectID AND
		[TimeEntry].[StartTime] < @PeriodStart AND
		[TimeEntry].[State] IN (2,3,6) --3: 6:  
	GROUP BY
		[Project].[RatesWithVAT],
		[Project].[ApplyVAT],
		[TimeEntry].[Rate],
		[TimeEntry].[VATRate]
		
	SELECT
		@FactExpenseBefore = ISNULL(@FactExpenseBefore, 0) + ISNULL(SUM(ISNULL([Expense].[Billable] * [Expense].[TotalWithVATPC],0)),0)
	FROM
		[Expense]
	WHERE
		[ProjectID] = @ProjectID AND
		[Expense].[Date] < @PeriodStart AND
		[State] IN (2,3,6)--3: 6:  	

	DECLARE @HaveTasks sql_variant
	SET @HaveTasks = (SELECT [Value] FROM [F41AB0F8-FDF0-4FAD-9B71-8F17B4A51B53] WHERE [Name] = 'EnabledTasks')

	SELECT
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectCode],
		[SupplierCompany].[FileAs] AS [SupplierCompanyName],
		[CostCenter].[FileAs] AS [CostCenter],
		[Employee].[FileAs] AS [ManagerName],
		[CustomerCompany].[FileAs] AS [CustomerCompanyName],
		[Project].[Date] AS [StartDate],
		ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) AS [EndDate],
		CASE
			WHEN ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) IS NOT NULL
			THEN dbo.fnPjm5GetWorkingDays(GETDATE(), ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]))
			ELSE NULL
		END AS [Remains],
		CASE
			WHEN ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) IS NOT NULL
			THEN dbo.fnPjm5GetWorkingDays(ISNULL(DATEADD(day, 1, [Project].[EndDate]), DATEADD(day, 1, [ProjectDetail].[DueDate])), GETDATE())
			ELSE NULL
		END AS [Exceed],
		[Project].[State] AS [State],
		[Project].[Budget],
		[ProjectDetail].[PlannedBudget] AS [PlanBudget],
		(SELECT 
			ISNULL(SUM([BusyEntry].[Planned] * [Assignment].[StandardRate]), 0) / 60.0
		FROM 
			[BusyEntry] 
			INNER JOIN [Assignment]
				ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
		WHERE [BusyEntry].[ProjectID] = [Project].[ID] AND [BusyEntry].[Date] < @PeriodEnd) AS [EstimatedBudget],
		(SELECT 
			ISNULL(SUM([BusyEntry].[Planned] * [Assignment].[StandardRate]), 0) / 60.0
		FROM 
			[BusyEntry] 
			INNER JOIN [Assignment]
				ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
		WHERE [BusyEntry].[ProjectID] = [Project].[ID] AND [BusyEntry].[Date] < @PeriodStart) AS [EstimatedBudgetBefore],
		@PeriodStart AS	[PeriodStart],
		DATEADD(day, -1, @PeriodEnd) AS [PeriodEnd],	
		@UserName AS [UserName],
		@FactExpense AS [FactExpense],
		@FactExpenseBefore AS [FactExpenseBefore],
		@TimeEntryHours AS [TimeEntryHours],
		@TimeEntrySum AS [TimeEntrySum],
		@NotApprovedHours AS [NotApprovedHours],
		@NotApprovedSum	AS [NotApprovedSum],
		[Project].[CurrencyCode] AS [CurrencyCode],
		@DateSelector AS [DateSelector],
		@TypeSelector AS [TypeSelector],
		CASE WHEN ((([Task].[ProjectID] IS NOT NULL) AND (@HaveTasks = 0))
			OR ([Task].[ProjectID] IS NULL)) 
			THEN 0
			ELSE 1
		END AS [HaveTasks]				
	FROM 
		[Project]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]	
		LEFT OUTER JOIN [Employee]
			ON [Project].[ProjectManagerEmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [CostCenter]
			ON [Project].[CostCenterID] = [CostCenter].[ID]
		LEFT JOIN [Task]
			ON [Project].[ID] = [Task].[ProjectID]						
	WHERE
		[Project].[ID] = @ProjectID

RETURN 0
GO

GRANT EXEC ON ReportBillOfProjectPeriodHeader TO PUBLIC

GO
