IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectReport')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectReport'
		DROP  Procedure  ReportProjectReport
	END

GO

PRINT 'Creating Procedure ReportProjectReport'
GO

/******************************************************************************
**		File:	ReportProjectReport.sql
**		Name: 	ReportProjectReport
**		Desc:	
*******************************************************************************
**		Date:		Author:		Description:
**		-----		-------		-------------
**    	22.08.13	BAO			1)      
**								2)     
**									[DevotionHours], [DevotionPercent]
**								3)     
**									
**		21.07.14	BAO			 ,    
**								"  "
*******************************************************************************/
CREATE Procedure ReportProjectReport
	@ProjectSelector INT,
	@ActiveProjectID TIdentifier,
	@NotActiveProjectID TIdentifier
	
AS
	SET NOCOUNT ON
		
	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE 
		@ProjectID TIdentifier
		
	SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END	
			
	SET TRANSACTION ISOLATION LEVEL READ UNCOMMITTED		
	SET NOCOUNT ON
	DECLARE @value TVariant,
			@WorkTime decimal(18,2),
			@Counter  decimal(18,2)
		
			
	EXECUTE ReportProjectReportHeader @ProjectID
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
	SET @WorkTime = @WorkTime / 60.00
	
	DECLARE
		@f	table(
			[ID]   int,
			[Fact] decimal(18,2)
		)
	INSERT INTO @f(
		[ID],
		[Fact]
		)
			
	SELECT
		[Assignment].[ID],
		SUM([TimeEntry].[Duration]) / 60.0
	FROM
		[Assignment]
		LEFT OUTER JOIN [TimeEntry]
			ON [TimeEntry].[AssignmentID] = [Assignment].[ID] AND
				[TimeEntry].[State]in(2,3,6)
	WHERE
		[Assignment].[ProjectID] = @ProjectID
	GROUP BY 
		[Assignment].[ID]	
		
	
		DECLARE
		@t	table(
			[Table]		int,
			[String1]	varchar(256),
			[String2]	varchar(256),
			[String3]	varchar(256),
			[State]		int,
			[Data1]		decimal(18,2),
			[Data2]		decimal(18,2),
			[Data3]		decimal(18,2),
			[Data4]		decimal(18,2),
			[Data5]		decimal(18,2),
			[Data6]		decimal(18,2),
			[Data7]		decimal(18,2),
			[Date1]		datetime,
			[Date2]		datetime,
			[DevotionHours] decimal(18,2),
			[DevotionPercent] decimal(18,2)
		)
	
	DECLARE @SummaryTask TABLE([ID] int, [SubCount] int)
	INSERT INTO	@SummaryTask
	SELECT
			[Parent].[ID],
			COUNT([Child].[ID]) 
		FROM 
			[Task] AS [Parent] 
			LEFT OUTER JOIN [Task] AS [Child] 
				ON [Child].[ParentID] = [Parent].[ID]
		WHERE
			[Parent].[ProjectID] = @ProjectID
		GROUP BY
			[Parent].[ID]
	
	
		INSERT INTO @t(
		[Table],
		[String1],
		[String2],
		[String3],
		[State],
		[Data1],
		[Data2],
		[Data3],
		[Data4],
		[Data5],
		[Data6],
		[Data7],
		[Date1],
		[Date2],
		[DevotionHours],
		[DevotionPercent]
	)
	
	SELECT
		1, --   
		[Assignment].[FileAs], --
		[Qualification].[FileAs], --
		NULL,
		[Assignment].[State],-- (/)
		SUM(([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00), --  
		[FactTable].[Fact], --   
		SUM(CASE WHEN [BusyEntry].[Date] <= CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
			THEN (([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00)
			ELSE 0 END
		),-- 
		0,
		0,
		0,
		0,
		NULL,
		NULL,
		CASE
			WHEN SUM(CASE WHEN [BusyEntry].[Date] <= CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
			THEN (([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00)
			ELSE 0 END) = 0 THEN NULL
			ELSE [FactTable].[Fact] - SUM(CASE WHEN [BusyEntry].[Date] <= CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
			THEN (([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00)
			ELSE 0 END
		)
		END AS [DevotionHours],--  (  -  )
		CASE
			WHEN SUM(([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00) = 0 THEN NULL
			ELSE ([FactTable].[Fact] - SUM(CASE WHEN [BusyEntry].[Date] <= CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
			THEN (([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00)
			ELSE 0 END)) / SUM(([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00)
		END [DevotionPercent] --  ( / )
	FROM
		[vwAssignment] AS [Assignment]
		LEFT OUTER JOIN [Qualification]
			ON [Assignment].[QualificationID] = [Qualification].[ID]
		LEFT OUTER JOIN [BusyEntry]
			ON [Assignment].[ID] = [BusyEntry].[AssignmentID] AND
			   [BusyEntry].[ProjectID]	= @ProjectID
		LEFT OUTER JOIN @f as [FactTable]
			ON [Assignment].[ID] = [FactTable].[ID]
		LEFT OUTER JOIN [Employee]
			ON [Assignment].[EmployeeID] = [Employee].[ID]
	WHERE
		[Assignment].[ProjectID] = @ProjectID AND
		(([FactTable].[Fact] IS NOT NULL AND [Assignment].[State] = 2) OR ([Assignment].[State] = 1)) AND
		[Employee].[HideInReports] = 0
	GROUP BY
		[Assignment].[FileAs],
		[Qualification].[FileAs],
		[Assignment].[State],
		[FactTable].[Fact]
					
	SELECT
		[Table],
		[String1],
		[String2],
		[String3],
		[State],
		[Data1],
		[Data2],
		[Data3],
		[Data4],
		[Data5],
		[Data6],
		[Data7],
		[Date1],
		[Date2],
		[DevotionHours],
		[DevotionPercent]
	FROM
		@t
		
	SELECT
		2 AS [Table], --    
		CASE WHEN
			[Task].[SubprojectID] IS NULL
			THEN
				[Task].[FileAs]
			ELSE
				[Project].[FileAs]
		END AS [String1], -- 
		NULL AS [String2],
		NULL AS [String3],
		[Task].[State],-- 
		[Task].[Duration] AS [Data1],--    
		CASE
			WHEN [Task].[ManHour] IS NULL OR [Task].[ManHour] = 0
			THEN 0
		ELSE [Task].[PlannedManHour] / ([Task].[ManHour] / 60.00) * 100
		END AS [Data2], -- %  
		CASE
			WHEN [Task].[ManHour] IS NULL OR [Task].[ManHour] = 0
			THEN 0
		ELSE [Task].[RealManHourNullable] / ([Task].[ManHour] / 60.00) * 100
		END AS [Data3], -- %  	
		[Task].[RealManHourNullable] AS [Data4],--  
		[Task].[PlannedManHour] AS [Data5],--  
		[Task].[ManHour] / 60.00 AS [Data6], --  
		[Task].[PercentComplete] * 100 AS [Data7],--, %
		[Task].[DueDate],--
		[Task].[StartDate],-- 
		CASE
			WHEN [Task].[PlannedManHour] = 0 THEN NULL
			ELSE [Task].[RealManHourNullable] - [Task].[PlannedManHour]
		END AS [DevotionHours],--  (  -  )
		CASE
			WHEN [Task].[ManHour] / 60.00 = 0 THEN NULL
			ELSE ([Task].[RealManHourNullable] - [Task].[PlannedManHour]) / ([Task].[ManHour] / 60.00)
		END [DevotionPercent] --  ( / )
	FROM
		[pjm5vwTask] AS [Task]
		INNER JOIN @SummaryTask AS [SummaryTask] ON
		(
			[SummaryTask].[ID] = [Task].[ID]
			AND
			[SummaryTask].[SubCount] = 0
		)
		LEFT OUTER JOIN [Project]
			ON [Project].[ID] = [Task].[SubprojectID]
	WHERE
		[Task].[ProjectID] = @ProjectID
	
	SELECT
		3 AS [Table], --  
		CASE WHEN
			[Task].[SubprojectID] IS NULL
			THEN
				[Task].[FileAs]
			ELSE
				[SubProject].[FileAs]
		END AS [String1], -- 
		NULL AS [String2], 
		[Project].[CurrencyCode],
		[Task].[State],
		0 AS [Data1],
		[Task].[Budget] AS [Data2], --  
		CASE
			WHEN [Task].[Budget] IS NULL OR [Task].[Budget] = 0
			THEN 0
		ELSE ISNULL(([Task].[PlannedBudget] / [Task].[Budget] * 100), 0)
		END AS [Data3], -- %  
		CASE
			WHEN [Task].[Budget] IS NULL OR [Task].[Budget] = 0
			THEN 0
		ELSE ISNULL((([Task].[TimeRealBudget] + [Task].[ExpenseRealBudget]) / [Task].[Budget] * 100), 0)
		END AS [Data4], -- %  	
		[Task].[TimeRealBudget] + [Task].[ExpenseRealBudget] AS [Data5] ,--  
		0 AS [Data6],
		[Task].[PlannedBudget] AS [Data7],--  	
    	NULL AS [DueDate],
    	NULL AS [StartDate],
    	CASE
			WHEN [Task].[PlannedBudget] = 0 THEN NULL
			ELSE ([Task].[TimeRealBudget] + [Task].[ExpenseRealBudget]) - [Task].[PlannedBudget]
		END AS [DevotionHours],--  (  -  )
		CASE
			WHEN [Task].[Budget] = 0 THEN NULL
			ELSE (([Task].[TimeRealBudget] + [Task].[ExpenseRealBudget]) - [Task].[PlannedBudget]) / [Task].[Budget]
		END [DevotionPercent] --  ( / )
	FROM 
		[pjm5vwTask] AS [Task]
		INNER JOIN [Project]
			ON 	[Task].[ProjectID] = [Project].[ID]
		INNER JOIN @SummaryTask AS [SummaryTask] ON
		(
			[SummaryTask].[ID] = [Task].[ID]
			AND
			[SummaryTask].[SubCount] = 0
		)
		LEFT OUTER JOIN [Project] AS [SubProject]
			ON [SubProject].[ID] = [Task].[SubprojectID]
	WHERE
		[Task].[ProjectID] = @ProjectID

RETURN 0
GO

GRANT EXEC ON ReportProjectReport TO PUBLIC

GO
