IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportServicesByCostCenters')
	BEGIN
		PRINT 'Dropping Procedure ReportServicesByCostCenters'
		DROP  Procedure  ReportServicesByCostCenters
	END

GO

PRINT 'Creating Procedure ReportServicesByCostCenters'
GO
/******************************************************************************
**		File: 
**		Name: ReportServicesByCostCenters
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE ReportServicesByCostCenters
	@CustomerID TIdentifier,
	@SupplierID TIdentifier,
	@DateSelector int,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS

DECLARE
	@Supplier TName,
	@Customer TName,
	@PeriodName TName,
	@TaskClass TClass,
	@EmployeeID TIdentifier,
	@Date TDate
 
SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
SET @TaskClass = dbo.adfGetClassByName('Pjm5.Task')

SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
-- 1 = Previous month
-- 0 = Current month
-- 3 = Previous quarter
-- 2 = Current quarter
IF @DateSelector =0
	SELECT
		@PeriodStart = [StartDate],
		@PeriodEnd = [EndDate]
	FROM	
		dbo.adfGetDateInterval(2, @Date, @Date, @Date)
ELSE IF @DateSelector =1
    SELECT
		@PeriodStart = [StartDate],
		@PeriodEnd = [EndDate]
	FROM	
		dbo.adfGetDateInterval(1, @Date, @Date, @Date)
ELSE IF @DateSelector =2
    SELECT
		@PeriodStart = [StartDate],
		@PeriodEnd = [EndDate]
	FROM	
		dbo.adfGetDateInterval(4, @Date, @Date, @Date)
ELSE IF @DateSelector =3
SELECT
		@PeriodStart = [StartDate],
		@PeriodEnd = [EndDate]
	FROM	
		dbo.adfGetDateInterval(3, @Date, @Date, @Date)
ELSE 
	SELECT
		@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
		@PeriodEnd = DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime))

SELECT
	@Customer = [Company].[LegalName]
FROM
	[Company]
WHERE
	[Company].[ID] = @CustomerID

SELECT
	@Supplier = [Company].[LegalName]
FROM
	[Company]
WHERE
	[Company].[ID] = @SupplierID

DECLARE @Entities TABLE 
(
	[DocumentClass] TClass,
	[DocumentID] TIdentifier,
	[CCCode] TCode,
	[CCFileAs] TName
)

INSERT INTO @Entities
(
	[DocumentClass],
	[DocumentID],
	[CCCode],
	[CCFileAs]
)
(
	SELECT DISTINCT
		(CASE WHEN [TimeEntry].[TaskID] IS NULL THEN [TimeEntry].[DocumentClass] ELSE @TaskClass END) AS [JobClass],
		(CASE WHEN [TimeEntry].[TaskID] IS NULL THEN [TimeEntry].[DocumentID] ELSE [TimeEntry].[TaskID] END) AS [JobID],
		[CostCenter].[Code],
		[CostCenter].[FileAs]
	FROM
		[TimeEntry]
		INNER JOIN [Project]
			ON [TimeEntry].[ProjectID] = [Project].[ID] AND
			[Project].[CustomerCompanyID] = @CustomerID AND
			([Project].[SupplierCompanyID] = @SupplierID OR @SupplierID IS NULL)
		LEFT OUTER JOIN [CostCenter]
			ON [Project].[CostCenterID] = [CostCenter].[ID]
	WHERE
		([TimeEntry].[StartTime] BETWEEN @PeriodStart AND @PeriodEnd) AND
		([TimeEntry].[TaskID] IS NOT NULL OR [TimeEntry].[DocumentClass] IS NOT NULL) AND
		([TimeEntry].[State] IN (3, 6))
)

DECLARE @Lines TABLE
(
	[CostCenterCode] TCode,
	[CostCenterName] TName,
	[ElementName] TName
)

-- Issues
INSERT INTO @Lines
(
	[CostCenterCode], [CostCenterName], [ElementName]
)
SELECT
	[Ent].[CCCode],
	[Ent].[CCFileAs],
	ISNULL(	[PropertyValue].[Value], [Issue].[FileAs])
FROM
	@Entities AS [Ent]
	INNER JOIN [Issue]
		ON [Issue].[Class] = [Ent].[DocumentClass] AND [Issue].[ID] = [Ent].[DocumentID] AND [Issue].[State] != 1
	LEFT OUTER JOIN [Property]	
		ON [Issue].[Class] = [Property].[Class] AND [Property].[Name] = ''
	LEFT OUTER JOIN [PropertyValue]
		ON [Property].[ID] = [PropertyValue].[PropertyID] AND [Issue].[ID] = [PropertyValue].[DocumentID]
UNION ALL
SELECT
	[Ent].[CCCode],
	[Ent].[CCFileAs],
	ISNULL(	[PropertyValue].[Value], [TaskRequest].[FileAs])
FROM
	@Entities AS [Ent]
	INNER JOIN [TaskRequest]
		ON [TaskRequest].[Class] = [Ent].[DocumentClass] AND [TaskRequest].[ID] = [Ent].[DocumentID] AND [TaskRequest].[State] != 4
	LEFT OUTER JOIN [Property]	
		ON [TaskRequest].[Class] = [Property].[Class] AND [Property].[Name] = ''
	LEFT OUTER JOIN [PropertyValue]
		ON [Property].[ID] = [PropertyValue].[PropertyID] AND [TaskRequest].[ID] = [PropertyValue].[DocumentID]
UNION ALL
SELECT
	[Ent].[CCCode],
	[Ent].[CCFileAs],
	ISNULL(	[PropertyValue].[Value], [ServiceAssignment].[FileAs])
FROM
	@Entities AS [Ent]
	INNER JOIN [ServiceAssignment]
		ON [ServiceAssignment].[Class] = [Ent].[DocumentClass] AND [ServiceAssignment].[ID] = [Ent].[DocumentID] AND [ServiceAssignment].[State] != 5
	LEFT OUTER JOIN [Property]	
		ON [ServiceAssignment].[Class] = [Property].[Class] AND [Property].[Name] = ''
	LEFT OUTER JOIN [PropertyValue]
		ON [Property].[ID] = [PropertyValue].[PropertyID] AND [ServiceAssignment].[ID] = [PropertyValue].[DocumentID]
UNION ALL
SELECT
	[Ent].[CCCode],
	[Ent].[CCFileAs],
	ISNULL(	[PropertyValue].[Value], [Task].[FileAs])
FROM
	@Entities AS [Ent]
	INNER JOIN [Task]
		ON [Task].[Class] = [Ent].[DocumentClass] AND [Task].[ID] = [Ent].[DocumentID] AND [Task].[State] != 6
	LEFT OUTER JOIN [Property]	
		ON [Task].[Class] = [Property].[Class] AND [Property].[Name] = ''
	LEFT OUTER JOIN [PropertyValue]
		ON [Property].[ID] = [PropertyValue].[PropertyID] AND [Task].[ID] = [PropertyValue].[DocumentID]
UNION ALL
SELECT
	[Ent].[CCCode],
	[Ent].[CCFileAs],
	ISNULL(	[PropertyValue].[Value], [ServiceRequest].[FileAs])
FROM
	@Entities AS [Ent]
	INNER JOIN [ServiceRequest]
		ON [ServiceRequest].[Class] = [Ent].[DocumentClass] AND [ServiceRequest].[ID] = [Ent].[DocumentID] AND [ServiceRequest].[State] != 6
	LEFT OUTER JOIN [Property]	
		ON [ServiceRequest].[Class] = [Property].[Class] AND [Property].[Name] = ''
	LEFT OUTER JOIN [PropertyValue]
		ON [Property].[ID] = [PropertyValue].[PropertyID] AND [ServiceRequest].[ID] = [PropertyValue].[DocumentID]
SET @PeriodEnd = DATEADD(day, -1, @PeriodEnd)
EXEC Pjm6GetTimeIntervalFormatted @PeriodStart, @PeriodEnd, 'ru', @Result = @PeriodName  OUTPUT 

SELECT
	[Employee].[FileAs] AS [UserName],
	@Customer AS [CustomerName],
	ISNULL(@Supplier, '()') AS [CompanyName],
	@PeriodName AS [PeriodName]
FROM
	[Employee]
WHERE
	[Employee].[ID] = @EmployeeID

SELECT DISTINCT * FROM @Lines

RETURN 0
GO
	
GRANT EXEC ON ReportServicesByCostCenters TO PUBLIC
GO