IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportTaskRequest')
	BEGIN
		PRINT 'Dropping Procedure ReportTaskRequest'
		DROP  Procedure  ReportTaskRequest
	END

GO

PRINT 'Creating Procedure ReportTaskRequest'
GO

/******************************************************************************
**		File: ReportTaskRequest.sql
**		Name: ReportTaskRequest
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		04.04.13	SOV				    . - 
**									     " "
*******************************************************************************/
CREATE Procedure ReportTaskRequest
	@ID TIdentifier
AS

	SET NOCOUNT ON
	DECLARE
		@ProjectID TIdentifier,
		@UserID			TIdentifier,
		@UserName		TName,
		@IsFinanceEnable	bit,
		@AdvancedTimeExpenses bit,
		@value TVariant,
		@ViewAllFinance TBool,
		@ViewFinance TBool,
		@CurrentEmployeeID TIdentifier,
		@IsPM TBool,
		@FinanceManagement TBool,
		@IsFinanceManager TBool
		
	SELECT 
		@ProjectID = [TaskRequest].[ProjectID]
	FROM 
		[TaskRequest]
	WHERE 
		[TaskRequest].[ID] = @ID
		
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @IsPM = dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID)
	SET @FinanceManagement = dbo.fnPjm7HasPossibilityToProjectFinanceManagement(@ProjectID, @CurrentEmployeeID)
	SET @IsFinanceManager = dbo.fnPjm7IsFinanceManager(@ProjectID, @CurrentEmployeeID)

	SET @IsFinanceEnable = @FinanceManagement & @ViewFinance
	SET @IsFinanceEnable = @IsFinanceEnable | @ViewAllFinance | @IsPM | @IsFinanceManager
		
	EXEC adfParameterGet 'AdvancedTimeExpensesForm', 'Pjm5', @value OUTPUT
	SET @AdvancedTimeExpenses = ISNULL(CAST(@value AS BIT), 0)
		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	SELECT
		[TaskRequest].[FileAs],
		[TaskRequest].[State],
		[TaskRequest].[StartTime] AS [StartDate],
		[TaskRequest].[DueTime] AS [DueDate],
		[TaskRequest].[DueTime] AS [EndDate],
		dbo.fnPjm5GetAssignmentListByTaskRequest([TaskRequest].[ID]) AS [AssignmentList],
		[Employee].[FileAs] AS [EmployeeFileAs],
		[Supervisor].[FileAs] AS [SupervisorFileAs],
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectCode],
		[Priority].[FileAs] AS [Priority],
		[TaskRequest].[PercentComplete] * 100 AS [Percent],
 		dbo.fnPjm5GetContactList([TaskRequest].[ID], [TaskRequest].[Class]) AS [Contacts],
		dbo.fnPjm5GetCategoryList([TaskRequest].[ID], [TaskRequest].[Class]) AS [Categories],
		dbo.fnPjm5GetAttachmentList([TaskRequest].[ID], [TaskRequest].[Class]) AS [AttachmentList],
		@UserName AS [UserName],
		[TaskRequest].[ActualManHour],
		[TaskRequest].[ManHour],
		[TaskRequest].[ActualBudget],
		[TaskRequest].[Budget],
		ISNULL([Project].[CurrencyCode], 'RUB') AS [CurrencyCode],
		CASE 
			WHEN (@IsFinanceEnable = 1 AND [Project].[ProjectTypeID] = 1) 		
				THEN 1
			ELSE 0
		END AS [HasFinanceAccess],
		@AdvancedTimeExpenses AS [AdvancedTimeExpenses],
		CASE
			WHEN [Project].[ID] = 1 THEN 1
			ELSE 0
		END AS [ComercialProject]
	FROM
		[TaskRequest]
		LEFT OUTER JOIN [Project]
			ON [TaskRequest].[ProjectID] = [Project].[ID]	
		LEFT OUTER JOIN [Priority]
			ON [TaskRequest].[PriorityID] = [Priority].[ID]	
		LEFT OUTER JOIN [Employee]
			ON [TaskRequest].[EmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Employee] AS [Supervisor]
			ON [TaskRequest].[SupervisorEmployeeID] = [Supervisor].[ID]
	WHERE
		[TaskRequest].[ID] = @ID
		
	
	SELECT
		1 AS [Table],
		[TaskRequest].[Comments] AS [Taxt],
		NULL AS [Date],
		NULL AS [DisplayName]		
	FROM
		[TaskRequest]
	WHERE
		[TaskRequest].[ID] = @ID		
	UNION ALL
	SELECT
		2,
		[Note].[Text],
		[Note].[Created],
		[Trustee].[DisplayName]
	FROM
		[TaskRequest]
		INNER JOIN [Note]
			ON [TaskRequest].[ID] = [Note].[DocumentID] AND
			   [TaskRequest].[Class] = [Note].[DocumentClass]
		INNER JOIN [Trustee]
			ON ([Note].[CreatedBy] = [Trustee].[ID])
	WHERE
		[TaskRequest].[ID] = @ID 
	ORDER BY 
		3 ASC		


GO

GRANT EXEC ON ReportTaskRequest TO PUBLIC

GO
