IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportTimeEntry')
	BEGIN
		PRINT 'Dropping Procedure ReportTimeEntry'
		DROP  Procedure  ReportTimeEntry
	END

GO

PRINT 'Creating Procedure ReportTimeEntry'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportTimeEntry
	@ID TIdentifier
AS

	SET NOCOUNT ON
	DECLARE
		@UserID			TIdentifier,
		@UserName		TName,
		@Lang TLanguage,
		@DocumentID TIdentifier,
		@DocumentClass TIdentifier,
		@DocumentTable TSysname,
		@DocumentName TName,
		@DocumentClassName TName,
		@ViewAllFinance TBool,
		@ViewAllProjects TBool, 
		@Assistant TBool,
		@CanViewTimeEntries TBool,
		@EmployeeID TIdentifier
		
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @Lang = dbo.adfGetLanguage()
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	
	
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) 
	SET @Assistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
	
	IF (@ViewAllFinance = 1) OR (@ViewAllProjects = 1 AND @Assistant = 1)
		SET @CanViewtimeEntries = 1
	ELSE
		SET @CanViewtimeEntries = 0
	
	SELECT
		@DocumentID = [TimeEntry].[DocumentID],
		@DocumentClass = [TimeEntry].[DocumentClass]
	FROM
		[TimeEntry]
	WHERE
		[TimeEntry].[ID] = @ID
		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	IF @Lang = 'en'
		BEGIN
			SELECT @DocumentClassName = [ClassGlobal].[Name]
			FROM [ClassGlobal]
			WHERE [ClassGlobal].[Class] = @DocumentClass AND [ClassGlobal].[Language] = @Lang
		END
	ELSE IF @Lang = 'ru'
		BEGIN
			SELECT @DocumentClassName = [Class].[Name]
			FROM [Class]
			WHERE [Class].[Class] = @DocumentClass
		END 
		
	--IF @DocumentClass = 38
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.ServiceAssignment')
		SELECT @DocumentName = [ServiceAssignment].[FileAs] FROM [ServiceAssignment] WHERE [ServiceAssignment].[ID] = @DocumentID
	--IF @DocumentClass = 47
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.Issue')
		SELECT @DocumentName = [Issue].[FileAs] FROM [Issue] WHERE [Issue].[ID] = @DocumentID
	--IF @DocumentClass = 52
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.ServiceRequest')
		SELECT @DocumentName = [ServiceRequest].[FileAs] FROM [ServiceRequest] WHERE [ServiceRequest].[ID] = @DocumentID
	--IF @DocumentClass = 65
	IF @DocumentClass = dbo.adfGetClassByName('Pjm5.TaskRequest')
		SELECT @DocumentName = [TaskRequest].[FileAs] FROM [TaskRequest] WHERE [TaskRequest].[ID] = @DocumentID
		
	SELECT
		CASE
			WHEN @CanViewtimeEntries = 1
				OR ([Project].[ProjectManagerEmployeeID] = @EmployeeID)
				OR (dbo.fnPjm5IsProjectMember([Project].[ID], @EmployeeID) = 1)
					THEN [TimeEntry].[FileAs]
			ELSE ''
		END AS [FileAs],
		[TimeEntry].[State],
		[TimeEntry].[Duration] / 60.00 AS [Duration],
		[TimeEntry].[Overtime],
		[TimeEntry].[StartTime],
		DATEADD(minute, [TimeEntry].[Duration], [TimeEntry].[StartTime]) AS [EndDate],
		[Project].[FileAs] AS [ProjectName],
		[Project].[Number] AS [ProjectCode],
		[Task].[FileAs] AS [TaskName],
		[Employee].[FileAs] AS [Employee],
		[ActivityType].[FileAs] AS [ActivityType],
		dbo.fnPjm5GetContactList([TimeEntry].[ID], [TimeEntry].[Class]) AS [Contacts],
		dbo.fnPjm5GetCategoryList([TimeEntry].[ID], [TimeEntry].[Class]) AS [Categories],
		dbo.fnPjm5GetAttachmentList([TimeEntry].[ID], [TimeEntry].[Class]) AS [AttachmentList],
		@UserName AS [UserName],
		@DocumentID AS [DocumentID],
		@DocumentClass AS [DocumentClass],
		@DocumentName AS [DocumentName],
		@DocumentClassName AS [DocumentClassName]
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [TimeEntry].[EmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Project]
			ON [TimeEntry].[ProjectID] = [Project].[ID]	
		LEFT OUTER JOIN [Task]
			ON [TimeEntry].[TaskID] = [Task].[ID]	
		LEFT OUTER JOIN [ActivityType]
			ON [TimeEntry].[ActivityTypeID] = [ActivityType].[ID]
	WHERE
		[TimeEntry].[ID] = @ID	
		
	SELECT
		2								AS [Table],
		[TransitionTemplate].[Name]		AS [TransitionName],
		[FromState].[Name]				AS [FromStateName],
		[ToState].[Name]				AS [ToStateName],
		[Transition].[Created]			AS [Time],
		[Action].[Name]					AS [ActionName],
		[Trustee].[DisplayName]			AS [TrusteeName]
	FROM
		[TimeEntry]
		INNER JOIN [Transition]
			ON [TimeEntry].[Class] = [Transition].[Class] AND
				[TimeEntry].[ID] = [Transition].[DocumentID]
		INNER JOIN [TransitionTemplate]
			ON	(	[TransitionTemplate].[ID] = [Transition].[TransitionTemplateID])
		LEFT OUTER JOIN [State] AS [FromState]
			ON	(	[FromState].[State] = [TransitionTemplate].[FromState]
				AND	[FromState].[Class] = [Transition].[Class])
		LEFT OUTER JOIN [State] AS [ToState]
			ON	(	[ToState].[State] = [TransitionTemplate].[ToState]
				AND	[ToState].[Class] = [Transition].[Class])
		INNER JOIN [Action]
			ON	(	[Action].[ID] = [TransitionTemplate].[ActionID])
		INNER JOIN [Trustee]
			ON	(	[Trustee].[ID] = [Transition].[UserID])
	WHERE
		[TimeEntry].[ID] = @ID	
		
	UNION ALL	
	SELECT
		1,
		[TimeEntry].[Comments],
		NULL,
		NULL,
		NULL,
		NULL,
		NULL
	FROM
		[TimeEntry]
	WHERE
		[TimeEntry].[ID] = @ID		
		
	UNION ALL
	SELECT
		3,
		NULL,
		NULL,
		NULL,
		[Note].[Created],
		[Note].[Text],
		[Trustee].[DisplayName]
	FROM
		[TimeEntry]
		INNER JOIN [Note]
			ON [TimeEntry].[ID] = [Note].[DocumentID] AND
			   [TimeEntry].[Class] = [Note].[DocumentClass]
		INNER JOIN [Trustee]
			ON ([Note].[CreatedBy] = [Trustee].[ID])
	WHERE
		[TimeEntry].[ID] = @ID 
	ORDER BY 
		5 ASC	

RETURN 0
GO

GRANT EXEC ON ReportTimeEntry TO PUBLIC

GO
