IF EXISTS (SELECT * FROM sysobjects WHERE TYPE = 'P' AND name = 'ReportTimeSellAnalysisByEmployeesHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportTimeSellAnalysisByEmployeesHeader'
		DROP  PROCEDURE  ReportTimeSellAnalysisByEmployeesHeader
	END
GO
PRINT 'Creating Procedure ReportTimeSellAnalysisByEmployeesHeader'
GO
/******************************************************************************
**		File: ReportTimeSellAnalysisByEmployeesHeader.sql
**		Name: ReportTimeSellAnalysisByEmployeesHeader
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Nikita.Golyshev
**		Date: 30.07.2014 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		28.10.14	SAP			   .   
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportTimeSellAnalysisByEmployeesHeader]		
	@OwnCompanyID TIdentifier,	
	@DivisionSelector int,			--  (0 -  , 2 -  )
	@DivisionID TIdentifier,		-- ID  (NULL - )
	@QualificationSelector int,		--  (0 -  , 2 -  )
	@QualificationID TIdentifier,	-- ID  (NULL - )
	@CurrencySelector int,			--   (0 - , 1 - )
	@BaseCurrencyRate DECIMAL(18,4), --    
	@PeriodSelector int,			--  (0 -  , 1 -  , 2 -  , 3 -  
									-- 4 -  , 5 -  , 6 -  
	@PeriodName TName,				--  
	@PeriodStart date,				--   
	@PeriodEnd date,				--   
	@ScaleSelector int,				--   (0 - , 1 - , 2 - , 3 - )
	@Scale int,
	@GroupBy int,
	@StandardEfficiency INT			--  	
AS
SET NOCOUNT ON

DECLARE
	@OwnCompanyName TName,
	@DivisionName TName,
	@QualificationName TName,
	@CurrencyCode TCode3,	
	@CurrencyWithPrefix TName,	
	@WorkingDays TName,
	@UserName TName,
	@UserID TIdentifier


--  	
	SELECT 
		@OwnCompanyName = [Company].[FileAs]		
	FROM
		[Company]
	WHERE 
		[Company].[ID] = @OwnCompanyID
	
	IF(@OwnCompanyName IS NULL)
	BEGIN 
		SET @OwnCompanyName = ''
	END

-- 
	SELECT
		@DivisionName = 
			CASE @DivisionSelector
				WHEN 0 THEN NULL
				WHEN 2 THEN (
					SELECT TOP(1) [FileAs]
					FROM [Division]
					WHERE [ID] = @DivisionID
				)
			END


-- 
	SELECT
		@QualificationName = 
			CASE @QualificationSelector
				WHEN 0 THEN NULL
				WHEN 2 THEN (
					SELECT TOP(1) [FileAs]
					FROM [Qualification]
					WHERE [ID] = @QualificationID
				)
			END


--   
	SELECT
		@CurrencyCode = 
			CASE @CurrencySelector
				WHEN 0 THEN [dbo].[fnPjm5GetBaseCurrency]()
				WHEN 1 THEN [dbo].[fnPjm5GetNationalCurrency]()
			END
			
	SELECT
		@CurrencyWithPrefix =
			CASE @ScaleSelector
				WHEN 0 THEN @CurrencyCode
				WHEN 1 THEN '. ' + @CurrencyCode
				WHEN 2 THEN '. ' + @CurrencyCode
				WHEN 3 THEN
					CASE @Scale
						WHEN 1000 THEN '. ' + @CurrencyCode
						WHEN 1000000 THEN '. ' + @CurrencyCode
						WHEN 1000000000 THEN '. ' + @CurrencyCode
						ELSE @CurrencyCode
					END 
			END


--  			
	SELECT
		@WorkingDays = dbo.fnPjm5GetWorkingDays(@PeriodStart,DATEADD(DAY,-1,@PeriodEnd))


-- 
	SET @UserID = dbo.adfGetCurrentUserID()		
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM 
		[Trustee]
	WHERE 
		[Trustee].[ID] = @UserID
	
	
--    
	SELECT
		@OwnCompanyName AS [OwnCompanyName],
		@DivisionName AS [DivisionName],
		@QualificationName AS [QualificationName],
		@PeriodName AS [PeriodName],
		@CurrencyWithPrefix AS [Currency],
		@StandardEfficiency AS [StandardEfficiency],
		@WorkingDays AS [WorkingDays],
		@WorkingDays*8 as [WorkingHours],
		@UserName AS [UserName],
		@GroupBy AS [GroupFlag],
		@CurrencySelector as [CurrencySelector],
		@BaseCurrencyRate as [BaseCurrencyRate]

RETURN 0
GO
GRANT EXEC ON ReportTimeSellAnalysisByEmployeesHeader TO PUBLIC
GO