IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'EmployeeTasksBrowse')
	BEGIN
		PRINT 'Dropping Procedure EmployeeTasksBrowse'
		DROP  Procedure  EmployeeTasksBrowse
	END

GO

PRINT 'Creating Procedure EmployeeTasksBrowse'
GO
/******************************************************************************
**		File: 
**		Name: EmployeeTasksBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure EmployeeTasksBrowse
	@EmployeeID TIdentifier,
	@StateSelector int
AS
	SET NOCOUNT ON
	
	DECLARE
		@ViewAllTasks TBool,
		@CurrentEmployeeID TIdentifier
		
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllTasks = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllTasks'))
	
	SELECT
		[Task].[ID]					as [TaskID],
		[vwAssignment].[ID]			as [AssignmentID],
		[Task].[FileAs]				as [TaskName],
		[vwAssignment].[FileAs]		as [AssignmentName],
		[TaskAssignment].[Units], 
		CAST([TaskAssignment].[Work]/60.0 as decimal(18,4)) as [Work],
		[Task].[StartDate],
		[Task].[DueDate],
		CASE WHEN [Task].[MsTaskID] IS NULL THEN 0 ELSE 1 END AS [FromMsProject],
		[TaskAssignment].[MsAvailable] AS [MsAvailable],
		[TaskAssignment].[RemainingWork]/60 AS [RemainingWork],
		[TaskAssignment].[RemainingOvertimeWork]/60 AS [RemainingOvertimeWork],
		ISNULL(
			(SELECT 
				SUM([TimeEntry].[Duration]) FROM [TimeEntry] 
			WHERE 
				[TimeEntry].[TaskID] = [Task].[ID] 
				AND [TimeEntry].[AssignmentID] = [vwAssignment].[ID]
				AND [TimeEntry].[State] IN (3, 6)) / 60.0 
		, 0) AS [ActualWork]
	FROM
		[Task] 
		INNER JOIN [TaskAssignment]
			ON ([Task].[ID] = [TaskAssignment].[TaskID])
		INNER JOIN [vwAssignment]
			ON ([TaskAssignment].[AssignmentID] = [vwAssignment].[ID])
		INNER JOIN [Project]
			ON [Project].[ID] = [Task].[ProjectID]
	WHERE
		[vwAssignment].[EmployeeID] = @EmployeeID
		AND
		(
		(@StateSelector = 0 AND [Task].[State] != 7) OR			--  
		(@StateSelector = 1 AND [Task].[State] = 8) OR			-- 
		(@StateSelector = 2 AND [Task].[State] = 2) OR		-- 
		(@StateSelector = 3 AND [Task].[State] = 5) OR		-- 
		(@StateSelector = 4 AND [Task].[State] = 3) OR			-- 
		(@StateSelector = 5 AND [Task].[State] = 6)				-- 
		)
		AND
		(
			@ViewAllTasks = 1 OR
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
			dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
		)
	ORDER BY
		[Task].[StartDate]
	
	SELECT
		[BusyEntry].[TaskID],
		[BusyEntry].[AssignmentID],
		[BusyEntry].[Date],
		CAST([BusyEntry].[Planned]/60.0 as decimal(18,4)) as [Value],
		[BusyEntry].[Committed]
	FROM
		[BusyEntry] INNER JOIN [Task]
			ON ([BusyEntry].[TaskID] = [Task].[ID])
		INNER JOIN [Project]
			ON [Project].[ID] = [Task].[ProjectID]
	WHERE
		[EmployeeID] = @EmployeeID	
	AND 
		(
		(@StateSelector = 0 AND [Task].[State] != 7) OR			--  
		(@StateSelector = 1 AND [Task].[State] = 8) OR			-- 
		(@StateSelector = 2 AND [Task].[State] = 2) OR		-- 
		(@StateSelector = 3 AND [Task].[State] = 5) OR		-- 
		(@StateSelector = 4 AND [Task].[State] = 3) OR			-- 
		(@StateSelector = 5 AND [Task].[State] = 6)				-- 
		)
	AND
		(
			@ViewAllTasks = 1 OR
			[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
			dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
		)
	
	RETURN 0
GO

GRANT EXEC ON EmployeeTasksBrowse TO PUBLIC
GO
