IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trTaskDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm5trTaskDelete'
		DROP  Trigger pjm5trTaskDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trTaskDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------	--------			-------------------------------------------
**		30.04.13	SOV					    ProjectDetail 
**										    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trTaskDelete'
GO
CREATE Trigger pjm5trTaskDelete 
ON [Task] FOR DELETE
AS
BEGIN
	DELETE
		[BusyEntry]
	FROM 
		[BusyEntry]
		INNER JOIN deleted
			ON deleted.[ID] = [BusyEntry].[TaskID]
	IF @@error != 0
	BEGIN
		RAISERROR('#cannotchangeemployeecalendar', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE @ProjectID TIdentifier
	DECLARE data CURSOR FAST_FORWARD FOR SELECT DISTINCT [ProjectID] FROM [deleted]
	OPEN data
	FETCH NEXT FROM data INTO @ProjectID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		;WITH [result] ([ProjectID], [DueDate], [PlannedManHour], [PlannedBudget], [PercentComplete]) AS
		(
			SELECT
				[ProjectID], 
				MAX([DueDate]), 
				SUM([ManHour]), 
				SUM([Budget]),
				SUM(
					CASE WHEN [Task].[State] IN (2, 3) AND [Task].[Duration] = 0 
							THEN [Task].[PercentComplete]
						 WHEN [Task].[State] IN (2, 3) AND [Task].[Duration] > 0
							THEN [Task].[PercentComplete] *  [Task].[Duration]
					ELSE 0
					END
					) / 
					SUM(CASE WHEN [Task].[State] IN (2, 3) AND [Task].[Duration] > 0 
							THEN [Task].[Duration] ELSE 1 END
				)
			FROM
				[Task]
			WHERE
				[Task].[ProjectID] = @ProjectID AND
				[Task].[State] IN (2, 3, 5) AND
				[Task].[MsTaskID] IS NULL
			GROUP BY 
				[ProjectID]
		)
		UPDATE
			[ProjectDetail]
		SET
			[DueDate] = ISNULL([result].[DueDate], [ProjectDetail].[DueDate]),
			[PercentComplete] = ISNULL([result].[PercentComplete], 0),
			[PlannedManHour] = ISNULL([result].[PlannedManHour], 0),
			[PlannedBudget] = ISNULL([result].[PlannedBudget], 0)
		FROM
			[ProjectDetail]
			LEFT JOIN [result]
				ON [result].[ProjectID] = [ProjectDetail].[ID]
		WHERE
			[ProjectDetail].[ID] = @ProjectID
		IF @@error != 0
		BEGIN
			CLOSE data
			DEALLOCATE data
			ROLLBACK TRANSACTION
			RETURN
		END
		FETCH NEXT FROM data INTO @ProjectID
	END
	CLOSE data
	DEALLOCATE data
END

GO
