IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskRequestChangeState]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskRequestChangeState'
		DROP PROCEDURE [dbo].[pjm5TaskRequestChangeState]
	END
GO

PRINT 'Creating procedure pjm5TaskRequestChangeState'
GO

/******************************************************************************
**		File: pjm5TaskRequestChangeState.sql
**		Name: pjm5TaskRequestChangeState
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Dmitry.Kolchev
**		Date: 01/21/2006 18:26:20
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		08.05.2013	SAI				   
**									 
**		24.09.2013	SOV				    ,   ,
**									-    
*******************************************************************************/
CREATE PROCEDURE pjm5TaskRequestChangeState
	@ID TIdentifier,
	@ToState TState
AS
	DECLARE @FromState TState,
			@TransitionTemplateID TIdentifier,
			@RightID TIdentifier,
			@Class TClass,
			@CurrentUserID TIdentifier,
			@CurrentEmployeeID TIdentifier,
			@ProjectID TIdentifier,
			@PercentComplete TPercent,
			@AuthorID TIdentifier,
			@SupervisorID TIdentifier,
			@EmployeeID TIdentifier,
			@Resolution TNotes,
			@ProjectManagerEmployeeID TIdentifier
			
	
	SET NOCOUNT ON
	
	SELECT
		@Class = [TaskRequest].[Class],
		@FromState = [TaskRequest].[State],
		@PercentComplete = [TaskRequest].[PercentComplete],
		@ProjectID = [TaskRequest].[ProjectID],
		@EmployeeID = [TaskRequest].[EmployeeID],
		@AuthorID = [TaskRequest].[CreatedBy],
		@SupervisorID = [TaskRequest].[SupervisorEmployeeID],
		@Resolution = [TaskRequest].[Resolution],
		@ProjectManagerEmployeeID = [Project].[ProjectManagerEmployeeID]
	FROM
		[TaskRequest] LEFT OUTER JOIN [Project] ON [TaskRequest].[ProjectID] = [Project].[ID]
	WHERE
		[TaskRequest].[ID] = @ID
		
	IF @FromState = @ToState
	BEGIN
		RAISERROR('#invalidargument', 18, -1)
		RETURN 1
	END
	
	SELECT
		@TransitionTemplateID = [ID],
		@RightID = [RightID]
	FROM
		[TransitionTemplate]
	WHERE
		[TransitionTemplate].[FromState] = @FromState AND [TransitionTemplate].[ToState] = @ToState
	AND
		[TransitionTemplate].[Class] = @Class
		
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#invalidoperation', 18, -1)
		RETURN 1
	END
	
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @CurrentUserID = dbo.adfGetCurrentUserID()

	SET @TransitionTemplateID = dbo.adfCheckTransitionRights(@TransitionTemplateID, @RightID, @CurrentUserID)
	
	IF (@FromState IN (2, 3) AND @ToState = 5 OR @FromState = 5 AND @ToState = 2)
	BEGIN
		IF
		(
			@AuthorID != @CurrentUserID AND
			ISNULL(@SupervisorID, -1) != @CurrentEmployeeID AND
			(ISNULL(@ProjectManagerEmployeeID, -1) NOT IN (@CurrentEmployeeID)) AND
			dbo.adfHasAccessRightByName('ManageAllTaskRequest') = 0
		)
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			RETURN 1
		END
	END
	
	
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF @FromState = 1 AND NOT EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestID] = @ID)
	BEGIN
		RAISERROR('#taskrequestisnotassigned', 18, -1)
		RETURN 0
	END

	IF @ProjectID IS NOT NULL AND @FromState = 1 AND NOT EXISTS	(	SELECT 
												* 
											FROM 
											[TaskRequestAssignment] 
											INNER JOIN [vwAssignment]
												ON [TaskRequestAssignment].[EmployeeID] = [vwAssignment].[EmployeeID]
											WHERE 
											[vwAssignment].[ProjectID] = @ProjectID AND
											[TaskRequestID] = @ID AND
											[vwAssignment].[State] = 1
										)
	BEGIN
		RAISERROR('#notassignedtospecifiedproject', 18, -1)
		RETURN 0
	END

	IF @FromState = 2 AND @ToState = 3
	BEGIN
		IF @Resolution IS NULL AND
			@AuthorID != @CurrentUserID
		BEGIN
			RAISERROR('#TaskRequestResolutionIsEmpty', 18, -1)
			RETURN 1
		END
		IF EXISTS(
			SELECT *
			FROM
				[TaskRequest]
				INNER JOIN [TaskRequestAssignment]
					ON [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID]
				INNER JOIN [Employee]
					ON [Employee].[ID] = [TaskRequestAssignment].[EmployeeID]
				INNER JOIN [DocumentCard]
					ON [DocumentCard].[ID] = [TaskRequest].[DocumentCardID]
				INNER JOIN [DocumentItem]
					ON [DocumentItem].[DocumentCardID] = [DocumentCard].[ID] AND
						[DocumentItem].[CheckedOutBy] = [Employee].[UserID]
			WHERE
				[TaskRequest].[ID] = @ID AND
				[DocumentItem].[State] = 3
		)
		BEGIN
			RAISERROR('#taskrequestdocumentischeckedout', 18, -1)
			RETURN 1
		END
	END
	
	IF @SupervisorID IS NOT NULL
		SELECT @SupervisorID = [UserID] FROM [Employee] WHERE [ID] = @SupervisorID
	
	SET @SupervisorID = ISNULL(@SupervisorID, -1)
	SET @AuthorID = ISNULL(@AuthorID, -1)
	DECLARE @SkipVerification BIT
	IF @ProjectID IS NOT NULL AND dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID) = 1
		SET @SkipVerification = 1	
	ELSE
		SET @SkipVerification = 0
	
	IF @SkipVerification = 0
	BEGIN
		IF @ToState = 4 AND @CurrentUserID NOT IN (@SupervisorID, @AuthorID)
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			RETURN 1
		END
		
		IF @ToState = 3 AND 
			@CurrentUserID NOT IN (@SupervisorID, @AuthorID) AND
			@CurrentEmployeeID != @EmployeeID
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			RETURN 1
		END
	END
	
	BEGIN TRANSACTION
	IF @FromState = 2 AND (@ToState = 3 OR @ToState = 5)
	BEGIN
		DECLARE @rv int
		EXEC @rv = pjm5TaskRequestCreateRecurrence @ID
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		SET @PercentComplete = 1.0
	END

	UPDATE [TaskRequest]
	SET
		[TaskRequest].[State] = @ToState,
		[TaskRequest].[PercentComplete] = @PercentComplete,
		[TaskRequest].[Modified] = DEFAULT,
		[TaskRequest].[ModifiedBy] = DEFAULT
	WHERE
		[TaskRequest].[ID] = @ID
	AND
		[TaskRequest].[State] = @FromState

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	IF @ToState = 4 OR @ToState = 5
	BEGIN
		EXEC @rv = pjm7AllDocumentReminderDismiss @Class, @ID
		IF @rv != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN @rv
		END
	END
	
	COMMIT TRANSACTION
	IF @ToState = 2
		EXEC pjm6TaskRequestApproved @ID
	IF @ToState = 3
		EXEC pjm6TaskRequestExecuted @ID
	IF @FromState = 2 AND @ToState = 4
		EXEC pjm6TaskRequestCanceled @ID
	IF @ToState in (3, 5)
	BEGIN
		DELETE [LastDocument]
		WHERE 
			[LastDocument].[DocumentClass] = @Class 
		AND
			[LastDocument].[DocumentID] = @ID
	END		
	RETURN 0
GO

GRANT EXECUTE ON pjm5TaskRequestChangeState TO PUBLIC
GO
