﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6TimeEntryAddedFromExchangeBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6TimeEntryAddedFromExchangeBrowse'
		DROP PROCEDURE [dbo].[pjm6TimeEntryAddedFromExchangeBrowse]
	END
GO

PRINT 'Creating procedure pjm6TimeEntryAddedFromExchangeBrowse'
GO

/******************************************************************************
**		File: TimeEntryAddedFromExchangeBrowse.sql
**		Name: pjm6TimeEntryAddedFromExchangeBrowse
**		Desc: Процедура возвращает список импортированных ЗОВ из MS Exchange
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      @DateSelector:					-----------
**			0 - не важно
**			1 - вчера и сегодня
**			2 - последние 7 дней
**
**		Auth: anton.paramonov
**		Date: 05.03.2012 14:50:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
*******************************************************************************/
CREATE PROCEDURE [dbo].[pjm6TimeEntryAddedFromExchangeBrowse]
	@DateSelector		int
AS

	SET NOCOUNT ON	

	DECLARE
		@CurrentEmployeeID	TIdentifier,
		@CurrentUserID		TIdentifier,
		@PeriodStart		TDate,
		@PeriodEnd			TDate,
		@Date				TDate,
		@Access				TBool


--	Установка значений параметров для выборки
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
	IF @DateSelector = 1 -- yesterday and today
		SELECT
			@PeriodEnd = GETDATE(),
			@PeriodStart = DATEADD(day, -1, @Date)
	IF @DateSelector = 2 -- last seven days
		SELECT
			@PeriodEnd = GETDATE(),
			@PeriodStart = DATEADD(day, -6, @Date)
			

	SET @Access = dbo.adfHasAccessRightByName('ViewAllFinance') | 
		(dbo.adfHasAccessRightByName('ViewAllProject') & dbo.adfHasAccessRightByName('Assistant'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	

--	Выборка данных
	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[EmployeeID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp]
	FROM
		[ExchangeNewImportDocument]
		INNER JOIN [vwTimeEntry] as [TimeEntry]
			ON	[TimeEntry].[ID] = [ExchangeNewImportDocument].[DocumentID] AND
				[TimeEntry].[Class] = [ExchangeNewImportDocument].[DocumentClass]					
	WHERE
		(
			@Access = 1 
			OR
			(@Access = 0 AND  [TimeEntry].[EmployeeID] = @CurrentEmployeeID)
		)
		AND 
		(
			@DateSelector = 0 OR
			[ExchangeNewImportDocument].[Date] BETWEEN @PeriodStart AND @PeriodEnd
		)  
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm6TimeEntryAddedFromExchangeBrowse] TO PUBLIC
GO
 
