IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TimeEntryBrowseByCategory]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TimeEntryBrowseByCategory'
		DROP PROCEDURE [dbo].[pjm5TimeEntryBrowseByCategory]
	END
GO

PRINT 'Creating procedure pjm5TimeEntryBrowseByCategory'
GO

/******************************************************************************
**		File: pjm5TimeEntryBrowseByCategory.sql
**		Name: pjm5TimeEntryBrowseByCategory
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		30.10.12	SAP				  " "
**		04.03.13	SAP				    
**									 " "     
**		26.04.13	SOV				  "" ("Rate")     -
**		05.09.13	SOV				     -   -   
**		24.07.14	BAO				     ,   
**									  
*******************************************************************************/
CREATE PROCEDURE [pjm5TimeEntryBrowseByCategory]
	@EmployeeID TIdentifier,
	@ProjectSelector INT,
	@ActiveProjectID TIdentifier,
	@NotActiveProjectID TIdentifier,
	@StateSelector INT,
	@DateSelector	INT,
	@PeriodStart	datetime,
	@PeriodEnd		datetime
AS
	SET NOCOUNT ON	
		
	DECLARE @none nvarchar(6)
	IF dbo.adfGetLanguage() = 'ru'
		SET @none = '()'
	ELSE
		SET @none = '(none)'

	EXEC pjm6TimeEntryBrowseParameters
			@DateSelector, 
			@PeriodStart	OUTPUT,
			@PeriodEnd		OUTPUT
			
	DECLARE
		@CurrentEmployeeID TIdentifier,
		@IncludeOwnTime TBool,
		@ParameterValue sql_variant,
		@BillableHoursStyle int
	
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
		
	IF @CurrentEmployeeID = ISNULL(@EmployeeID, @CurrentEmployeeID)
		SET @IncludeOwnTime = 1
	ELSE
		SET @IncludeOwnTime = 0

	EXEC dbo.[adfParameterGet] @Name='BillableHoursStyle', @Group='Pjm7', @Value=@ParameterValue OUTPUT
	SET @BillableHoursStyle = 
		CASE
			WHEN @ParameterValue IS NULL OR @ParameterValue = 0 THEN 0
			ELSE 1
		END

	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[ActivityTypeID],
		[TimeEntry].[EmployeeID],
		[Project].[CustomerCompanyID],
		[TimeEntry].[ProjectID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[RoundedDuration],
		[TimeEntry].[Billable],
		CASE
			WHEN [Project].[ViewFinance] = 1 OR [Project].[ViewBillableHour]=1 OR
				(@BillableHoursStyle=1 AND [TimeEntry].[EmployeeID] = @CurrentEmployeeID)
				THEN [TimeEntry].[BillableDuration]
			ELSE -60
		END AS BillableDuration,
		[TimeEntry].[Overtime],
		CASE
			WHEN [Project].[ViewFinance] != 1  THEN -1 
			ELSE [TimeEntry].[Rate]
		END AS [Rate],
		[TimeEntry].[CurrencyCode],
		[TimeEntry].[VATRate],
		CASE 
			WHEN ([Project].[ViewFinance] = 1)
			THEN 
				CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
			ELSE 
				-1 
		END AS [Sum],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp],
		ISNULL([Category].[FileAs], @none) as [Category],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
		END AS [DocumentClassName],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
		END AS [DocumentName],
		[Project].[CostCenterID]
	FROM
		[vwTimeEntry] as [TimeEntry]
		LEFT OUTER JOIN 
		dbo.fnPjm6GetAvailableProjectsForTimeBrowse (
			@ProjectSelector,
			@ActiveProjectID,
			@NotActiveProjectID) 
			AS [Project]
			ON [Project].[ID] = ISNULL([TimeEntry].[ProjectID], -1)
		LEFT OUTER JOIN [DocumentCategory]
			ON ([TimeEntry].[Class] = [DocumentCategory].[DocumentClass] AND [TimeEntry].[ID] = [DocumentCategory].[DocumentID])
		LEFT OUTER JOIN [Category]
			ON ([DocumentCategory].[DocumentClass] = [Category].[DocumentClass] AND [DocumentCategory].[CategoryID] = [Category].[ID])
	WHERE
		(
			@EmployeeID IS NULL OR
			[TimeEntry].[EmployeeID] = @EmployeeID
		)
		 AND 
		(
			(@StateSelector = 0) OR										--  
			(@StateSelector = 1 AND [TimeEntry].[State] IN (1, 5)) OR	-- / 
			(@StateSelector = 2 AND [TimeEntry].[State] = 2) OR			-- .  
			(@StateSelector = 3 AND [TimeEntry].[State] = 3) OR			-- 
			(@StateSelector = 4 AND [TimeEntry].[State] = 6) OR			--   
			(@StateSelector = 5 AND [TimeEntry].[State] = 4)			-- 
		) AND
		(
			@DateSelector = 0 OR
			(
				([TimeEntry].[StartTime] >= @PeriodStart)
				AND 
				([TimeEntry].[StartTime] < @PeriodEnd)
			)
		) AND
		(
			[Project].[ID] IS NOT NULL OR
				@IncludeOwnTime = 1 AND
				[TimeEntry].[ProjectID] IS NULL AND
				[TimeEntry].[EmployeeID] = @CurrentEmployeeID AND
				@ProjectSelector = 0
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5TimeEntryBrowseByCategory] TO PUBLIC
GO
 
