IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TimeEntryBrowseByProject]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TimeEntryBrowseByProject'
		DROP PROCEDURE [dbo].[pjm5TimeEntryBrowseByProject]
	END
GO

PRINT 'Creating procedure pjm5TimeEntryBrowseByProject'
GO

/******************************************************************************
**		File: TimeEntryBrowseByProject.sql
**		Name: pjm5TimeEntryBrowseByProject
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    	04.03.13	SAP				    
**									 " "     
**		01.04.13	SOV				. -      
**		13.05.13	SOV				. -     
**		09.09.13	SOV				  . -   -
**		17.10.13	SOV				   - fnpjm7BillableHourGet
*******************************************************************************/
CREATE PROCEDURE [pjm5TimeEntryBrowseByProject]
	@EmployeeID TIdentifier,
	@StateSelector INT,
	@ProjectID TIdentifier,
	@DateSelector INT,
	@PeriodStart TDate,
	@PeriodEnd TDate
AS
	SET NOCOUNT ON
	DECLARE 
		@ViewAllFinance TBool,
		@CurrentEmployeeID TIdentifier,
		@HasFinansDataAccess INT,
		@AllowCreateProjectEntry INT,
		@IsProjectMember INT,
		@ViewAllProjects TBool,
		@Assistant TBool,
		@IsFinanceManager TBool,
		@value	TVariant,
		@BillableHoursStyle int
	
	EXEC adfParameterGet @Name='BillableHoursStyle', @Group='Pjm7', @Value = @Value OUTPUT
	SET	@BillableHoursStyle = CONVERT(int, @value)

	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()	
		
	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) 
	SET @Assistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
	
	SET @HasFinansDataAccess = dbo.fnPjm5HasFinansDataAccess(@ProjectID, @CurrentEmployeeID, NULL, NULL)
	SET @IsFinanceManager = dbo.fnPjm7IsFinanceManager(@ProjectID, @CurrentEmployeeID)

	SET @AllowCreateProjectEntry = dbo.fnPjm5AllowCreateProjectEntry(@ProjectID, @CurrentEmployeeID)

	IF @AllowCreateProjectEntry = 0 AND ((@ViewAllProjects = 1 AND @Assistant = 1) OR @IsFinanceManager = 1)
	   SET @AllowCreateProjectEntry = 1

	EXEC pjm6TimeEntryBrowseParameters
			@DateSelector, 
			@PeriodStart	OUTPUT,
			@PeriodEnd		OUTPUT

	
	SELECT
		[TimeEntry].[Class],
		[TimeEntry].[ID],
		[TimeEntry].[State],
		[TimeEntry].[Flag],
		[TimeEntry].[FileAs],
		[TimeEntry].[ActivityTypeID],
		[TimeEntry].[EmployeeID],
		[TimeEntry].[ProjectID],
		[TimeEntry].[StartTime],
		[TimeEntry].[Duration],
		[TimeEntry].[RoundedDuration],
		[TimeEntry].[Billable],
		dbo.fnpjm7BillableHourGet([TimeEntry].[ProjectID], [TimeEntry].[BillableDuration], @BillableHoursStyle,
			CASE [TimeEntry].[EmployeeID]
				WHEN @CurrentEmployeeID THEN 1
				ELSE 0
			END
		) AS BillableDuration,
		[TimeEntry].[Overtime],
		[TimeEntry].[Rate],
		[TimeEntry].[CurrencyCode],
		[TimeEntry].[VATRate],
		CASE 
			WHEN @HasFinansDataAccess != 1
				THEN -1
			ELSE CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
		END AS [Sum],
		[TimeEntry].[Color],
		[TimeEntry].[Comments],
		[TimeEntry].[Created],
		[TimeEntry].[CreatedBy],
		[TimeEntry].[Modified],
		[TimeEntry].[ModifiedBy],
		[TimeEntry].[Timestamp],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
		END AS [DocumentClassName],
		CASE
			WHEN [TimeEntry].[TaskID] IS NULL
				THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
				ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
		END AS [DocumentName]
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		( 
			@ViewAllFinance = 1 OR 
			@AllowCreateProjectEntry = 1
		) AND
		(
			([TimeEntry].[ProjectID] = @ProjectID)
		) AND
		(
			@EmployeeID IS NULL OR
			[TimeEntry].[EmployeeID] = @EmployeeID
		) AND 
		(
			@DateSelector = 0 OR
			[TimeEntry].[StartTime] BETWEEN @PeriodStart AND @PeriodEnd
		) AND
		(
			(@StateSelector = 0) OR										--  
			(@StateSelector = 1 AND [TimeEntry].[State] IN (1, 5)) OR	-- / 
			(@StateSelector = 2 AND [TimeEntry].[State] = 2) OR			-- .  
			(@StateSelector = 3 AND [TimeEntry].[State] = 3) OR			-- 
			(@StateSelector = 4 AND [TimeEntry].[State] = 6) OR			--   
			(@StateSelector = 5 AND [TimeEntry].[State] = 4)			-- 
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5TimeEntryBrowseByProject] TO PUBLIC
GO
   